Class: Google::Apis::ContaineranalysisV1alpha1::Assessment
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Assessment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Assessment provides all information that is related to a single vulnerability for this product.
Instance Attribute Summary collapse
-
#cve ⇒ String
Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability.
-
#impacts ⇒ Array<String>
Contains information about the impact of this vulnerability, this will change with time.
-
#justification ⇒ Google::Apis::ContaineranalysisV1alpha1::Justification
Justification provides the justification when the state of the assessment if NOT_AFFECTED.
-
#long_description ⇒ String
A detailed description of this Vex.
-
#related_uris ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Uri>
Holds a list of references associated with this vulnerability item and assessment.
-
#remediations ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Remediation>
Specifies details on how to handle (and presumably, fix) a vulnerability.
-
#short_description ⇒ String
A one sentence description of this Vex.
-
#state ⇒ String
Provides the state of this Vulnerability assessment.
-
#vulnerability_id ⇒ String
The vulnerability identifier for this Assessment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Assessment
constructor
A new instance of Assessment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Assessment
Returns a new instance of Assessment.
201 202 203 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cve ⇒ String
Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking
number for the vulnerability.
Corresponds to the JSON property cve
153 154 155 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 153 def cve @cve end |
#impacts ⇒ Array<String>
Contains information about the impact of this vulnerability, this will change
with time.
Corresponds to the JSON property impacts
159 160 161 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 159 def impacts @impacts end |
#justification ⇒ Google::Apis::ContaineranalysisV1alpha1::Justification
Justification provides the justification when the state of the assessment if
NOT_AFFECTED.
Corresponds to the JSON property justification
165 166 167 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 165 def justification @justification end |
#long_description ⇒ String
A detailed description of this Vex.
Corresponds to the JSON property longDescription
170 171 172 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 170 def long_description @long_description end |
#related_uris ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Uri>
Holds a list of references associated with this vulnerability item and
assessment. These uris have additional information about the vulnerability and
the assessment itself. E.g. Link to a document which details how this
assessment concluded the state of this vulnerability.
Corresponds to the JSON property relatedUris
178 179 180 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 178 def @related_uris end |
#remediations ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Remediation>
Specifies details on how to handle (and presumably, fix) a vulnerability.
Corresponds to the JSON property remediations
183 184 185 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 183 def remediations @remediations end |
#short_description ⇒ String
A one sentence description of this Vex.
Corresponds to the JSON property shortDescription
188 189 190 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 188 def short_description @short_description end |
#state ⇒ String
Provides the state of this Vulnerability assessment.
Corresponds to the JSON property state
193 194 195 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 193 def state @state end |
#vulnerability_id ⇒ String
The vulnerability identifier for this Assessment. Will hold one of common
identifiers e.g. CVE, GHSA etc.
Corresponds to the JSON property vulnerabilityId
199 200 201 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 199 def vulnerability_id @vulnerability_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 206 def update!(**args) @cve = args[:cve] if args.key?(:cve) @impacts = args[:impacts] if args.key?(:impacts) @justification = args[:justification] if args.key?(:justification) @long_description = args[:long_description] if args.key?(:long_description) @related_uris = args[:related_uris] if args.key?(:related_uris) @remediations = args[:remediations] if args.key?(:remediations) @short_description = args[:short_description] if args.key?(:short_description) @state = args[:state] if args.key?(:state) @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id) end |