Class: Google::Apis::ContaineranalysisV1alpha1::AttestationAuthorityHint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

This submessage provides human-readable hints about the purpose of the AttestationAuthority. Because the name of a Note acts as its resource reference, it is important to disambiguate the canonical name of the Note ( which might be a UUID for security purposes) from "readable" names more suitable for debug output. Note that these hints should NOT be used to look up AttestationAuthorities in security sensitive contexts, such as when looking up Attestations to verify.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttestationAuthorityHint

Returns a new instance of AttestationAuthorityHint.



282
283
284
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#human_readable_nameString

The human readable name of this Attestation Authority, for example "qa". Corresponds to the JSON property humanReadableName

Returns:

  • (String)


280
281
282
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 280

def human_readable_name
  @human_readable_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



287
288
289
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 287

def update!(**args)
  @human_readable_name = args[:human_readable_name] if args.key?(:human_readable_name)
end