Class: Google::Apis::ContaineranalysisV1alpha1::BaseImage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BaseImage

Returns a new instance of BaseImage.



316
317
318
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layer_countFixnum

The number of layers that the base image is composed of. Corresponds to the JSON property layerCount

Returns:

  • (Fixnum)


299
300
301
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 299

def layer_count
  @layer_count
end

#nameString

The name of the base image. Corresponds to the JSON property name

Returns:

  • (String)


304
305
306
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 304

def name
  @name
end

#registryString

The registry of the base image. Corresponds to the JSON property registry

Returns:

  • (String)


309
310
311
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 309

def registry
  @registry
end

#repositoryString

The repository name in which the base image is from. Corresponds to the JSON property repository

Returns:

  • (String)


314
315
316
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 314

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



321
322
323
324
325
326
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 321

def update!(**args)
  @layer_count = args[:layer_count] if args.key?(:layer_count)
  @name = args[:name] if args.key?(:name)
  @registry = args[:registry] if args.key?(:registry)
  @repository = args[:repository] if args.key?(:repository)
end