Class: Google::Apis::ContaineranalysisV1alpha1::BuildStep

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A step in the build pipeline. Next ID: 23

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuildStep

Returns a new instance of BuildStep.



832
833
834
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_exit_codesArray<Fixnum>

Allow this build step to fail without failing the entire build if and only if the exit code is one of the specified codes. If allow_failure is also specified, this field will take precedence. Corresponds to the JSON property allowExitCodes

Returns:

  • (Array<Fixnum>)


691
692
693
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 691

def allow_exit_codes
  @allow_exit_codes
end

#allow_failureBoolean Also known as: allow_failure?

Allow this build step to fail without failing the entire build. If false, the entire build will fail if this step fails. Otherwise, the build will succeed, but this step will still have a failure status. Error information will be reported in the failure_detail field. Corresponds to the JSON property allowFailure

Returns:

  • (Boolean)


699
700
701
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 699

def allow_failure
  @allow_failure
end

#argsArray<String>

A list of arguments that will be presented to the step when it is started. If the image used to run the step's container has an entrypoint, the args are used as arguments to that entrypoint. If the image does not define an entrypoint, the first element in args is used as the entrypoint, and the remainder will be used as arguments. Corresponds to the JSON property args

Returns:

  • (Array<String>)


709
710
711
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 709

def args
  @args
end

#automap_substitutionsBoolean Also known as: automap_substitutions?

Option to include built-in and custom substitutions as env variables for this build step. This option will override the global option in BuildOption. Corresponds to the JSON property automapSubstitutions

Returns:

  • (Boolean)


715
716
717
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 715

def automap_substitutions
  @automap_substitutions
end

#dirString

Working directory to use when running this step's container. If this value is a relative path, it is relative to the build's working directory. If this value is absolute, it may be outside the build's working directory, in which case the contents of the path may not be persisted across build step executions, unless a volume for that path is specified. If the build specifies a RepoSource with dir and a step with a dir, which specifies an absolute path, the RepoSource dir is ignored for the step's execution. Corresponds to the JSON property dir

Returns:

  • (String)


727
728
729
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 727

def dir
  @dir
end

#entrypointString

Entrypoint to be used instead of the build step image's default entrypoint. If unset, the image's default entrypoint is used. Corresponds to the JSON property entrypoint

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 733

def entrypoint
  @entrypoint
end

#envArray<String>

A list of environment variable definitions to be used when running a step. The elements are of the form "KEY=VALUE" for the environment variable "KEY" being given the value "VALUE". Corresponds to the JSON property env

Returns:

  • (Array<String>)


740
741
742
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 740

def env
  @env
end

#exit_codeFixnum

Output only. Return code from running the step. Corresponds to the JSON property exitCode

Returns:

  • (Fixnum)


745
746
747
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 745

def exit_code
  @exit_code
end

#idString

Unique identifier for this build step, used in wait_for to reference this build step as a dependency. Corresponds to the JSON property id

Returns:

  • (String)


751
752
753
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 751

def id
  @id
end

#nameString

Required. The name of the container image that will run this particular build step. If the image is available in the host's Docker daemon's cache, it will be run directly. If not, the host will attempt to pull the image first, using the builder service account's credentials if necessary. The Docker daemon's cache will already have the latest versions of all of the officially supported build steps (https://github.com/GoogleCloudPlatform/cloud-builders). The Docker daemon will also have cached many of the layers for some popular images, like "ubuntu", "debian" , but they will be refreshed at the time you attempt to use them. If you built an image in a previous build step, it will be stored in the host's Docker daemon's cache and is available to use as the name for a later build step. Corresponds to the JSON property name

Returns:

  • (String)


766
767
768
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 766

def name
  @name
end

#pull_timingGoogle::Apis::ContaineranalysisV1alpha1::TimeSpan

Start and end times for a build execution phase. Next ID: 3 Corresponds to the JSON property pullTiming



771
772
773
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 771

def pull_timing
  @pull_timing
end

#remote_configString

Remote configuration for the build step. Corresponds to the JSON property remoteConfig

Returns:

  • (String)


776
777
778
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 776

def remote_config
  @remote_config
end

#resultsArray<Google::Apis::ContaineranalysisV1alpha1::StepResult>

Corresponds to the JSON property results



781
782
783
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 781

def results
  @results
end

#scriptString

A shell script to be executed in the step. When script is provided, the user cannot specify the entrypoint or args. Corresponds to the JSON property script

Returns:

  • (String)


787
788
789
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 787

def script
  @script
end

#secret_envArray<String>

A list of environment variables which are encrypted using a Cloud Key Management Service crypto key. These values must be specified in the build's Secret. Corresponds to the JSON property secretEnv

Returns:

  • (Array<String>)


794
795
796
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 794

def secret_env
  @secret_env
end

#statusString

Output only. Status of the build step. At this time, build step status is only updated on build completion; step status is not updated in real-time as the build progresses. Corresponds to the JSON property status

Returns:

  • (String)


801
802
803
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 801

def status
  @status
end

#timeoutString

Time limit for executing this build step. If not defined, the step has no time limit and will be allowed to continue to run until either it completes or the build itself times out. Corresponds to the JSON property timeout

Returns:

  • (String)


808
809
810
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 808

def timeout
  @timeout
end

#timingGoogle::Apis::ContaineranalysisV1alpha1::TimeSpan

Start and end times for a build execution phase. Next ID: 3 Corresponds to the JSON property timing



813
814
815
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 813

def timing
  @timing
end

#volumesArray<Google::Apis::ContaineranalysisV1alpha1::Volume>

List of volumes to mount into the build step. Each volume is created as an empty volume prior to execution of the build step. Upon completion of the build, volumes and their contents are discarded. Using a named volume in only one step is not valid as it is indicative of a build request with an incorrect configuration. Corresponds to the JSON property volumes



822
823
824
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 822

def volumes
  @volumes
end

#wait_forArray<String>

The ID(s) of the step(s) that this build step depends on. This build step will not start until all the build steps in wait_for have completed successfully. If wait_for is empty, this build step will start when all previous build steps in the Build.Steps list have completed successfully. Corresponds to the JSON property waitFor

Returns:

  • (Array<String>)


830
831
832
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 830

def wait_for
  @wait_for
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 837

def update!(**args)
  @allow_exit_codes = args[:allow_exit_codes] if args.key?(:allow_exit_codes)
  @allow_failure = args[:allow_failure] if args.key?(:allow_failure)
  @args = args[:args] if args.key?(:args)
  @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions)
  @dir = args[:dir] if args.key?(:dir)
  @entrypoint = args[:entrypoint] if args.key?(:entrypoint)
  @env = args[:env] if args.key?(:env)
  @exit_code = args[:exit_code] if args.key?(:exit_code)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @pull_timing = args[:pull_timing] if args.key?(:pull_timing)
  @remote_config = args[:remote_config] if args.key?(:remote_config)
  @results = args[:results] if args.key?(:results)
  @script = args[:script] if args.key?(:script)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
  @status = args[:status] if args.key?(:status)
  @timeout = args[:timeout] if args.key?(:timeout)
  @timing = args[:timing] if args.key?(:timing)
  @volumes = args[:volumes] if args.key?(:volumes)
  @wait_for = args[:wait_for] if args.key?(:wait_for)
end