Class: Google::Apis::ContaineranalysisV1alpha1::Command
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Command
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Command describes a step performed as part of the build pipeline.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Command-line arguments used when executing this Command.
-
#dir ⇒ String
Working directory (relative to project source root) used when running this Command.
-
#env ⇒ Array<String>
Environment variables set before running this Command.
-
#id ⇒ String
Optional unique identifier for this Command, used in wait_for to reference this Command as a dependency.
-
#name ⇒ String
Name of the command, as presented on the command line, or if the command is packaged as a Docker container, as presented to
docker pull. -
#wait_for ⇒ Array<String>
The ID(s) of the Command(s) that this Command depends on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Command
constructor
A new instance of Command.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Command
Returns a new instance of Command.
1124 1125 1126 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Command-line arguments used when executing this Command.
Corresponds to the JSON property args
1094 1095 1096 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1094 def args @args end |
#dir ⇒ String
Working directory (relative to project source root) used when running this
Command.
Corresponds to the JSON property dir
1100 1101 1102 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1100 def dir @dir end |
#env ⇒ Array<String>
Environment variables set before running this Command.
Corresponds to the JSON property env
1105 1106 1107 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1105 def env @env end |
#id ⇒ String
Optional unique identifier for this Command, used in wait_for to reference
this Command as a dependency.
Corresponds to the JSON property id
1111 1112 1113 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1111 def id @id end |
#name ⇒ String
Name of the command, as presented on the command line, or if the command is
packaged as a Docker container, as presented to docker pull.
Corresponds to the JSON property name
1117 1118 1119 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1117 def name @name end |
#wait_for ⇒ Array<String>
The ID(s) of the Command(s) that this Command depends on.
Corresponds to the JSON property waitFor
1122 1123 1124 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1122 def wait_for @wait_for end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1129 1130 1131 1132 1133 1134 1135 1136 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1129 def update!(**args) @args = args[:args] if args.key?(:args) @dir = args[:dir] if args.key?(:dir) @env = args[:env] if args.key?(:env) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @wait_for = args[:wait_for] if args.key?(:wait_for) end |