Class: Google::Apis::ContaineranalysisV1alpha1::ComplianceNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

ComplianceNote encapsulates all information about a specific compliance check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComplianceNote

Returns a new instance of ComplianceNote.



1281
1282
1283
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cis_benchmarkGoogle::Apis::ContaineranalysisV1alpha1::CisBenchmark

A compliance check that is a CIS benchmark. Corresponds to the JSON property cisBenchmark



1243
1244
1245
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1243

def cis_benchmark
  @cis_benchmark
end

#descriptionString

A description about this compliance check. Corresponds to the JSON property description

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1248

def description
  @description
end

#impactString

Potential impact of the suggested remediation Corresponds to the JSON property impact

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1253

def impact
  @impact
end

#rationaleString

A rationale for the existence of this compliance check. Corresponds to the JSON property rationale

Returns:

  • (String)


1258
1259
1260
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1258

def rationale
  @rationale
end

#remediationString

A description of remediation steps if the compliance check fails. Corresponds to the JSON property remediation

Returns:

  • (String)


1263
1264
1265
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1263

def remediation
  @remediation
end

#scan_instructionsString

Serialized scan instructions with a predefined format. Corresponds to the JSON property scanInstructions NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1269
1270
1271
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1269

def scan_instructions
  @scan_instructions
end

#titleString

The title that identifies this compliance check. Corresponds to the JSON property title

Returns:

  • (String)


1274
1275
1276
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1274

def title
  @title
end

#versionArray<Google::Apis::ContaineranalysisV1alpha1::ComplianceVersion>

The OS and config versions the benchmark applies to. Corresponds to the JSON property version



1279
1280
1281
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1279

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1286

def update!(**args)
  @cis_benchmark = args[:cis_benchmark] if args.key?(:cis_benchmark)
  @description = args[:description] if args.key?(:description)
  @impact = args[:impact] if args.key?(:impact)
  @rationale = args[:rationale] if args.key?(:rationale)
  @remediation = args[:remediation] if args.key?(:remediation)
  @scan_instructions = args[:scan_instructions] if args.key?(:scan_instructions)
  @title = args[:title] if args.key?(:title)
  @version = args[:version] if args.key?(:version)
end