Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

ApprovalConfig describes configuration for manual approval of a build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalConfig

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalConfig.



1317
1318
1319
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_requiredBoolean Also known as: approval_required?

Whether or not approval is needed. If this is set on a build, it will become pending when created, and will need to be explicitly approved to start. Corresponds to the JSON property approvalRequired

Returns:

  • (Boolean)


1314
1315
1316
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1314

def approval_required
  @approval_required
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1322
1323
1324
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1322

def update!(**args)
  @approval_required = args[:approval_required] if args.key?(:approval_required)
end