Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects.



1538
1539
1540
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Cloud Storage bucket and optional object path, in the form "gs://bucket/path/ to/somewhere/". (see Bucket Name Requirements). Files in the workspace matching any path pattern will be uploaded to Cloud Storage with this location as a prefix. Corresponds to the JSON property location

Returns:

  • (String)


1526
1527
1528
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1526

def location
  @location
end

#pathsArray<String>

Path globs used to match files in the build's workspace. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


1531
1532
1533
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1531

def paths
  @paths
end

#timingGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property timing



1536
1537
1538
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1536

def timing
  @timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1543
1544
1545
1546
1547
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1543

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @paths = args[:paths] if args.key?(:paths)
  @timing = args[:timing] if args.key?(:timing)
end