Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact.



1541
1542
1543
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Maven artifactId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property artifactId

Returns:

  • (String)


1506
1507
1508
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1506

def artifact_id
  @artifact_id
end

#deploy_folderString

Optional. Path to a folder containing the files to upload to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/target/, or a relative path from /workspace, e.g. my-app/target/. This field is mutually exclusive with the path field. Corresponds to the JSON property deployFolder

Returns:

  • (String)


1514
1515
1516
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1514

def deploy_folder
  @deploy_folder
end

#group_idString

Maven groupId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property groupId

Returns:

  • (String)


1519
1520
1521
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1519

def group_id
  @group_id
end

#pathString

Optional. Path to an artifact in the build's workspace to be uploaded to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/ target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/ target/my-app-1.0.SNAPSHOT.jar. Corresponds to the JSON property path

Returns:

  • (String)


1527
1528
1529
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1527

def path
  @path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


1534
1535
1536
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1534

def repository
  @repository
end

#versionString

Maven version value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property version

Returns:

  • (String)


1539
1540
1541
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1539

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1546
1547
1548
1549
1550
1551
1552
1553
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1546

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder)
  @group_id = args[:group_id] if args.key?(:group_id)
  @path = args[:path] if args.key?(:path)
  @repository = args[:repository] if args.key?(:repository)
  @version = args[:version] if args.key?(:version)
end