Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
A fatal problem encountered during the execution of the build.
Instance Attribute Summary collapse
-
#detail ⇒ String
Explains the failure issue in more detail using hard-coded text.
-
#type ⇒ String
The name of the failure.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo.
2078 2079 2080 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detail ⇒ String
Explains the failure issue in more detail using hard-coded text.
Corresponds to the JSON property detail
2071 2072 2073 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2071 def detail @detail end |
#type ⇒ String
The name of the failure.
Corresponds to the JSON property type
2076 2077 2078 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2076 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2083 2084 2085 2086 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2083 def update!(**args) @detail = args[:detail] if args.key?(:detail) @type = args[:type] if args.key?(:type) end |