Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Optional arguments to enable specific features of builds.
Instance Attribute Summary collapse
-
#automap_substitutions ⇒ Boolean
(also: #automap_substitutions?)
Option to include built-in and custom substitutions as env variables for all build steps.
-
#default_logs_bucket_behavior ⇒ String
Optional.
-
#disk_size_gb ⇒ Fixnum
Requested disk size for the VM that runs the build.
-
#dynamic_substitutions ⇒ Boolean
(also: #dynamic_substitutions?)
Option to specify whether or not to apply bash style string operations to the substitutions.
-
#enable_structured_logging ⇒ Boolean
(also: #enable_structured_logging?)
Optional.
-
#env ⇒ Array<String>
A list of global environment variable definitions that will exist for all build steps in this build.
-
#log_streaming_option ⇒ String
Option to define build log streaming behavior to Cloud Storage.
-
#logging ⇒ String
Option to specify the logging mode, which determines if and where build logs are stored.
-
#machine_type ⇒ String
Compute Engine machine type on which to run the build.
-
#pool ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOption
Details about how a build should be executed on a
WorkerPool. -
#pubsub_topic ⇒ String
Optional.
-
#requested_verify_option ⇒ String
Requested verifiability options.
-
#secret_env ⇒ Array<String>
A list of global environment variables, which are encrypted using a Cloud Key Management Service crypto key.
-
#source_provenance_hash ⇒ Array<String>
Requested hash for SourceProvenance.
-
#substitution_option ⇒ String
Option to specify behavior when there is an error in the substitution checks.
-
#volumes ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>
Global list of volumes to mount for ALL build steps Each volume is created as an empty volume prior to starting the build process.
-
#worker_pool ⇒ String
This field deprecated; please use
pool.nameinstead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions.
2206 2207 2208 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automap_substitutions ⇒ Boolean Also known as: automap_substitutions?
Option to include built-in and custom substitutions as env variables for all
build steps.
Corresponds to the JSON property automapSubstitutions
2097 2098 2099 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2097 def automap_substitutions @automap_substitutions end |
#default_logs_bucket_behavior ⇒ String
Optional. Option to specify how default logs buckets are setup.
Corresponds to the JSON property defaultLogsBucketBehavior
2103 2104 2105 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2103 def default_logs_bucket_behavior @default_logs_bucket_behavior end |
#disk_size_gb ⇒ Fixnum
Requested disk size for the VM that runs the build. Note that this is NOT "
disk free"; some of the space will be used by the operating system and build
utilities. Also note that this is the minimum disk size that will be allocated
for the build -- the build may run with a larger disk than requested. At
present, the maximum disk size is 4000GB; builds that request more than the
maximum are rejected with an error.
Corresponds to the JSON property diskSizeGb
2113 2114 2115 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2113 def disk_size_gb @disk_size_gb end |
#dynamic_substitutions ⇒ Boolean Also known as: dynamic_substitutions?
Option to specify whether or not to apply bash style string operations to the
substitutions. NOTE: this is always enabled for triggered builds and cannot be
overridden in the build configuration file.
Corresponds to the JSON property dynamicSubstitutions
2120 2121 2122 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2120 def dynamic_substitutions @dynamic_substitutions end |
#enable_structured_logging ⇒ Boolean Also known as: enable_structured_logging?
Optional. Option to specify whether structured logging is enabled. If true,
JSON-formatted logs are parsed as structured logs.
Corresponds to the JSON property enableStructuredLogging
2127 2128 2129 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2127 def enable_structured_logging @enable_structured_logging end |
#env ⇒ Array<String>
A list of global environment variable definitions that will exist for all
build steps in this build. If a variable is defined in both globally and in a
build step, the variable will use the build step value. The elements are of
the form "KEY=VALUE" for the environment variable "KEY" being given the value "
VALUE".
Corresponds to the JSON property env
2137 2138 2139 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2137 def env @env end |
#log_streaming_option ⇒ String
Option to define build log streaming behavior to Cloud Storage.
Corresponds to the JSON property logStreamingOption
2142 2143 2144 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2142 def log_streaming_option @log_streaming_option end |
#logging ⇒ String
Option to specify the logging mode, which determines if and where build logs
are stored.
Corresponds to the JSON property logging
2148 2149 2150 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2148 def logging @logging end |
#machine_type ⇒ String
Compute Engine machine type on which to run the build.
Corresponds to the JSON property machineType
2153 2154 2155 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2153 def machine_type @machine_type end |
#pool ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOption
Details about how a build should be executed on a WorkerPool. See running
builds in a private pool for more information.
Corresponds to the JSON property pool
2160 2161 2162 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2160 def pool @pool end |
#pubsub_topic ⇒ String
Optional. Option to specify the Pub/Sub topic to receive build status updates.
Corresponds to the JSON property pubsubTopic
2165 2166 2167 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2165 def pubsub_topic @pubsub_topic end |
#requested_verify_option ⇒ String
Requested verifiability options.
Corresponds to the JSON property requestedVerifyOption
2170 2171 2172 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2170 def requested_verify_option @requested_verify_option end |
#secret_env ⇒ Array<String>
A list of global environment variables, which are encrypted using a Cloud Key
Management Service crypto key. These values must be specified in the build's
Secret. These variables will be available to all build steps in this build.
Corresponds to the JSON property secretEnv
2177 2178 2179 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2177 def secret_env @secret_env end |
#source_provenance_hash ⇒ Array<String>
Requested hash for SourceProvenance.
Corresponds to the JSON property sourceProvenanceHash
2182 2183 2184 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2182 def source_provenance_hash @source_provenance_hash end |
#substitution_option ⇒ String
Option to specify behavior when there is an error in the substitution checks.
NOTE: this is always set to ALLOW_LOOSE for triggered builds and cannot be
overridden in the build configuration file.
Corresponds to the JSON property substitutionOption
2189 2190 2191 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2189 def substitution_option @substitution_option end |
#volumes ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>
Global list of volumes to mount for ALL build steps Each volume is created as
an empty volume prior to starting the build process. Upon completion of the
build, volumes and their contents are discarded. Global volume names and paths
cannot conflict with the volumes defined a build step. Using a global volume
in a build with only one step is not valid as it is indicative of a build
request with an incorrect configuration.
Corresponds to the JSON property volumes
2199 2200 2201 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2199 def volumes @volumes end |
#worker_pool ⇒ String
This field deprecated; please use pool.name instead.
Corresponds to the JSON property workerPool
2204 2205 2206 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2204 def worker_pool @worker_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2211 def update!(**args) @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions) @default_logs_bucket_behavior = args[:default_logs_bucket_behavior] if args.key?(:default_logs_bucket_behavior) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @dynamic_substitutions = args[:dynamic_substitutions] if args.key?(:dynamic_substitutions) @enable_structured_logging = args[:enable_structured_logging] if args.key?(:enable_structured_logging) @env = args[:env] if args.key?(:env) @log_streaming_option = args[:log_streaming_option] if args.key?(:log_streaming_option) @logging = args[:logging] if args.key?(:logging) @machine_type = args[:machine_type] if args.key?(:machine_type) @pool = args[:pool] if args.key?(:pool) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @requested_verify_option = args[:requested_verify_option] if args.key?(:requested_verify_option) @secret_env = args[:secret_env] if args.key?(:secret_env) @source_provenance_hash = args[:source_provenance_hash] if args.key?(:source_provenance_hash) @substitution_option = args[:substitution_option] if args.key?(:substitution_option) @volumes = args[:volumes] if args.key?(:volumes) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) end |