Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency.



2649
2650
2651
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2618
2619
2620
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2618

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2623
2624
2625
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2623

def dest_path
  @dest_path
end

#fetch_tagsBoolean Also known as: fetch_tags?

Optional. True if remote tags should be fetched too (default false). Note: when depth is 1 (default), git fetch only retrieves tags pointing to commits within the shallow boundary. Set depth to -1 to fetch all historical tags. Corresponds to the JSON property fetchTags

Returns:

  • (Boolean)


2630
2631
2632
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2630

def fetch_tags
  @fetch_tags
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2636
2637
2638
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2636

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2642
2643
2644
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2642

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2647
2648
2649
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2647

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2654
2655
2656
2657
2658
2659
2660
2661
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2654

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @fetch_tags = args[:fetch_tags] if args.key?(:fetch_tags)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end