Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

This config defines the location of a source through Developer Connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig.



2459
2460
2461
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Required. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


2445
2446
2447
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2445

def dir
  @dir
end

Required. The Developer Connect Git repository link, formatted as projects/*/ locations/*/connections/*/gitRepositoryLink/*. Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


2451
2452
2453
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2451

def git_repository_link
  @git_repository_link
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


2457
2458
2459
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2457

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2464
2465
2466
2467
2468
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2464

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @revision = args[:revision] if args.key?(:revision)
end