Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes.



2724
2725
2726
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Hash>

Collection of file hashes. Corresponds to the JSON property fileHash



2722
2723
2724
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2722

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2729
2730
2731
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2729

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end