Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Location of the source in a supported storage service.
Instance Attribute Summary collapse
-
#connected_repository ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
-
#developer_connect_config ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
This config defines the location of a source through Developer Connect.
-
#git_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
-
#repo_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
-
#storage_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
-
#storage_source_manifest ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Source
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Source
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Source.
3149 3150 3151 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connected_repository ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Corresponds to the JSON property connectedRepository
3120 3121 3122 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3120 def connected_repository @connected_repository end |
#developer_connect_config ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
This config defines the location of a source through Developer Connect.
Corresponds to the JSON property developerConnectConfig
3125 3126 3127 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3125 def developer_connect_config @developer_connect_config end |
#git_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
Corresponds to the JSON property gitSource
3130 3131 3132 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3130 def git_source @git_source end |
#repo_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
Corresponds to the JSON property repoSource
3135 3136 3137 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3135 def repo_source @repo_source end |
#storage_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
Corresponds to the JSON property storageSource
3140 3141 3142 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3140 def storage_source @storage_source end |
#storage_source_manifest ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage. This feature is in Preview;
see description here.
Corresponds to the JSON property storageSourceManifest
3147 3148 3149 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3147 def storage_source_manifest @storage_source_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3154 3155 3156 3157 3158 3159 3160 3161 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3154 def update!(**args) @connected_repository = args[:connected_repository] if args.key?(:connected_repository) @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config) @git_source = args[:git_source] if args.key?(:git_source) @repo_source = args[:repo_source] if args.key?(:repo_source) @storage_source = args[:storage_source] if args.key?(:storage_source) @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest) end |