Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Location of the source in an archive file in Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource.



3274
3275
3276
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

Cloud Storage bucket containing the source (see Bucket Name Requirements). Corresponds to the JSON property bucket

Returns:

  • (String)


3255
3256
3257
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3255

def bucket
  @bucket
end

#generationFixnum

Optional. Cloud Storage generation for the object. If the generation is omitted, the latest generation will be used. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


3261
3262
3263
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3261

def generation
  @generation
end

#objectString

Required. Cloud Storage object containing the source. This object must be a zipped (.zip) or gzipped archive file (.tar.gz) containing source to build. Corresponds to the JSON property object

Returns:

  • (String)


3267
3268
3269
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3267

def object
  @object
end

#source_fetcherString

Optional. Option to specify the tool to fetch the source file for the build. Corresponds to the JSON property sourceFetcher

Returns:

  • (String)


3272
3273
3274
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3272

def source_fetcher
  @source_fetcher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3279
3280
3281
3282
3283
3284
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3279

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @generation = args[:generation] if args.key?(:generation)
  @object = args[:object] if args.key?(:object)
  @source_fetcher = args[:source_fetcher] if args.key?(:source_fetcher)
end