Class: Google::Apis::ContaineranalysisV1alpha1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Deployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The period during which some deployable was active in a runtime.
Instance Attribute Summary collapse
-
#address ⇒ String
Address of the runtime element hosting this deployment.
-
#config ⇒ String
Configuration used to create this deployment.
-
#deploy_time ⇒ String
Beginning of the lifetime of this deployment.
-
#platform ⇒ String
Platform hosting this deployment.
-
#resource_uri ⇒ Array<String>
Resource URI for the artifact being deployed taken from the deployable field with the same name.
-
#undeploy_time ⇒ String
End of the lifetime of this deployment.
-
#user_email ⇒ String
Identity of the user that triggered this deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
3761 3762 3763 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address of the runtime element hosting this deployment.
Corresponds to the JSON property address
3728 3729 3730 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3728 def address @address end |
#config ⇒ String
Configuration used to create this deployment.
Corresponds to the JSON property config
3733 3734 3735 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3733 def config @config end |
#deploy_time ⇒ String
Beginning of the lifetime of this deployment.
Corresponds to the JSON property deployTime
3738 3739 3740 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3738 def deploy_time @deploy_time end |
#platform ⇒ String
Platform hosting this deployment.
Corresponds to the JSON property platform
3743 3744 3745 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3743 def platform @platform end |
#resource_uri ⇒ Array<String>
Resource URI for the artifact being deployed taken from the deployable field
with the same name.
Corresponds to the JSON property resourceUri
3749 3750 3751 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3749 def resource_uri @resource_uri end |
#undeploy_time ⇒ String
End of the lifetime of this deployment.
Corresponds to the JSON property undeployTime
3754 3755 3756 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3754 def undeploy_time @undeploy_time end |
#user_email ⇒ String
Identity of the user that triggered this deployment.
Corresponds to the JSON property userEmail
3759 3760 3761 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3759 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3766 3767 3768 3769 3770 3771 3772 3773 3774 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3766 def update!(**args) @address = args[:address] if args.key?(:address) @config = args[:config] if args.key?(:config) @deploy_time = args[:deploy_time] if args.key?(:deploy_time) @platform = args[:platform] if args.key?(:platform) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time) @user_email = args[:user_email] if args.key?(:user_email) end |