Class: Google::Apis::ContaineranalysisV1alpha1::Discovered
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Discovered
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Provides information about the scan status of a discovered resource.
Instance Attribute Summary collapse
-
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1alpha1::AnalysisCompleted
Indicates which analysis completed successfully.
-
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Status>
Indicates any errors encountered during analysis of a resource.
-
#analysis_status ⇒ String
The status of discovery for the resource.
-
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1alpha1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#archive_time ⇒ String
The time occurrences related to this discovery occurrence were archived.
-
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
-
#cpe ⇒ String
The CPE of the resource being scanned.
-
#files ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::File>
Optional.
-
#last_scan_time ⇒ String
The last time this resource was scanned.
-
#last_vulnerability_update_time ⇒ String
Optional.
-
#operation ⇒ Google::Apis::ContaineranalysisV1alpha1::Operation
This resource represents a long-running operation that is the result of a network API call.
-
#sbom_status ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomStatus
The status of an SBOM generation.
-
#vulnerability_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation
The status of a vulnerability attestation generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Discovered
constructor
A new instance of Discovered.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Discovered
Returns a new instance of Discovered.
4014 4015 4016 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1alpha1::AnalysisCompleted
Indicates which analysis completed successfully. Multiple types of analysis
can be performed on a single resource.
Corresponds to the JSON property analysisCompleted
3945 3946 3947 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3945 def analysis_completed @analysis_completed end |
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Status>
Indicates any errors encountered during analysis of a resource. There could be
0 or more of these errors.
Corresponds to the JSON property analysisError
3951 3952 3953 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3951 def analysis_error @analysis_error end |
#analysis_status ⇒ String
The status of discovery for the resource.
Corresponds to the JSON property analysisStatus
3956 3957 3958 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3956 def analysis_status @analysis_status end |
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1alpha1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property analysisStatusError
3966 3967 3968 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3966 def analysis_status_error @analysis_status_error end |
#archive_time ⇒ String
The time occurrences related to this discovery occurrence were archived.
Corresponds to the JSON property archiveTime
3971 3972 3973 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3971 def archive_time @archive_time end |
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
Corresponds to the JSON property continuousAnalysis
3976 3977 3978 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3976 def continuous_analysis @continuous_analysis end |
#cpe ⇒ String
The CPE of the resource being scanned.
Corresponds to the JSON property cpe
3981 3982 3983 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3981 def cpe @cpe end |
#files ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::File>
Optional. Files that make up the resource described by the occurrence.
Corresponds to the JSON property files
3986 3987 3988 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3986 def files @files end |
#last_scan_time ⇒ String
The last time this resource was scanned.
Corresponds to the JSON property lastScanTime
3991 3992 3993 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3991 def last_scan_time @last_scan_time end |
#last_vulnerability_update_time ⇒ String
Optional. The last time vulnerability scan results changed.
Corresponds to the JSON property lastVulnerabilityUpdateTime
3996 3997 3998 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3996 def last_vulnerability_update_time @last_vulnerability_update_time end |
#operation ⇒ Google::Apis::ContaineranalysisV1alpha1::Operation
This resource represents a long-running operation that is the result of a
network API call.
Corresponds to the JSON property operation
4002 4003 4004 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4002 def operation @operation end |
#sbom_status ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomStatus
The status of an SBOM generation.
Corresponds to the JSON property sbomStatus
4007 4008 4009 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4007 def sbom_status @sbom_status end |
#vulnerability_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation
The status of a vulnerability attestation generation.
Corresponds to the JSON property vulnerabilityAttestation
4012 4013 4014 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4012 def vulnerability_attestation @vulnerability_attestation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4019 def update!(**args) @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed) @analysis_error = args[:analysis_error] if args.key?(:analysis_error) @analysis_status = args[:analysis_status] if args.key?(:analysis_status) @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error) @archive_time = args[:archive_time] if args.key?(:archive_time) @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis) @cpe = args[:cpe] if args.key?(:cpe) @files = args[:files] if args.key?(:files) @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time) @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time) @operation = args[:operation] if args.key?(:operation) @sbom_status = args[:sbom_status] if args.key?(:sbom_status) @vulnerability_attestation = args[:vulnerability_attestation] if args.key?(:vulnerability_attestation) end |