Class: Google::Apis::ContaineranalysisV1alpha1::Distribution

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

This represents a particular channel of distribution for a given package. e.g. Debian's jessie-backports dpkg mirror

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Distribution

Returns a new instance of Distribution.



4090
4091
4092
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The CPU architecture for which packages in this distribution channel were built Corresponds to the JSON property architecture

Returns:

  • (String)


4059
4060
4061
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4059

def architecture
  @architecture
end

#cpe_uriString

The cpe_uri in cpe format denoting the package manager version distributing a package. Corresponds to the JSON property cpeUri

Returns:

  • (String)


4065
4066
4067
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4065

def cpe_uri
  @cpe_uri
end

#descriptionString

The distribution channel-specific description of this package. Corresponds to the JSON property description

Returns:

  • (String)


4070
4071
4072
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4070

def description
  @description
end

#latest_versionGoogle::Apis::ContaineranalysisV1alpha1::Version

Version contains structured information about the version of the package. For a discussion of this in Debian/Ubuntu: http://serverfault.com/questions/604541/ debian-packages-version-convention For a discussion of this in Redhat/Fedora/ Centos: http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/ Corresponds to the JSON property latestVersion



4078
4079
4080
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4078

def latest_version
  @latest_version
end

#maintainerString

A freeform string denoting the maintainer of this package. Corresponds to the JSON property maintainer

Returns:

  • (String)


4083
4084
4085
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4083

def maintainer
  @maintainer
end

#urlString

The distribution channel-specific homepage for this package. Corresponds to the JSON property url

Returns:

  • (String)


4088
4089
4090
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4088

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4095
4096
4097
4098
4099
4100
4101
4102
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4095

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @latest_version = args[:latest_version] if args.key?(:latest_version)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @url = args[:url] if args.key?(:url)
end