Class: Google::Apis::ContaineranalysisV1alpha1::DocumentOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DocumentOccurrence

Returns a new instance of DocumentOccurrence.



4202
4203
4204
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Identify when the SPDX file was originally created. The date is to be specified according to combined date and time in UTC format as specified in ISO 8601 standard Corresponds to the JSON property createTime

Returns:

  • (String)


4152
4153
4154
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4152

def create_time
  @create_time
end

#creator_commentString

A field for creators of the SPDX file to provide general comments about the creation of the SPDX file or any other relevant comment not included in the other fields Corresponds to the JSON property creatorComment

Returns:

  • (String)


4159
4160
4161
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4159

def creator_comment
  @creator_comment
end

#creatorsArray<String>

Identify who (or what, in the case of a tool) created the SPDX file. If the SPDX file was created by an individual, indicate the person's name Corresponds to the JSON property creators

Returns:

  • (Array<String>)


4165
4166
4167
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4165

def creators
  @creators
end

#document_commentString

A field for creators of the SPDX file content to provide comments to the consumers of the SPDX document Corresponds to the JSON property documentComment

Returns:

  • (String)


4171
4172
4173
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4171

def document_comment
  @document_comment
end

#external_document_refsArray<String>

Identify any external SPDX documents referenced within this SPDX document Corresponds to the JSON property externalDocumentRefs

Returns:

  • (Array<String>)


4176
4177
4178
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4176

def external_document_refs
  @external_document_refs
end

#idString

Identify the current SPDX document which may be referenced in relationships by other files, packages internally and documents externally Corresponds to the JSON property id

Returns:

  • (String)


4182
4183
4184
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4182

def id
  @id
end

#license_list_versionString

A field for creators of the SPDX file to provide the version of the SPDX License List used when the SPDX file was created Corresponds to the JSON property licenseListVersion

Returns:

  • (String)


4188
4189
4190
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4188

def license_list_version
  @license_list_version
end

#namespaceString

Provide an SPDX document specific namespace as a unique absolute Uniform Resource Identifier (URI) as specified in RFC-3986, with the exception of the ‘

’ delimiter

Corresponds to the JSON property namespace

Returns:

  • (String)


4195
4196
4197
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4195

def namespace
  @namespace
end

#titleString

Identify name of this document as designated by creator Corresponds to the JSON property title

Returns:

  • (String)


4200
4201
4202
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4200

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4207

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator_comment = args[:creator_comment] if args.key?(:creator_comment)
  @creators = args[:creators] if args.key?(:creators)
  @document_comment = args[:document_comment] if args.key?(:document_comment)
  @external_document_refs = args[:external_document_refs] if args.key?(:external_document_refs)
  @id = args[:id] if args.key?(:id)
  @license_list_version = args[:license_list_version] if args.key?(:license_list_version)
  @namespace = args[:namespace] if args.key?(:namespace)
  @title = args[:title] if args.key?(:title)
end