Class: Google::Apis::ContaineranalysisV1alpha1::Envelope

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Envelope

Returns a new instance of Envelope.



3903
3904
3905
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#payloadString

The bytes being signed Corresponds to the JSON property payload NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3891
3892
3893
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3891

def payload
  @payload
end

#payload_typeString

The type of payload being signed Corresponds to the JSON property payloadType

Returns:

  • (String)


3896
3897
3898
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3896

def payload_type
  @payload_type
end

#signaturesArray<Google::Apis::ContaineranalysisV1alpha1::EnvelopeSignature>

The signatures over the payload Corresponds to the JSON property signatures



3901
3902
3903
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3901

def signatures
  @signatures
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3908
3909
3910
3911
3912
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3908

def update!(**args)
  @payload = args[:payload] if args.key?(:payload)
  @payload_type = args[:payload_type] if args.key?(:payload_type)
  @signatures = args[:signatures] if args.key?(:signatures)
end