Class: Google::Apis::ContaineranalysisV1alpha1::ExploitPredictionScoringSystem

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

ExploitPredictionScoringSystem provides information about the Exploit Prediction Scoring System (EPSS) score and percentile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExploitPredictionScoringSystem

Returns a new instance of ExploitPredictionScoringSystem.



3958
3959
3960
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentileFloat

Optional. The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score Corresponds to the JSON property percentile

Returns:

  • (Float)


3950
3951
3952
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3950

def percentile
  @percentile
end

#scoreFloat

Optional. The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days Corresponds to the JSON property score

Returns:

  • (Float)


3956
3957
3958
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3956

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3963
3964
3965
3966
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3963

def update!(**args)
  @percentile = args[:percentile] if args.key?(:percentile)
  @score = args[:score] if args.key?(:score)
end