Class: Google::Apis::ContaineranalysisV1alpha1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Container message for hashes of byte content of files, used in Source messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



4454
4455
4456
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::ContaineranalysisV1alpha1::HashProp>

Collection of file hashes. Corresponds to the JSON property fileHash



4452
4453
4454
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4452

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4459
4460
4461
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4459

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end