Class: Google::Apis::ContaineranalysisV1alpha1::FileNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::FileNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
FileNote represents an SPDX File Information section: https://spdx.github.io/ spdx-spec/4-file-information/
Instance Attribute Summary collapse
-
#checksum ⇒ Array<String>
Provide a unique identifier to match analysis information on each specific file in a package Corresponds to the JSON property
checksum. -
#file_type ⇒ String
This field provides information about the type of file identified Corresponds to the JSON property
fileType. -
#title ⇒ String
Identify the full path and filename that corresponds to the file information in this section Corresponds to the JSON property
title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileNote
constructor
A new instance of FileNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileNote
Returns a new instance of FileNote.
4498 4499 4500 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checksum ⇒ Array<String>
Provide a unique identifier to match analysis information on each specific
file in a package
Corresponds to the JSON property checksum
4485 4486 4487 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4485 def checksum @checksum end |
#file_type ⇒ String
This field provides information about the type of file identified
Corresponds to the JSON property fileType
4490 4491 4492 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4490 def file_type @file_type end |
#title ⇒ String
Identify the full path and filename that corresponds to the file information
in this section
Corresponds to the JSON property title
4496 4497 4498 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4496 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4503 4504 4505 4506 4507 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4503 def update!(**args) @checksum = args[:checksum] if args.key?(:checksum) @file_type = args[:file_type] if args.key?(:file_type) @title = args[:title] if args.key?(:title) end |