Class: Google::Apis::ContaineranalysisV1alpha1::FileOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::FileOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
FileOccurrence represents an SPDX File Information section: https://spdx. github.io/spdx-spec/4-file-information/
Instance Attribute Summary collapse
-
#attributions ⇒ Array<String>
This field provides a place for the SPDX data creator to record, at the file level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property
attributions. -
#comment ⇒ String
This field provides a place for the SPDX file creator to record any general comments about the file Corresponds to the JSON property
comment. -
#contributors ⇒ Array<String>
This field provides a place for the SPDX file creator to record file contributors Corresponds to the JSON property
contributors. -
#copyright ⇒ String
Identify the copyright holder of the file, as well as any dates present Corresponds to the JSON property
copyright. -
#files_license_info ⇒ Array<String>
This field contains the license information actually found in the file, if any Corresponds to the JSON property
filesLicenseInfo. -
#id ⇒ String
Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property
id. -
#license_concluded ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
-
#notice ⇒ String
This field provides a place for the SPDX file creator to record license notices or other such related notices found in the file Corresponds to the JSON property
notice.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileOccurrence
constructor
A new instance of FileOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileOccurrence
Returns a new instance of FileOccurrence.
4581 4582 4583 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4581 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributions ⇒ Array<String>
This field provides a place for the SPDX data creator to record, at the file
level, acknowledgements that may be needed to be communicated in some contexts
Corresponds to the JSON property attributions
4540 4541 4542 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4540 def attributions @attributions end |
#comment ⇒ String
This field provides a place for the SPDX file creator to record any general
comments about the file
Corresponds to the JSON property comment
4546 4547 4548 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4546 def comment @comment end |
#contributors ⇒ Array<String>
This field provides a place for the SPDX file creator to record file
contributors
Corresponds to the JSON property contributors
4552 4553 4554 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4552 def contributors @contributors end |
#copyright ⇒ String
Identify the copyright holder of the file, as well as any dates present
Corresponds to the JSON property copyright
4557 4558 4559 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4557 def copyright @copyright end |
#files_license_info ⇒ Array<String>
This field contains the license information actually found in the file, if any
Corresponds to the JSON property filesLicenseInfo
4562 4563 4564 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4562 def files_license_info @files_license_info end |
#id ⇒ String
Uniquely identify any element in an SPDX document which may be referenced by
other elements
Corresponds to the JSON property id
4568 4569 4570 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4568 def id @id end |
#license_concluded ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
Corresponds to the JSON property licenseConcluded
4573 4574 4575 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4573 def license_concluded @license_concluded end |
#notice ⇒ String
This field provides a place for the SPDX file creator to record license
notices or other such related notices found in the file
Corresponds to the JSON property notice
4579 4580 4581 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4579 def notice @notice end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4586 def update!(**args) @attributions = args[:attributions] if args.key?(:attributions) @comment = args[:comment] if args.key?(:comment) @contributors = args[:contributors] if args.key?(:contributors) @copyright = args[:copyright] if args.key?(:copyright) @files_license_info = args[:files_license_info] if args.key?(:files_license_info) @id = args[:id] if args.key?(:id) @license_concluded = args[:license_concluded] if args.key?(:license_concluded) @notice = args[:notice] if args.key?(:notice) end |