Class: Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder.



4963
4964
4965
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

URI indicating the builder’s identity. Corresponds to the JSON property id

Returns:

  • (String)


4961
4962
4963
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4961

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4968
4969
4970
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4968

def update!(**args)
  @id = args[:id] if args.key?(:id)
end