Class: Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMaterial

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMaterial

Returns a new instance of GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMaterial.



5078
5079
5080
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

Collection of cryptographic digests for the contents of this artifact. Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


5071
5072
5073
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5071

def digest
  @digest
end

#uriString

The method by which this artifact was referenced during the build. Corresponds to the JSON property uri

Returns:

  • (String)


5076
5077
5078
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5076

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5083
5084
5085
5086
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5083

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @uri = args[:uri] if args.key?(:uri)
end