Class: Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Other properties of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMetadata

Returns a new instance of GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMetadata.



5122
5123
5124
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_finished_onString

The timestamp of when the build completed. Corresponds to the JSON property buildFinishedOn

Returns:

  • (String)


5096
5097
5098
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5096

def build_finished_on
  @build_finished_on
end

#build_invocation_idString

Identifies this particular build invocation, which can be useful for finding associated logs or other ad-hoc analysis. Corresponds to the JSON property buildInvocationId

Returns:

  • (String)


5102
5103
5104
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5102

def build_invocation_id
  @build_invocation_id
end

#build_started_onString

The timestamp of when the build started. Corresponds to the JSON property buildStartedOn

Returns:

  • (String)


5107
5108
5109
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5107

def build_started_on
  @build_started_on
end

#completenessGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaCompleteness

Indicates that the builder claims certain fields in this message to be complete. Corresponds to the JSON property completeness



5113
5114
5115
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5113

def completeness
  @completeness
end

#reproducibleBoolean Also known as: reproducible?

If true, the builder claims that running invocation on materials will produce bit-for-bit identical output. Corresponds to the JSON property reproducible

Returns:

  • (Boolean)


5119
5120
5121
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5119

def reproducible
  @reproducible
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5127
5128
5129
5130
5131
5132
5133
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5127

def update!(**args)
  @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on)
  @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id)
  @build_started_on = args[:build_started_on] if args.key?(:build_started_on)
  @completeness = args[:completeness] if args.key?(:completeness)
  @reproducible = args[:reproducible] if args.key?(:reproducible)
end