Class: Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SourceContext

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsContaineranalysisV1alpha1SourceContext

Returns a new instance of GoogleDevtoolsContaineranalysisV1alpha1SourceContext.



5107
5108
5109
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_repoGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1CloudRepoSourceContext

A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo. Corresponds to the JSON property cloudRepo



5089
5090
5091
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5089

def cloud_repo
  @cloud_repo
end

#gerritGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1GerritSourceContext

A SourceContext referring to a Gerrit project. Corresponds to the JSON property gerrit



5094
5095
5096
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5094

def gerrit
  @gerrit
end

#gitGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1GitSourceContext

A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub). Corresponds to the JSON property git



5100
5101
5102
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5100

def git
  @git
end

#labelsHash<String,String>

Labels with user defined metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5105
5106
5107
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5105

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5112
5113
5114
5115
5116
5117
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5112

def update!(**args)
  @cloud_repo = args[:cloud_repo] if args.key?(:cloud_repo)
  @gerrit = args[:gerrit] if args.key?(:gerrit)
  @git = args[:git] if args.key?(:git)
  @labels = args[:labels] if args.key?(:labels)
end