Class: Google::Apis::ContaineranalysisV1alpha1::IdentifierHelper

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Helps in identifying the underlying product. This should be treated like a one- of field. Only one field should be set in this proto. This is a workaround because spanner indexes on one-of fields restrict addition and deletion of fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentifierHelper

Returns a new instance of IdentifierHelper.



5164
5165
5166
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldString

The field that is set in the API proto. Corresponds to the JSON property field

Returns:

  • (String)


5156
5157
5158
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5156

def field
  @field
end

#generic_uriString

Contains a URI which is vendor-specific. Example: The artifact repository URL of an image. Corresponds to the JSON property genericUri

Returns:

  • (String)


5162
5163
5164
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5162

def generic_uri
  @generic_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5169
5170
5171
5172
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5169

def update!(**args)
  @field = args[:field] if args.key?(:field)
  @generic_uri = args[:generic_uri] if args.key?(:generic_uri)
end