Class: Google::Apis::ContaineranalysisV1alpha1::InTotoStatement

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Spec defined at https://github.com/in-toto/attestation/tree/main/spec# statement The serialized InTotoStatement will be stored as Envelope.payload. Envelope.payloadType is always "application/vnd.in-toto+json".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoStatement

Returns a new instance of InTotoStatement.



5349
5350
5351
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#_typeString

Always "https://in-toto.io/Statement/v0.1". Corresponds to the JSON property _type

Returns:

  • (String)


5321
5322
5323
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5321

def _type
  @_type
end

#predicate_typeString

"https://slsa.dev/provenance/v0.1" for SlsaProvenance. Corresponds to the JSON property predicateType

Returns:

  • (String)


5326
5327
5328
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5326

def predicate_type
  @predicate_type
end

#provenanceGoogle::Apis::ContaineranalysisV1alpha1::InTotoProvenance

Generic Grafeas provenance. Corresponds to the JSON property provenance



5331
5332
5333
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5331

def provenance
  @provenance
end

#slsa_provenanceGoogle::Apis::ContaineranalysisV1alpha1::SlsaProvenance

SlsaProvenance is the slsa provenance as defined by the slsa spec. Corresponds to the JSON property slsaProvenance



5336
5337
5338
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5336

def slsa_provenance
  @slsa_provenance
end

#slsa_provenance_zero_twoGoogle::Apis::ContaineranalysisV1alpha1::SlsaProvenanceZeroTwo

SlsaProvenanceZeroTwo is the slsa provenance as defined by the slsa spec. See full explanation of fields at slsa.dev/provenance/v0.2. Corresponds to the JSON property slsaProvenanceZeroTwo



5342
5343
5344
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5342

def slsa_provenance_zero_two
  @slsa_provenance_zero_two
end

#subjectArray<Google::Apis::ContaineranalysisV1alpha1::Subject>

subject is the subjects of the intoto statement Corresponds to the JSON property subject



5347
5348
5349
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5347

def subject
  @subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5354
5355
5356
5357
5358
5359
5360
5361
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5354

def update!(**args)
  @_type = args[:_type] if args.key?(:_type)
  @predicate_type = args[:predicate_type] if args.key?(:predicate_type)
  @provenance = args[:provenance] if args.key?(:provenance)
  @slsa_provenance = args[:slsa_provenance] if args.key?(:slsa_provenance)
  @slsa_provenance_zero_two = args[:slsa_provenance_zero_two] if args.key?(:slsa_provenance_zero_two)
  @subject = args[:subject] if args.key?(:subject)
end