Class: Google::Apis::ContaineranalysisV1alpha1::Layer
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Layer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Layer holds metadata specific to a layer of a Docker image.
Instance Attribute Summary collapse
-
#arguments ⇒ String
The recovered arguments to the Dockerfile directive.
-
#directive ⇒ String
The recovered Dockerfile directive used to construct this layer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Layer
constructor
A new instance of Layer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Layer
Returns a new instance of Layer.
5479 5480 5481 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ String
The recovered arguments to the Dockerfile directive.
Corresponds to the JSON property arguments
5472 5473 5474 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5472 def arguments @arguments end |
#directive ⇒ String
The recovered Dockerfile directive used to construct this layer.
Corresponds to the JSON property directive
5477 5478 5479 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5477 def directive @directive end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5484 5485 5486 5487 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5484 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @directive = args[:directive] if args.key?(:directive) end |