Class: Google::Apis::ContaineranalysisV1alpha1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



5535
5536
5537
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::ContaineranalysisV1alpha1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



5512
5513
5514
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5512

def base_images
  @base_images
end

#chain_idString

The chain ID of the layer in the container image. Corresponds to the JSON property chainId

Returns:

  • (String)


5517
5518
5519
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5517

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


5523
5524
5525
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5523

def command
  @command
end

#diff_idString

The diff ID (sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


5528
5529
5530
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5528

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


5533
5534
5535
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5533

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5540
5541
5542
5543
5544
5545
5546
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5540

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end