Class: Google::Apis::ContaineranalysisV1alpha1::Package
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Package
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
This represents a particular package that is distributed over various channels. e.g. glibc (aka libc6) is distributed by many, at various versions.
Instance Attribute Summary collapse
-
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were built.
-
#cpe_uri ⇒ String
The cpe_uri in CPE format denoting the package manager version distributing a package.
-
#description ⇒ String
The description of this package.
-
#digest ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Digest>
Hash value, typically a file digest, that allows unique identification a specific package.
-
#distribution ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Distribution>
The various channels by which a package is distributed.
-
#license ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
-
#maintainer ⇒ String
A freeform text denoting the maintainer of this package.
-
#name ⇒ String
The name of the package.
-
#package_type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).
-
#url ⇒ String
The homepage for this package.
-
#version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Package
constructor
A new instance of Package.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Package
Returns a new instance of Package.
6322 6323 6324 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were
built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
6263 6264 6265 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6263 def architecture @architecture end |
#cpe_uri ⇒ String
The cpe_uri in CPE format denoting the
package manager version distributing a package. The cpe_uri will be blank for
language packages.
Corresponds to the JSON property cpeUri
6270 6271 6272 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6270 def cpe_uri @cpe_uri end |
#description ⇒ String
The description of this package.
Corresponds to the JSON property description
6275 6276 6277 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6275 def description @description end |
#digest ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Digest>
Hash value, typically a file digest, that allows unique identification a
specific package.
Corresponds to the JSON property digest
6281 6282 6283 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6281 def digest @digest end |
#distribution ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Distribution>
The various channels by which a package is distributed.
Corresponds to the JSON property distribution
6286 6287 6288 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6286 def distribution @distribution end |
#license ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
Corresponds to the JSON property license
6291 6292 6293 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6291 def license @license end |
#maintainer ⇒ String
A freeform text denoting the maintainer of this package.
Corresponds to the JSON property maintainer
6296 6297 6298 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6296 def maintainer @maintainer end |
#name ⇒ String
The name of the package.
Corresponds to the JSON property name
6301 6302 6303 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6301 def name @name end |
#package_type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js
packages, etc.).
Corresponds to the JSON property packageType
6307 6308 6309 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6307 def package_type @package_type end |
#url ⇒ String
The homepage for this package.
Corresponds to the JSON property url
6312 6313 6314 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6312 def url @url end |
#version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package. For
a discussion of this in Debian/Ubuntu: http://serverfault.com/questions/604541/
debian-packages-version-convention For a discussion of this in Redhat/Fedora/
Centos: http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/
Corresponds to the JSON property version
6320 6321 6322 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6320 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6327 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @description = args[:description] if args.key?(:description) @digest = args[:digest] if args.key?(:digest) @distribution = args[:distribution] if args.key?(:distribution) @license = args[:license] if args.key?(:license) @maintainer = args[:maintainer] if args.key?(:maintainer) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @url = args[:url] if args.key?(:url) @version = args[:version] if args.key?(:version) end |