Class: Google::Apis::ContaineranalysisV1alpha1::PackageInfoOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

PackageInfoOccurrence represents an SPDX Package Information section: https:// spdx.github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoOccurrence

Returns a new instance of PackageInfoOccurrence.



6623
6624
6625
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

A place for the SPDX file creator to record any general comments about the package being described Corresponds to the JSON property comment

Returns:

  • (String)


6571
6572
6573
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6571

def comment
  @comment
end

#filenameString

Provide the actual file name of the package, or path of the directory being treated as a package Corresponds to the JSON property filename

Returns:

  • (String)


6577
6578
6579
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6577

def filename
  @filename
end

#home_pageString

Output only. Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6583
6584
6585
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6583

def home_page
  @home_page
end

#idString

Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property id

Returns:

  • (String)


6589
6590
6591
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6589

def id
  @id
end

#license_concludedGoogle::Apis::ContaineranalysisV1alpha1::License

License information. Corresponds to the JSON property licenseConcluded



6594
6595
6596
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6594

def license_concluded
  @license_concluded
end

#package_typeString

Output only. The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6599
6600
6601
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6599

def package_type
  @package_type
end

#source_infoString

Provide a place for the SPDX file creator to record any relevant background information or additional comments about the origin of the package Corresponds to the JSON property sourceInfo

Returns:

  • (String)


6605
6606
6607
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6605

def source_info
  @source_info
end

#summary_descriptionString

Output only. A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6610
6611
6612
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6610

def summary_description
  @summary_description
end

#titleString

Output only. Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6616
6617
6618
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6616

def title
  @title
end

#versionString

Output only. Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6621
6622
6623
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6621

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
6639
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6628

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @filename = args[:filename] if args.key?(:filename)
  @home_page = args[:home_page] if args.key?(:home_page)
  @id = args[:id] if args.key?(:id)
  @license_concluded = args[:license_concluded] if args.key?(:license_concluded)
  @package_type = args[:package_type] if args.key?(:package_type)
  @source_info = args[:source_info] if args.key?(:source_info)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @title = args[:title] if args.key?(:title)
  @version = args[:version] if args.key?(:version)
end