Class: Google::Apis::ContaineranalysisV1alpha1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

This message wraps a location affected by a vulnerability and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



6684
6685
6686
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property affectedLocation



6659
6660
6661
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6659

def affected_location
  @affected_location
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when distro or language system has not yet assigned a severity for this vulnerability. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


6667
6668
6669
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6667

def effective_severity
  @effective_severity
end

#fixed_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property fixedLocation



6672
6673
6674
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6672

def fixed_location
  @fixed_location
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


6677
6678
6679
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6677

def package_type
  @package_type
end

#severity_nameString

Corresponds to the JSON property severityName

Returns:

  • (String)


6682
6683
6684
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6682

def severity_name
  @severity_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6689
6690
6691
6692
6693
6694
6695
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6689

def update!(**args)
  @affected_location = args[:affected_location] if args.key?(:affected_location)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @fixed_location = args[:fixed_location] if args.key?(:fixed_location)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
end