Class: Google::Apis::ContaineranalysisV1alpha1::Product

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Product contains information about a product and how to uniquely identify it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Product

Returns a new instance of Product.



6358
6359
6360
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Token that identifies a product so that it can be referred to from other parts in the document. There is no predefined format as long as it uniquely identifies a group in the context of the current document. Corresponds to the JSON property id

Returns:

  • (String)


6343
6344
6345
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6343

def id
  @id
end

#identifier_helperGoogle::Apis::ContaineranalysisV1alpha1::IdentifierHelper

Helps in identifying the underlying product. This should be treated like a one- of field. Only one field should be set in this proto. This is a workaround because spanner indexes on one-of fields restrict addition and deletion of fields. Corresponds to the JSON property identifierHelper



6351
6352
6353
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6351

def identifier_helper
  @identifier_helper
end

#nameString

Name of the product. Corresponds to the JSON property name

Returns:

  • (String)


6356
6357
6358
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6356

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6363
6364
6365
6366
6367
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6363

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @identifier_helper = args[:identifier_helper] if args.key?(:identifier_helper)
  @name = args[:name] if args.key?(:name)
end