Class: Google::Apis::ContaineranalysisV1alpha1::Risk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

The Risk message provides information about the risk of a vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Risk

Returns a new instance of Risk.



6762
6763
6764
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cisa_kevGoogle::Apis::ContaineranalysisV1alpha1::CisaKnownExploitedVulnerabilities

CISAKnownExploitedVulnerabilities provides information about whether the vulnerability is known to have been leveraged as part of a ransomware campaign. Corresponds to the JSON property cisaKev



6754
6755
6756
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6754

def cisa_kev
  @cisa_kev
end

#epssGoogle::Apis::ContaineranalysisV1alpha1::ExploitPredictionScoringSystem

ExploitPredictionScoringSystem provides information about the Exploit Prediction Scoring System (EPSS) score and percentile. Corresponds to the JSON property epss



6760
6761
6762
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6760

def epss
  @epss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6767
6768
6769
6770
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6767

def update!(**args)
  @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev)
  @epss = args[:epss] if args.key?(:epss)
end