Class: Google::Apis::ContaineranalysisV1alpha1::SbomReferenceIntotoPayload
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::SbomReferenceIntotoPayload
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The actual payload that contains the SBOM Reference data. The payload follows the intoto statement specification. See https://github.com/in-toto/attestation/ blob/main/spec/v1.0/statement.md for more details.
Instance Attribute Summary collapse
-
#_type ⇒ String
Identifier for the schema of the Statement.
-
#predicate ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomReferenceIntotoPredicate
A predicate which describes the SBOM being referenced.
-
#predicate_type ⇒ String
URI identifying the type of the Predicate.
-
#subject ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Subject>
Set of software artifacts that the attestation applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SbomReferenceIntotoPayload
constructor
A new instance of SbomReferenceIntotoPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SbomReferenceIntotoPayload
Returns a new instance of SbomReferenceIntotoPayload.
7335 7336 7337 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#_type ⇒ String
Identifier for the schema of the Statement.
Corresponds to the JSON property _type
7317 7318 7319 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7317 def _type @_type end |
#predicate ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomReferenceIntotoPredicate
A predicate which describes the SBOM being referenced.
Corresponds to the JSON property predicate
7322 7323 7324 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7322 def predicate @predicate end |
#predicate_type ⇒ String
URI identifying the type of the Predicate.
Corresponds to the JSON property predicateType
7327 7328 7329 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7327 def predicate_type @predicate_type end |
#subject ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Subject>
Set of software artifacts that the attestation applies to. Each element
represents a single software artifact.
Corresponds to the JSON property subject
7333 7334 7335 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7333 def subject @subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7340 7341 7342 7343 7344 7345 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7340 def update!(**args) @_type = args[:_type] if args.key?(:_type) @predicate = args[:predicate] if args.key?(:predicate) @predicate_type = args[:predicate_type] if args.key?(:predicate_type) @subject = args[:subject] if args.key?(:subject) end |