Class: Google::Apis::ContaineranalysisV1alpha1::SbomReferenceIntotoPredicate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A predicate which describes the SBOM being referenced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SbomReferenceIntotoPredicate

Returns a new instance of SbomReferenceIntotoPredicate.



7490
7491
7492
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

A map of algorithm to digest of the contents of the SBOM. Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


7473
7474
7475
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7473

def digest
  @digest
end

#locationString

The location of the SBOM. Corresponds to the JSON property location

Returns:

  • (String)


7478
7479
7480
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7478

def location
  @location
end

#mime_typeString

The mime type of the SBOM. Corresponds to the JSON property mimeType

Returns:

  • (String)


7483
7484
7485
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7483

def mime_type
  @mime_type
end

#referrer_idString

The person or system referring this predicate to the consumer. Corresponds to the JSON property referrerId

Returns:

  • (String)


7488
7489
7490
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7488

def referrer_id
  @referrer_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7495
7496
7497
7498
7499
7500
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7495

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @location = args[:location] if args.key?(:location)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @referrer_id = args[:referrer_id] if args.key?(:referrer_id)
end