Class: Google::Apis::ContaineranalysisV1alpha1::SlsaCompleteness

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Indicates that the builder claims certain fields in this message to be complete.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaCompleteness

Returns a new instance of SlsaCompleteness.



7222
7223
7224
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsBoolean Also known as: arguments?

If true, the builder claims that recipe.arguments is complete, meaning that all external inputs are properly captured in the recipe. Corresponds to the JSON property arguments

Returns:

  • (Boolean)


7206
7207
7208
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7206

def arguments
  @arguments
end

#environmentBoolean Also known as: environment?

If true, the builder claims that recipe.environment is claimed to be complete. Corresponds to the JSON property environment

Returns:

  • (Boolean)


7212
7213
7214
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7212

def environment
  @environment
end

#materialsBoolean Also known as: materials?

If true, the builder claims that materials are complete, usually through some controls to prevent network access. Sometimes called "hermetic". Corresponds to the JSON property materials

Returns:

  • (Boolean)


7219
7220
7221
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7219

def materials
  @materials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7227
7228
7229
7230
7231
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7227

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @environment = args[:environment] if args.key?(:environment)
  @materials = args[:materials] if args.key?(:materials)
end