Class: Google::Apis::ContaineranalysisV1alpha1::Version

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Version contains structured information about the version of the package. For a discussion of this in Debian/Ubuntu: http://serverfault.com/questions/604541/ debian-packages-version-convention For a discussion of this in Redhat/Fedora/ Centos: http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



8451
8452
8453
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


8425
8426
8427
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8425

def epoch
  @epoch
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is vulnerable, when defining the version bounds. For example, if the minimum version is 2.0, inclusive=true would say 2.0 is vulnerable, while inclusive=false would say it's not Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


8432
8433
8434
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8432

def inclusive
  @inclusive
end

#kindString

Distinguish between sentinel MIN/MAX versions and normal versions. If kind is not NORMAL, then the other fields are ignored. Corresponds to the JSON property kind

Returns:

  • (String)


8439
8440
8441
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8439

def kind
  @kind
end

#nameString

The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


8444
8445
8446
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8444

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


8449
8450
8451
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8449

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8456
8457
8458
8459
8460
8461
8462
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8456

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end