Class: Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAssessmentNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAssessmentNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE. Multiple VulnerabilityAssessmentNotes together form a Vex statement. Please go/sds-vex-example for a sample Vex statement in the CSAF format.
Instance Attribute Summary collapse
-
#assessment ⇒ Google::Apis::ContaineranalysisV1alpha1::Assessment
Assessment provides all information that is related to a single vulnerability for this product.
-
#language_code ⇒ String
Identifies the language used by this document, corresponding to IETF BCP 47 / RFC 5646.
-
#long_description ⇒ String
A detailed description of this Vex.
-
#product ⇒ Google::Apis::ContaineranalysisV1alpha1::Product
Product contains information about a product and how to uniquely identify it.
-
#publisher ⇒ Google::Apis::ContaineranalysisV1alpha1::Publisher
Publisher contains information about the publisher of this Note.
-
#short_description ⇒ String
A one sentence description of this Vex.
-
#title ⇒ String
The title of the note.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityAssessmentNote
constructor
A new instance of VulnerabilityAssessmentNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityAssessmentNote
Returns a new instance of VulnerabilityAssessmentNote.
8618 8619 8620 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assessment ⇒ Google::Apis::ContaineranalysisV1alpha1::Assessment
Assessment provides all information that is related to a single vulnerability
for this product.
Corresponds to the JSON property assessment
8585 8586 8587 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8585 def assessment @assessment end |
#language_code ⇒ String
Identifies the language used by this document, corresponding to IETF BCP 47 /
RFC 5646.
Corresponds to the JSON property languageCode
8591 8592 8593 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8591 def language_code @language_code end |
#long_description ⇒ String
A detailed description of this Vex.
Corresponds to the JSON property longDescription
8596 8597 8598 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8596 def long_description @long_description end |
#product ⇒ Google::Apis::ContaineranalysisV1alpha1::Product
Product contains information about a product and how to uniquely identify it.
Corresponds to the JSON property product
8601 8602 8603 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8601 def product @product end |
#publisher ⇒ Google::Apis::ContaineranalysisV1alpha1::Publisher
Publisher contains information about the publisher of this Note.
Corresponds to the JSON property publisher
8606 8607 8608 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8606 def publisher @publisher end |
#short_description ⇒ String
A one sentence description of this Vex.
Corresponds to the JSON property shortDescription
8611 8612 8613 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8611 def short_description @short_description end |
#title ⇒ String
The title of the note. E.g. Vex-Debian-11.4
Corresponds to the JSON property title
8616 8617 8618 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8616 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8623 8624 8625 8626 8627 8628 8629 8630 8631 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8623 def update!(**args) @assessment = args[:assessment] if args.key?(:assessment) @language_code = args[:language_code] if args.key?(:language_code) @long_description = args[:long_description] if args.key?(:long_description) @product = args[:product] if args.key?(:product) @publisher = args[:publisher] if args.key?(:publisher) @short_description = args[:short_description] if args.key?(:short_description) @title = args[:title] if args.key?(:title) end |