Class: Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

The status of a vulnerability attestation generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityAttestation

Returns a new instance of VulnerabilityAttestation.



8645
8646
8647
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorString

Output only. If failure, the error reason for why the attestation generation failed. Corresponds to the JSON property error

Returns:

  • (String)


8633
8634
8635
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8633

def error
  @error
end

#last_attempt_timeString

Output only. The last time we attempted to generate an attestation. Corresponds to the JSON property lastAttemptTime

Returns:

  • (String)


8638
8639
8640
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8638

def last_attempt_time
  @last_attempt_time
end

#stateString

Output only. The success/failure state of the latest attestation attempt. Corresponds to the JSON property state

Returns:

  • (String)


8643
8644
8645
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8643

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8650
8651
8652
8653
8654
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8650

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @last_attempt_time = args[:last_attempt_time] if args.key?(:last_attempt_time)
  @state = args[:state] if args.key?(:state)
end