Class: Google::Apis::ContaineranalysisV1alpha1::VulnerabilityType
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::VulnerabilityType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
VulnerabilityType provides metadata about a security vulnerability.
Instance Attribute Summary collapse
-
#advisory_publish_time ⇒ String
Time this advisory was published by the source.
-
#cvss_score ⇒ Float
The CVSS score for this Vulnerability.
-
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System.
-
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
-
#cwe ⇒ Array<String>
A list of CWE for this vulnerability.
-
#details ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Detail>
All information about the package to specifically identify this vulnerability.
-
#severity ⇒ String
Note provider assigned impact of the vulnerability Corresponds to the JSON property
severity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityType
constructor
A new instance of VulnerabilityType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityType
Returns a new instance of VulnerabilityType.
8661 8662 8663 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advisory_publish_time ⇒ String
Time this advisory was published by the source.
Corresponds to the JSON property advisoryPublishTime
8622 8623 8624 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8622 def advisory_publish_time @advisory_publish_time end |
#cvss_score ⇒ Float
The CVSS score for this Vulnerability.
Corresponds to the JSON property cvssScore
8627 8628 8629 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8627 def cvss_score @cvss_score end |
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2
and v3. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS v2
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS v3
details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator
Corresponds to the JSON property cvssV2
8636 8637 8638 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8636 def cvss_v2 @cvss_v2 end |
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
Corresponds to the JSON property cvssVersion
8641 8642 8643 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8641 def cvss_version @cvss_version end |
#cwe ⇒ Array<String>
A list of CWE for this vulnerability. For details, see: https://cwe.mitre.org/
index.html
Corresponds to the JSON property cwe
8647 8648 8649 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8647 def cwe @cwe end |
#details ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Detail>
All information about the package to specifically identify this vulnerability.
One entry per (version range and cpe_uri) the package vulnerability has
manifested in.
Corresponds to the JSON property details
8654 8655 8656 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8654 def details @details end |
#severity ⇒ String
Note provider assigned impact of the vulnerability
Corresponds to the JSON property severity
8659 8660 8661 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8659 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8666 8667 8668 8669 8670 8671 8672 8673 8674 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8666 def update!(**args) @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time) @cvss_score = args[:cvss_score] if args.key?(:cvss_score) @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2) @cvss_version = args[:cvss_version] if args.key?(:cvss_version) @cwe = args[:cwe] if args.key?(:cwe) @details = args[:details] if args.key?(:details) @severity = args[:severity] if args.key?(:severity) end |