Class: Google::Apis::ContaineranalysisV1alpha1::BaseImage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BaseImage

Returns a new instance of BaseImage.



273
274
275
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layer_countFixnum

The number of layers that the base image is composed of. Corresponds to the JSON property layerCount

Returns:

  • (Fixnum)


261
262
263
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 261

def layer_count
  @layer_count
end

#nameString

The name of the base image. Corresponds to the JSON property name

Returns:

  • (String)


266
267
268
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 266

def name
  @name
end

#repositoryString

The repository name in which the base image is from. Corresponds to the JSON property repository

Returns:

  • (String)


271
272
273
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 271

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



278
279
280
281
282
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 278

def update!(**args)
  @layer_count = args[:layer_count] if args.key?(:layer_count)
  @name = args[:name] if args.key?(:name)
  @repository = args[:repository] if args.key?(:repository)
end