Class: Google::Apis::ContaineranalysisV1alpha1::ComplianceNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ComplianceNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
ComplianceNote encapsulates all information about a specific compliance check.
Instance Attribute Summary collapse
-
#cis_benchmark ⇒ Google::Apis::ContaineranalysisV1alpha1::CisBenchmark
A compliance check that is a CIS benchmark.
-
#description ⇒ String
A description about this compliance check.
-
#impact ⇒ String
Potential impact of the suggested remediation Corresponds to the JSON property
impact. -
#rationale ⇒ String
A rationale for the existence of this compliance check.
-
#remediation ⇒ String
A description of remediation steps if the compliance check fails.
-
#scan_instructions ⇒ String
Serialized scan instructions with a predefined format.
-
#title ⇒ String
The title that identifies this compliance check.
-
#version ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ComplianceVersion>
The OS and config versions the benchmark applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComplianceNote
constructor
A new instance of ComplianceNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComplianceNote
Returns a new instance of ComplianceNote.
1183 1184 1185 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cis_benchmark ⇒ Google::Apis::ContaineranalysisV1alpha1::CisBenchmark
A compliance check that is a CIS benchmark.
Corresponds to the JSON property cisBenchmark
1145 1146 1147 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1145 def cis_benchmark @cis_benchmark end |
#description ⇒ String
A description about this compliance check.
Corresponds to the JSON property description
1150 1151 1152 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1150 def description @description end |
#impact ⇒ String
Potential impact of the suggested remediation
Corresponds to the JSON property impact
1155 1156 1157 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1155 def impact @impact end |
#rationale ⇒ String
A rationale for the existence of this compliance check.
Corresponds to the JSON property rationale
1160 1161 1162 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1160 def rationale @rationale end |
#remediation ⇒ String
A description of remediation steps if the compliance check fails.
Corresponds to the JSON property remediation
1165 1166 1167 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1165 def remediation @remediation end |
#scan_instructions ⇒ String
Serialized scan instructions with a predefined format.
Corresponds to the JSON property scanInstructions
NOTE: Values are automatically base64 encoded/decoded in the client library.
1171 1172 1173 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1171 def scan_instructions @scan_instructions end |
#title ⇒ String
The title that identifies this compliance check.
Corresponds to the JSON property title
1176 1177 1178 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1176 def title @title end |
#version ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ComplianceVersion>
The OS and config versions the benchmark applies to.
Corresponds to the JSON property version
1181 1182 1183 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1181 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1188 def update!(**args) @cis_benchmark = args[:cis_benchmark] if args.key?(:cis_benchmark) @description = args[:description] if args.key?(:description) @impact = args[:impact] if args.key?(:impact) @rationale = args[:rationale] if args.key?(:rationale) @remediation = args[:remediation] if args.key?(:remediation) @scan_instructions = args[:scan_instructions] if args.key?(:scan_instructions) @title = args[:title] if args.key?(:title) @version = args[:version] if args.key?(:version) end |