Class: Google::Apis::ContaineranalysisV1alpha1::ComplianceNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

ComplianceNote encapsulates all information about a specific compliance check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComplianceNote

Returns a new instance of ComplianceNote.



1177
1178
1179
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cis_benchmarkGoogle::Apis::ContaineranalysisV1alpha1::CisBenchmark

A compliance check that is a CIS benchmark. Corresponds to the JSON property cisBenchmark



1139
1140
1141
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1139

def cis_benchmark
  @cis_benchmark
end

#descriptionString

A description about this compliance check. Corresponds to the JSON property description

Returns:

  • (String)


1144
1145
1146
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1144

def description
  @description
end

#impactString

Potential impact of the suggested remediation Corresponds to the JSON property impact

Returns:

  • (String)


1149
1150
1151
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1149

def impact
  @impact
end

#rationaleString

A rationale for the existence of this compliance check. Corresponds to the JSON property rationale

Returns:

  • (String)


1154
1155
1156
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1154

def rationale
  @rationale
end

#remediationString

A description of remediation steps if the compliance check fails. Corresponds to the JSON property remediation

Returns:

  • (String)


1159
1160
1161
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1159

def remediation
  @remediation
end

#scan_instructionsString

Serialized scan instructions with a predefined format. Corresponds to the JSON property scanInstructions NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1165
1166
1167
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1165

def scan_instructions
  @scan_instructions
end

#titleString

The title that identifies this compliance check. Corresponds to the JSON property title

Returns:

  • (String)


1170
1171
1172
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1170

def title
  @title
end

#versionArray<Google::Apis::ContaineranalysisV1alpha1::ComplianceVersion>

The OS and config versions the benchmark applies to. Corresponds to the JSON property version



1175
1176
1177
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1175

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1182

def update!(**args)
  @cis_benchmark = args[:cis_benchmark] if args.key?(:cis_benchmark)
  @description = args[:description] if args.key?(:description)
  @impact = args[:impact] if args.key?(:impact)
  @rationale = args[:rationale] if args.key?(:rationale)
  @remediation = args[:remediation] if args.key?(:remediation)
  @scan_instructions = args[:scan_instructions] if args.key?(:scan_instructions)
  @title = args[:title] if args.key?(:title)
  @version = args[:version] if args.key?(:version)
end