Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

ApprovalResult describes the decision and associated metadata of a manual approval of a build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.



1361
1362
1363
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_timeString

Output only. The time when the approval decision was made. Corresponds to the JSON property approvalTime

Returns:

  • (String)


1335
1336
1337
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1335

def approval_time
  @approval_time
end

#approver_accountString

Output only. Email of the user that called the ApproveBuild API to approve or reject a build at the time that the API was called. Corresponds to the JSON property approverAccount

Returns:

  • (String)


1341
1342
1343
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1341

def 
  @approver_account
end

#commentString

Optional. An optional comment for this manual approval result. Corresponds to the JSON property comment

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1346

def comment
  @comment
end

#decisionString

Required. The decision of this manual approval. Corresponds to the JSON property decision

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1351

def decision
  @decision
end

#urlString

Optional. An optional URL tied to this manual approval result. This field is essentially the same as comment, except that it will be rendered by the UI differently. An example use case is a link to an external job that approved this Build. Corresponds to the JSON property url

Returns:

  • (String)


1359
1360
1361
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1359

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1366
1367
1368
1369
1370
1371
1372
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1366

def update!(**args)
  @approval_time = args[:approval_time] if args.key?(:approval_time)
  @approver_account = args[:approver_account] if args.key?(:approver_account)
  @comment = args[:comment] if args.key?(:comment)
  @decision = args[:decision] if args.key?(:decision)
  @url = args[:url] if args.key?(:url)
end