Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
ApprovalResult describes the decision and associated metadata of a manual approval of a build.
Instance Attribute Summary collapse
-
#approval_time ⇒ String
Output only.
-
#approver_account ⇒ String
Output only.
-
#comment ⇒ String
Optional.
-
#decision ⇒ String
Required.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.
1317 1318 1319 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_time ⇒ String
Output only. The time when the approval decision was made.
Corresponds to the JSON property approvalTime
1291 1292 1293 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1291 def approval_time @approval_time end |
#approver_account ⇒ String
Output only. Email of the user that called the ApproveBuild API to approve or
reject a build at the time that the API was called.
Corresponds to the JSON property approverAccount
1297 1298 1299 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1297 def approver_account @approver_account end |
#comment ⇒ String
Optional. An optional comment for this manual approval result.
Corresponds to the JSON property comment
1302 1303 1304 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1302 def comment @comment end |
#decision ⇒ String
Required. The decision of this manual approval.
Corresponds to the JSON property decision
1307 1308 1309 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1307 def decision @decision end |
#url ⇒ String
Optional. An optional URL tied to this manual approval result. This field is
essentially the same as comment, except that it will be rendered by the UI
differently. An example use case is a link to an external job that approved
this Build.
Corresponds to the JSON property url
1315 1316 1317 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1315 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1322 def update!(**args) @approval_time = args[:approval_time] if args.key?(:approval_time) @approver_account = args[:approver_account] if args.key?(:approver_account) @comment = args[:comment] if args.key?(:comment) @decision = args[:decision] if args.key?(:decision) @url = args[:url] if args.key?(:url) end |