Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Artifacts produced by a build that should be uploaded upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact>
Optional.
-
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule>
Optional.
-
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build steps.
-
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#objects ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.
-
#oci ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci>
Optional.
-
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.
1504 1505 1506 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact>
Optional. A list of generic artifacts to be uploaded to Artifact Registry upon
successful completion of all build steps. If any artifacts fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property genericArtifacts
1445 1446 1447 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1445 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule>
Optional. A list of Go modules to be uploaded to Artifact Registry upon
successful completion of all build steps. If any objects fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property goModules
1452 1453 1454 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1452 def go_modules @go_modules end |
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build
steps. The images will be pushed using the builder service account's
credentials. The digests of the pushed images will be stored in the Build
resource's results field. If any of the images fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property images
1461 1462 1463 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1461 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful
completion of all build steps. Artifacts in the workspace matching specified
paths globs will be uploaded to the specified Artifact Registry repository
using the builder service account's credentials. If any artifacts fail to be
pushed, the build is marked FAILURE.
Corresponds to the JSON property mavenArtifacts
1470 1471 1472 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1470 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful
completion of all build steps. Npm packages in the specified paths will be
uploaded to the specified Artifact Registry repository using the builder
service account's credentials. If any packages fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property npmPackages
1479 1480 1481 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1479 def npm_packages @npm_packages end |
#objects ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion
of all build steps.
Corresponds to the JSON property objects
1485 1486 1487 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1485 def objects @objects end |
#oci ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci>
Optional. A list of OCI images to be uploaded to Artifact Registry upon
successful completion of all build steps. OCI images in the specified paths
will be uploaded to the specified Artifact Registry repository using the
builder service account's credentials. If any images fail to be pushed, the
build is marked FAILURE.
Corresponds to the JSON property oci
1494 1495 1496 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1494 def oci @oci end |
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful
completion of all build steps. The build service account credentials will be
used to perform the upload. If any objects fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property pythonPackages
1502 1503 1504 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1502 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1509 def update!(**args) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @objects = args[:objects] if args.key?(:objects) @oci = args[:oci] if args.key?(:oci) @python_packages = args[:python_packages] if args.key?(:python_packages) end |