Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Generic artifact to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#folder ⇒ String
Required.
-
#registry_path ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact.
1514 1515 1516 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folder ⇒ String
Required. Path to the generic artifact in the build's workspace to be uploaded
to Artifact Registry.
Corresponds to the JSON property folder
1505 1506 1507 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1505 def folder @folder end |
#registry_path ⇒ String
Required. Registry path to upload the generic artifact to, in the form
projects/$PROJECT/locations/$LOCATION/repositories/$REPO/packages/$PACKAGE/
versions/$VERSION
Corresponds to the JSON property registryPath
1512 1513 1514 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1512 def registry_path @registry_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1519 1520 1521 1522 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1519 def update!(**args) @folder = args[:folder] if args.key?(:folder) @registry_path = args[:registry_path] if args.key?(:registry_path) end |