Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Maven
artifactIdvalue used when uploading the artifact to Artifact Registry. -
#deploy_folder ⇒ String
Optional.
-
#group_id ⇒ String
Maven
groupIdvalue used when uploading the artifact to Artifact Registry. -
#path ⇒ String
Optional.
-
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix.
-
#version ⇒ String
Maven
versionvalue used when uploading the artifact to Artifact Registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact.
1535 1536 1537 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Maven artifactId value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property artifactId
1500 1501 1502 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1500 def artifact_id @artifact_id end |
#deploy_folder ⇒ String
Optional. Path to a folder containing the files to upload to Artifact Registry.
This can be either an absolute path, e.g. /workspace/my-app/target/, or a
relative path from /workspace, e.g. my-app/target/. This field is mutually
exclusive with the path field.
Corresponds to the JSON property deployFolder
1508 1509 1510 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1508 def deploy_folder @deploy_folder end |
#group_id ⇒ String
Maven groupId value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property groupId
1513 1514 1515 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1513 def group_id @group_id end |
#path ⇒ String
Optional. Path to an artifact in the build's workspace to be uploaded to
Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/
target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/
target/my-app-1.0.SNAPSHOT.jar.
Corresponds to the JSON property path
1521 1522 1523 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1521 def path @path end |
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$
PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be
uploaded to Artifact Registry with this location as a prefix.
Corresponds to the JSON property repository
1528 1529 1530 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1528 def repository @repository end |
#version ⇒ String
Maven version value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property version
1533 1534 1535 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1533 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1540 1541 1542 1543 1544 1545 1546 1547 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1540 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder) @group_id = args[:group_id] if args.key?(:group_id) @path = args[:path] if args.key?(:path) @repository = args[:repository] if args.key?(:repository) @version = args[:version] if args.key?(:version) end |