Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo.



2066
2067
2068
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


2059
2060
2061
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2059

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


2064
2065
2066
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2064

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2071
2072
2073
2074
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2071

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end