Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Optional arguments to enable specific features of builds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions.



2021
2022
2023
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automap_substitutionsBoolean Also known as: automap_substitutions?

Option to include built-in and custom substitutions as env variables for all build steps. Corresponds to the JSON property automapSubstitutions

Returns:

  • (Boolean)


1912
1913
1914
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1912

def automap_substitutions
  @automap_substitutions
end

#default_logs_bucket_behaviorString

Optional. Option to specify how default logs buckets are setup. Corresponds to the JSON property defaultLogsBucketBehavior

Returns:

  • (String)


1918
1919
1920
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1918

def default_logs_bucket_behavior
  @default_logs_bucket_behavior
end

#disk_size_gbFixnum

Requested disk size for the VM that runs the build. Note that this is NOT " disk free"; some of the space will be used by the operating system and build utilities. Also note that this is the minimum disk size that will be allocated for the build -- the build may run with a larger disk than requested. At present, the maximum disk size is 4000GB; builds that request more than the maximum are rejected with an error. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


1928
1929
1930
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1928

def disk_size_gb
  @disk_size_gb
end

#dynamic_substitutionsBoolean Also known as: dynamic_substitutions?

Option to specify whether or not to apply bash style string operations to the substitutions. NOTE: this is always enabled for triggered builds and cannot be overridden in the build configuration file. Corresponds to the JSON property dynamicSubstitutions

Returns:

  • (Boolean)


1935
1936
1937
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1935

def dynamic_substitutions
  @dynamic_substitutions
end

#enable_structured_loggingBoolean Also known as: enable_structured_logging?

Optional. Option to specify whether structured logging is enabled. If true, JSON-formatted logs are parsed as structured logs. Corresponds to the JSON property enableStructuredLogging

Returns:

  • (Boolean)


1942
1943
1944
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1942

def enable_structured_logging
  @enable_structured_logging
end

#envArray<String>

A list of global environment variable definitions that will exist for all build steps in this build. If a variable is defined in both globally and in a build step, the variable will use the build step value. The elements are of the form "KEY=VALUE" for the environment variable "KEY" being given the value " VALUE". Corresponds to the JSON property env

Returns:

  • (Array<String>)


1952
1953
1954
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1952

def env
  @env
end

#log_streaming_optionString

Option to define build log streaming behavior to Cloud Storage. Corresponds to the JSON property logStreamingOption

Returns:

  • (String)


1957
1958
1959
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1957

def log_streaming_option
  @log_streaming_option
end

#loggingString

Option to specify the logging mode, which determines if and where build logs are stored. Corresponds to the JSON property logging

Returns:

  • (String)


1963
1964
1965
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1963

def logging
  @logging
end

#machine_typeString

Compute Engine machine type on which to run the build. Corresponds to the JSON property machineType

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1968

def machine_type
  @machine_type
end

#poolGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOption

Details about how a build should be executed on a WorkerPool. See running builds in a private pool for more information. Corresponds to the JSON property pool



1975
1976
1977
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1975

def pool
  @pool
end

#pubsub_topicString

Optional. Option to specify the Pub/Sub topic to receive build status updates. Corresponds to the JSON property pubsubTopic

Returns:

  • (String)


1980
1981
1982
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1980

def pubsub_topic
  @pubsub_topic
end

#requested_verify_optionString

Requested verifiability options. Corresponds to the JSON property requestedVerifyOption

Returns:

  • (String)


1985
1986
1987
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1985

def requested_verify_option
  @requested_verify_option
end

#secret_envArray<String>

A list of global environment variables, which are encrypted using a Cloud Key Management Service crypto key. These values must be specified in the build's Secret. These variables will be available to all build steps in this build. Corresponds to the JSON property secretEnv

Returns:

  • (Array<String>)


1992
1993
1994
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1992

def secret_env
  @secret_env
end

#source_provenance_hashArray<String>

Requested hash for SourceProvenance. Corresponds to the JSON property sourceProvenanceHash

Returns:

  • (Array<String>)


1997
1998
1999
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 1997

def source_provenance_hash
  @source_provenance_hash
end

#substitution_optionString

Option to specify behavior when there is an error in the substitution checks. NOTE: this is always set to ALLOW_LOOSE for triggered builds and cannot be overridden in the build configuration file. Corresponds to the JSON property substitutionOption

Returns:

  • (String)


2004
2005
2006
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2004

def substitution_option
  @substitution_option
end

#volumesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>

Global list of volumes to mount for ALL build steps Each volume is created as an empty volume prior to starting the build process. Upon completion of the build, volumes and their contents are discarded. Global volume names and paths cannot conflict with the volumes defined a build step. Using a global volume in a build with only one step is not valid as it is indicative of a build request with an incorrect configuration. Corresponds to the JSON property volumes



2014
2015
2016
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2014

def volumes
  @volumes
end

#worker_poolString

This field deprecated; please use pool.name instead. Corresponds to the JSON property workerPool

Returns:

  • (String)


2019
2020
2021
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2019

def worker_pool
  @worker_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2026

def update!(**args)
  @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions)
  @default_logs_bucket_behavior = args[:default_logs_bucket_behavior] if args.key?(:default_logs_bucket_behavior)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @dynamic_substitutions = args[:dynamic_substitutions] if args.key?(:dynamic_substitutions)
  @enable_structured_logging = args[:enable_structured_logging] if args.key?(:enable_structured_logging)
  @env = args[:env] if args.key?(:env)
  @log_streaming_option = args[:log_streaming_option] if args.key?(:log_streaming_option)
  @logging = args[:logging] if args.key?(:logging)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @pool = args[:pool] if args.key?(:pool)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @requested_verify_option = args[:requested_verify_option] if args.key?(:requested_verify_option)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
  @source_provenance_hash = args[:source_provenance_hash] if args.key?(:source_provenance_hash)
  @substitution_option = args[:substitution_option] if args.key?(:substitution_option)
  @volumes = args[:volumes] if args.key?(:volumes)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
end