Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

An image built by the pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage.



2293
2294
2295
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


2275
2276
2277
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2275

def artifact_registry_package
  @artifact_registry_package
end

#digestString

Docker Registry 2.0 digest. Corresponds to the JSON property digest

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2280

def digest
  @digest
end

#nameString

Name used to push the container image to Google Container Registry, as presented to docker push. Corresponds to the JSON property name

Returns:

  • (String)


2286
2287
2288
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2286

def name
  @name
end

#push_timingGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



2291
2292
2293
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2291

def push_timing
  @push_timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2298
2299
2300
2301
2302
2303
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2298

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @digest = args[:digest] if args.key?(:digest)
  @name = args[:name] if args.key?(:name)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
end