Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
An image built by the pipeline.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#digest ⇒ String
Docker Registry 2.0 digest.
-
#name ⇒ String
Name used to push the container image to Google Container Registry, as presented to
docker push. -
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage.
2287 2288 2289 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
2269 2270 2271 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2269 def artifact_registry_package @artifact_registry_package end |
#digest ⇒ String
Docker Registry 2.0 digest.
Corresponds to the JSON property digest
2274 2275 2276 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2274 def digest @digest end |
#name ⇒ String
Name used to push the container image to Google Container Registry, as
presented to docker push.
Corresponds to the JSON property name
2280 2281 2282 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2280 def name @name end |
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
2285 2286 2287 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2285 def push_timing @push_timing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2292 2293 2294 2295 2296 2297 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2292 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @digest = args[:digest] if args.key?(:digest) @name = args[:name] if args.key?(:name) @push_timing = args[:push_timing] if args.key?(:push_timing) end |