Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
A dependency that the Cloud Build worker will fetch before executing user steps.
Instance Attribute Summary collapse
-
#empty ⇒ Boolean
(also: #empty?)
If set to true disable all dependency fetching (ignoring the default source as well).
-
#generic_artifact ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGenericArtifactDependency
Represents a generic artifact as a build dependency.
-
#git_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency
Represents a git repository as a build dependency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency.
2560 2561 2562 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#empty ⇒ Boolean Also known as: empty?
If set to true disable all dependency fetching (ignoring the default source as
well).
Corresponds to the JSON property empty
2547 2548 2549 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2547 def empty @empty end |
#generic_artifact ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGenericArtifactDependency
Represents a generic artifact as a build dependency.
Corresponds to the JSON property genericArtifact
2553 2554 2555 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2553 def generic_artifact @generic_artifact end |
#git_source ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency
Represents a git repository as a build dependency.
Corresponds to the JSON property gitSource
2558 2559 2560 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2558 def git_source @git_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2565 2566 2567 2568 2569 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2565 def update!(**args) @empty = args[:empty] if args.key?(:empty) @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact) @git_source = args[:git_source] if args.key?(:git_source) end |