Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency.



2512
2513
2514
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


2499
2500
2501
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2499

def empty
  @empty
end

#generic_artifactGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGenericArtifactDependency

Represents a generic artifact as a build dependency. Corresponds to the JSON property genericArtifact



2505
2506
2507
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2505

def generic_artifact
  @generic_artifact
end

#git_sourceGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



2510
2511
2512
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2510

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2517
2518
2519
2520
2521
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2517

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact)
  @git_source = args[:git_source] if args.key?(:git_source)
end