Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency.



2350
2351
2352
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


2342
2343
2344
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2342

def empty
  @empty
end

#git_sourceGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



2348
2349
2350
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2348

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2355
2356
2357
2358
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2355

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @git_source = args[:git_source] if args.key?(:git_source)
end