Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency.



2629
2630
2631
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2606
2607
2608
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2606

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2611
2612
2613
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2611

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2616
2617
2618
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2616

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2622
2623
2624
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2622

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2627
2628
2629
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2627

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2634
2635
2636
2637
2638
2639
2640
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2634

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end