Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency.



2581
2582
2583
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2558
2559
2560
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2558

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2563
2564
2565
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2563

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2568
2569
2570
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2568

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2574
2575
2576
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2574

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2579
2580
2581
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2579

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2586
2587
2588
2589
2590
2591
2592
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2586

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end