Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
This config defines the location of a source through Developer Connect.
Instance Attribute Summary collapse
-
#dir ⇒ String
Required.
-
#git_repository_link ⇒ String
Required.
-
#revision ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig.
2453 2454 2455 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dir ⇒ String
Required. Directory, relative to the source root, in which to run the build.
Corresponds to the JSON property dir
2439 2440 2441 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2439 def dir @dir end |
#git_repository_link ⇒ String
Required. The Developer Connect Git repository link, formatted as projects/*/
locations/*/connections/*/gitRepositoryLink/*.
Corresponds to the JSON property gitRepositoryLink
2445 2446 2447 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2445 def git_repository_link @git_repository_link end |
#revision ⇒ String
Required. The revision to fetch from the Git repository such as a branch, a
tag, a commit SHA, or any Git ref.
Corresponds to the JSON property revision
2451 2452 2453 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2451 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2458 2459 2460 2461 2462 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2458 def update!(**args) @dir = args[:dir] if args.key?(:dir) @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link) @revision = args[:revision] if args.key?(:revision) end |