Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Artifacts created by the build pipeline.
Instance Attribute Summary collapse
-
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage.
-
#artifact_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
-
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order corresponding to build step indices.
-
#build_step_results ⇒ Hash<String,Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps.
-
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only.
-
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional.
-
#images ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
-
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
-
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
-
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage.
-
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Results
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Results.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Results
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Results.
3002 3003 3004 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud
Storage. Only populated when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property artifactManifest
2938 2939 2940 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2938 def artifact_manifest @artifact_manifest end |
#artifact_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property artifactTiming
2943 2944 2945 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2943 def artifact_timing @artifact_timing end |
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
Corresponds to the JSON property buildStepImages
2948 2949 2950 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2948 def build_step_images @build_step_images end |
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order
corresponding to build step indices. Cloud Builders can produce this output by writing to $
BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $
BUILDER_OUTPUT variable is read-only and can't be substituted.
Corresponds to the JSON property buildStepOutputs
2957 2958 2959 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2957 def build_step_outputs @build_step_outputs end |
#build_step_results ⇒ Hash<String,Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps. step_id ->
Corresponds to the JSON property buildStepResults
2962 2963 2964 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2962 def build_step_results @build_step_results end |
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only. Generic artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property genericArtifacts
2968 2969 2970 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2968 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional. Go module artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property goModules
2974 2975 2976 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2974 def go_modules @go_modules end |
#images ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
Corresponds to the JSON property images
2979 2980 2981 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2979 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property mavenArtifacts
2984 2985 2986 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2984 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property npmPackages
2989 2990 2991 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2989 def npm_packages @npm_packages end |
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage. Only populated
when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property numArtifacts
2995 2996 2997 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2995 def num_artifacts @num_artifacts end |
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property pythonPackages
3000 3001 3002 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3000 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3007 def update!(**args) @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest) @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing) @build_step_images = args[:build_step_images] if args.key?(:build_step_images) @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs) @build_step_results = args[:build_step_results] if args.key?(:build_step_results) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts) @python_packages = args[:python_packages] if args.key?(:python_packages) end |