Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Artifacts created by the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Results

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Results.



2954
2955
2956
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_manifestString

Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property artifactManifest

Returns:

  • (String)


2890
2891
2892
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2890

def artifact_manifest
  @artifact_manifest
end

#artifact_timingGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property artifactTiming



2895
2896
2897
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2895

def artifact_timing
  @artifact_timing
end

#build_step_imagesArray<String>

List of build step digests, in the order corresponding to build step indices. Corresponds to the JSON property buildStepImages

Returns:

  • (Array<String>)


2900
2901
2902
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2900

def build_step_images
  @build_step_images
end

#build_step_outputsArray<String>

List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $ BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $ BUILDER_OUTPUT variable is read-only and can't be substituted. Corresponds to the JSON property buildStepOutputs

Returns:

  • (Array<String>)


2909
2910
2911
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2909

def build_step_outputs
  @build_step_outputs
end

#build_step_resultsHash<String,Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStepResults>

Results for build steps. step_id -> Corresponds to the JSON property buildStepResults



2914
2915
2916
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2914

def build_step_results
  @build_step_results
end

#generic_artifactsArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact>

Output only. Generic artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property genericArtifacts



2920
2921
2922
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2920

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule>

Optional. Go module artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property goModules



2926
2927
2928
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2926

def go_modules
  @go_modules
end

#imagesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage>

Container images that were built as a part of the build. Corresponds to the JSON property images



2931
2932
2933
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2931

def images
  @images
end

#maven_artifactsArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact>

Maven artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property mavenArtifacts



2936
2937
2938
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2936

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage>

Npm packages uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property npmPackages



2941
2942
2943
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2941

def npm_packages
  @npm_packages
end

#num_artifactsFixnum

Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property numArtifacts

Returns:

  • (Fixnum)


2947
2948
2949
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2947

def num_artifacts
  @num_artifacts
end

#python_packagesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage>

Python artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property pythonPackages



2952
2953
2954
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2952

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2959

def update!(**args)
  @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest)
  @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing)
  @build_step_images = args[:build_step_images] if args.key?(:build_step_images)
  @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs)
  @build_step_results = args[:build_step_results] if args.key?(:build_step_results)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end