Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Artifacts created by the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Results

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Results.



2754
2755
2756
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_manifestString

Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property artifactManifest

Returns:

  • (String)


2701
2702
2703
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2701

def artifact_manifest
  @artifact_manifest
end

#artifact_timingGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property artifactTiming



2706
2707
2708
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2706

def artifact_timing
  @artifact_timing
end

#build_step_imagesArray<String>

List of build step digests, in the order corresponding to build step indices. Corresponds to the JSON property buildStepImages

Returns:

  • (Array<String>)


2711
2712
2713
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2711

def build_step_images
  @build_step_images
end

#build_step_outputsArray<String>

List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $ BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $ BUILDER_OUTPUT variable is read-only and can't be substituted. Corresponds to the JSON property buildStepOutputs

Returns:

  • (Array<String>)


2720
2721
2722
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2720

def build_step_outputs
  @build_step_outputs
end

#go_modulesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule>

Optional. Go module artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property goModules



2726
2727
2728
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2726

def go_modules
  @go_modules
end

#imagesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage>

Container images that were built as a part of the build. Corresponds to the JSON property images



2731
2732
2733
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2731

def images
  @images
end

#maven_artifactsArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact>

Maven artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property mavenArtifacts



2736
2737
2738
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2736

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage>

Npm packages uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property npmPackages



2741
2742
2743
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2741

def npm_packages
  @npm_packages
end

#num_artifactsFixnum

Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property numArtifacts

Returns:

  • (Fixnum)


2747
2748
2749
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2747

def num_artifacts
  @num_artifacts
end

#python_packagesArray<Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage>

Python artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property pythonPackages



2752
2753
2754
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2752

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
2770
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2759

def update!(**args)
  @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest)
  @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing)
  @build_step_images = args[:build_step_images] if args.key?(:build_step_images)
  @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end