Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Location of the source in an archive file in Cloud Storage.
Instance Attribute Summary collapse
-
#bucket ⇒ String
Cloud Storage bucket containing the source (see Bucket Name Requirements).
-
#generation ⇒ Fixnum
Optional.
-
#object ⇒ String
Required.
-
#source_fetcher ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource.
2993 2994 2995 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2993 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ String
Cloud Storage bucket containing the source (see Bucket Name Requirements).
Corresponds to the JSON property bucket
2974 2975 2976 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2974 def bucket @bucket end |
#generation ⇒ Fixnum
Optional. Cloud Storage generation for the object. If the generation is
omitted, the latest generation will be used.
Corresponds to the JSON property generation
2980 2981 2982 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2980 def generation @generation end |
#object ⇒ String
Required. Cloud Storage object containing the source. This object must be a
zipped (.zip) or gzipped archive file (.tar.gz) containing source to build.
Corresponds to the JSON property object
2986 2987 2988 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2986 def object @object end |
#source_fetcher ⇒ String
Optional. Option to specify the tool to fetch the source file for the build.
Corresponds to the JSON property sourceFetcher
2991 2992 2993 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2991 def source_fetcher @source_fetcher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2998 2999 3000 3001 3002 3003 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 2998 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @generation = args[:generation] if args.key?(:generation) @object = args[:object] if args.key?(:object) @source_fetcher = args[:source_fetcher] if args.key?(:source_fetcher) end |