Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.
Instance Attribute Summary collapse
-
#artifact_fingerprint ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>
Output only.
-
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact.
3393 3394 3395 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_fingerprint ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property artifactFingerprint
3370 3371 3372 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3370 def artifact_fingerprint @artifact_fingerprint end |
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3375 3376 3377 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3375 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>
Output only. The file hashes that make up the generic artifact.
Corresponds to the JSON property fileHashes
3380 3381 3382 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3380 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3385 3386 3387 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3385 def push_timing @push_timing end |
#uri ⇒ String
Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/
repositories/r1/packages/p1/versions/v1
Corresponds to the JSON property uri
3391 3392 3393 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3391 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3398 3399 3400 3401 3402 3403 3404 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3398 def update!(**args) @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |