Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
A Go module artifact uploaded to Artifact Registry using the GoModule directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule.
3421 3422 3423 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3403 3404 3405 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3403 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
3409 3410 3411 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3409 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3414 3415 3416 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3414 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
3419 3420 3421 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3419 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3426 3427 3428 3429 3430 3431 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3426 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |