Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A Maven artifact uploaded using the MavenArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact.



3138
3139
3140
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3120
3121
3122
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3120

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3126
3127
3128
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3126

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3131
3132
3133
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3131

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


3136
3137
3138
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3136

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3143
3144
3145
3146
3147
3148
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3143

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end