Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

An npm package uploaded to Artifact Registry using the NpmPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage.



3509
3510
3511
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3509

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3491
3492
3493
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3491

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3497
3498
3499
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3497

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3502
3503
3504
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3502

def push_timing
  @push_timing
end

#uriString

URI of the uploaded npm package. Corresponds to the JSON property uri

Returns:

  • (String)


3507
3508
3509
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3507

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3514
3515
3516
3517
3518
3519
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3514

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end