Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Artifact uploaded using the PythonPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage.
3214 3215 3216 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3196 3197 3198 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3196 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
3202 3203 3204 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3202 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3207 3208 3209 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3207 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
3212 3213 3214 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3212 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3219 3220 3221 3222 3223 3224 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3219 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |