Class: Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the volume to mount.
-
#path ⇒ String
Path at which to mount the volume.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Volume.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Volume.
3579 3580 3581 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the volume to mount. Volume names must be unique per build step and
must be valid names for Docker volumes. Each named volume must be used by at
least two build steps.
Corresponds to the JSON property name
3570 3571 3572 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3570 def name @name end |
#path ⇒ String
Path at which to mount the volume. Paths must be absolute and cannot conflict
with other volume paths on the same build step or with certain reserved volume
paths.
Corresponds to the JSON property path
3577 3578 3579 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3577 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3584 3585 3586 3587 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3584 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) end |