Class: Google::Apis::ContaineranalysisV1alpha1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Deployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The period during which some deployable was active in a runtime.
Instance Attribute Summary collapse
-
#address ⇒ String
Address of the runtime element hosting this deployment.
-
#config ⇒ String
Configuration used to create this deployment.
-
#deploy_time ⇒ String
Beginning of the lifetime of this deployment.
-
#platform ⇒ String
Platform hosting this deployment.
-
#resource_uri ⇒ Array<String>
Resource URI for the artifact being deployed taken from the deployable field with the same name.
-
#undeploy_time ⇒ String
End of the lifetime of this deployment.
-
#user_email ⇒ String
Identity of the user that triggered this deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
3740 3741 3742 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address of the runtime element hosting this deployment.
Corresponds to the JSON property address
3707 3708 3709 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3707 def address @address end |
#config ⇒ String
Configuration used to create this deployment.
Corresponds to the JSON property config
3712 3713 3714 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3712 def config @config end |
#deploy_time ⇒ String
Beginning of the lifetime of this deployment.
Corresponds to the JSON property deployTime
3717 3718 3719 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3717 def deploy_time @deploy_time end |
#platform ⇒ String
Platform hosting this deployment.
Corresponds to the JSON property platform
3722 3723 3724 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3722 def platform @platform end |
#resource_uri ⇒ Array<String>
Resource URI for the artifact being deployed taken from the deployable field
with the same name.
Corresponds to the JSON property resourceUri
3728 3729 3730 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3728 def resource_uri @resource_uri end |
#undeploy_time ⇒ String
End of the lifetime of this deployment.
Corresponds to the JSON property undeployTime
3733 3734 3735 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3733 def undeploy_time @undeploy_time end |
#user_email ⇒ String
Identity of the user that triggered this deployment.
Corresponds to the JSON property userEmail
3738 3739 3740 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3738 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3745 3746 3747 3748 3749 3750 3751 3752 3753 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3745 def update!(**args) @address = args[:address] if args.key?(:address) @config = args[:config] if args.key?(:config) @deploy_time = args[:deploy_time] if args.key?(:deploy_time) @platform = args[:platform] if args.key?(:platform) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time) @user_email = args[:user_email] if args.key?(:user_email) end |