Class: Google::Apis::ContaineranalysisV1alpha1::Deployment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

The period during which some deployable was active in a runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Deployment

Returns a new instance of Deployment.



3692
3693
3694
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address of the runtime element hosting this deployment. Corresponds to the JSON property address

Returns:

  • (String)


3659
3660
3661
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3659

def address
  @address
end

#configString

Configuration used to create this deployment. Corresponds to the JSON property config

Returns:

  • (String)


3664
3665
3666
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3664

def config
  @config
end

#deploy_timeString

Beginning of the lifetime of this deployment. Corresponds to the JSON property deployTime

Returns:

  • (String)


3669
3670
3671
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3669

def deploy_time
  @deploy_time
end

#platformString

Platform hosting this deployment. Corresponds to the JSON property platform

Returns:

  • (String)


3674
3675
3676
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3674

def platform
  @platform
end

#resource_uriArray<String>

Resource URI for the artifact being deployed taken from the deployable field with the same name. Corresponds to the JSON property resourceUri

Returns:

  • (Array<String>)


3680
3681
3682
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3680

def resource_uri
  @resource_uri
end

#undeploy_timeString

End of the lifetime of this deployment. Corresponds to the JSON property undeployTime

Returns:

  • (String)


3685
3686
3687
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3685

def undeploy_time
  @undeploy_time
end

#user_emailString

Identity of the user that triggered this deployment. Corresponds to the JSON property userEmail

Returns:

  • (String)


3690
3691
3692
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3690

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3697
3698
3699
3700
3701
3702
3703
3704
3705
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3697

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @config = args[:config] if args.key?(:config)
  @deploy_time = args[:deploy_time] if args.key?(:deploy_time)
  @platform = args[:platform] if args.key?(:platform)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time)
  @user_email = args[:user_email] if args.key?(:user_email)
end