Class: Google::Apis::ContaineranalysisV1alpha1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Deployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The period during which some deployable was active in a runtime.
Instance Attribute Summary collapse
-
#address ⇒ String
Address of the runtime element hosting this deployment.
-
#config ⇒ String
Configuration used to create this deployment.
-
#deploy_time ⇒ String
Beginning of the lifetime of this deployment.
-
#platform ⇒ String
Platform hosting this deployment.
-
#resource_uri ⇒ Array<String>
Resource URI for the artifact being deployed taken from the deployable field with the same name.
-
#undeploy_time ⇒ String
End of the lifetime of this deployment.
-
#user_email ⇒ String
Identity of the user that triggered this deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
3413 3414 3415 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address of the runtime element hosting this deployment.
Corresponds to the JSON property address
3380 3381 3382 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3380 def address @address end |
#config ⇒ String
Configuration used to create this deployment.
Corresponds to the JSON property config
3385 3386 3387 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3385 def config @config end |
#deploy_time ⇒ String
Beginning of the lifetime of this deployment.
Corresponds to the JSON property deployTime
3390 3391 3392 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3390 def deploy_time @deploy_time end |
#platform ⇒ String
Platform hosting this deployment.
Corresponds to the JSON property platform
3395 3396 3397 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3395 def platform @platform end |
#resource_uri ⇒ Array<String>
Resource URI for the artifact being deployed taken from the deployable field
with the same name.
Corresponds to the JSON property resourceUri
3401 3402 3403 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3401 def resource_uri @resource_uri end |
#undeploy_time ⇒ String
End of the lifetime of this deployment.
Corresponds to the JSON property undeployTime
3406 3407 3408 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3406 def undeploy_time @undeploy_time end |
#user_email ⇒ String
Identity of the user that triggered this deployment.
Corresponds to the JSON property userEmail
3411 3412 3413 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3411 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3418 def update!(**args) @address = args[:address] if args.key?(:address) @config = args[:config] if args.key?(:config) @deploy_time = args[:deploy_time] if args.key?(:deploy_time) @platform = args[:platform] if args.key?(:platform) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time) @user_email = args[:user_email] if args.key?(:user_email) end |