Class: Google::Apis::ContaineranalysisV1alpha1::Discovered
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Discovered
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Provides information about the scan status of a discovered resource.
Instance Attribute Summary collapse
-
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1alpha1::AnalysisCompleted
Indicates which analysis completed successfully.
-
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Status>
Indicates any errors encountered during analysis of a resource.
-
#analysis_status ⇒ String
The status of discovery for the resource.
-
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1alpha1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#archive_time ⇒ String
The time occurrences related to this discovery occurrence were archived.
-
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
-
#cpe ⇒ String
The CPE of the resource being scanned.
-
#files ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::File>
Optional.
-
#last_scan_time ⇒ String
The last time this resource was scanned.
-
#last_vulnerability_update_time ⇒ String
Optional.
-
#operation ⇒ Google::Apis::ContaineranalysisV1alpha1::Operation
This resource represents a long-running operation that is the result of a network API call.
-
#sbom_status ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomStatus
The status of an SBOM generation.
-
#vulnerability_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation
The status of a vulnerability attestation generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Discovered
constructor
A new instance of Discovered.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Discovered
Returns a new instance of Discovered.
4005 4006 4007 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1alpha1::AnalysisCompleted
Indicates which analysis completed successfully. Multiple types of analysis
can be performed on a single resource.
Corresponds to the JSON property analysisCompleted
3936 3937 3938 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3936 def analysis_completed @analysis_completed end |
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Status>
Indicates any errors encountered during analysis of a resource. There could be
0 or more of these errors.
Corresponds to the JSON property analysisError
3942 3943 3944 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3942 def analysis_error @analysis_error end |
#analysis_status ⇒ String
The status of discovery for the resource.
Corresponds to the JSON property analysisStatus
3947 3948 3949 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3947 def analysis_status @analysis_status end |
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1alpha1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property analysisStatusError
3957 3958 3959 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3957 def analysis_status_error @analysis_status_error end |
#archive_time ⇒ String
The time occurrences related to this discovery occurrence were archived.
Corresponds to the JSON property archiveTime
3962 3963 3964 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3962 def archive_time @archive_time end |
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
Corresponds to the JSON property continuousAnalysis
3967 3968 3969 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3967 def continuous_analysis @continuous_analysis end |
#cpe ⇒ String
The CPE of the resource being scanned.
Corresponds to the JSON property cpe
3972 3973 3974 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3972 def cpe @cpe end |
#files ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::File>
Optional. Files that make up the resource described by the occurrence.
Corresponds to the JSON property files
3977 3978 3979 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3977 def files @files end |
#last_scan_time ⇒ String
The last time this resource was scanned.
Corresponds to the JSON property lastScanTime
3982 3983 3984 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3982 def last_scan_time @last_scan_time end |
#last_vulnerability_update_time ⇒ String
Optional. The last time vulnerability scan results changed.
Corresponds to the JSON property lastVulnerabilityUpdateTime
3987 3988 3989 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3987 def last_vulnerability_update_time @last_vulnerability_update_time end |
#operation ⇒ Google::Apis::ContaineranalysisV1alpha1::Operation
This resource represents a long-running operation that is the result of a
network API call.
Corresponds to the JSON property operation
3993 3994 3995 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3993 def operation @operation end |
#sbom_status ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomStatus
The status of an SBOM generation.
Corresponds to the JSON property sbomStatus
3998 3999 4000 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3998 def sbom_status @sbom_status end |
#vulnerability_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation
The status of a vulnerability attestation generation.
Corresponds to the JSON property vulnerabilityAttestation
4003 4004 4005 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4003 def vulnerability_attestation @vulnerability_attestation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4010 def update!(**args) @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed) @analysis_error = args[:analysis_error] if args.key?(:analysis_error) @analysis_status = args[:analysis_status] if args.key?(:analysis_status) @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error) @archive_time = args[:archive_time] if args.key?(:archive_time) @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis) @cpe = args[:cpe] if args.key?(:cpe) @files = args[:files] if args.key?(:files) @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time) @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time) @operation = args[:operation] if args.key?(:operation) @sbom_status = args[:sbom_status] if args.key?(:sbom_status) @vulnerability_attestation = args[:vulnerability_attestation] if args.key?(:vulnerability_attestation) end |