Class: Google::Apis::ContaineranalysisV1alpha1::Discovered

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Provides information about the scan status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Discovered

Returns a new instance of Discovered.



3999
4000
4001
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::ContaineranalysisV1alpha1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



3930
3931
3932
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3930

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::ContaineranalysisV1alpha1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



3936
3937
3938
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3936

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


3941
3942
3943
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3941

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::ContaineranalysisV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



3951
3952
3953
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3951

def analysis_status_error
  @analysis_status_error
end

#archive_timeString

The time occurrences related to this discovery occurrence were archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


3956
3957
3958
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3956

def archive_time
  @archive_time
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


3961
3962
3963
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3961

def continuous_analysis
  @continuous_analysis
end

#cpeString

The CPE of the resource being scanned. Corresponds to the JSON property cpe

Returns:

  • (String)


3966
3967
3968
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3966

def cpe
  @cpe
end

#filesArray<Google::Apis::ContaineranalysisV1alpha1::File>

Optional. Files that make up the resource described by the occurrence. Corresponds to the JSON property files



3971
3972
3973
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3971

def files
  @files
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


3976
3977
3978
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3976

def last_scan_time
  @last_scan_time
end

#last_vulnerability_update_timeString

Optional. The last time vulnerability scan results changed. Corresponds to the JSON property lastVulnerabilityUpdateTime

Returns:

  • (String)


3981
3982
3983
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3981

def last_vulnerability_update_time
  @last_vulnerability_update_time
end

#operationGoogle::Apis::ContaineranalysisV1alpha1::Operation

This resource represents a long-running operation that is the result of a network API call. Corresponds to the JSON property operation



3987
3988
3989
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3987

def operation
  @operation
end

#sbom_statusGoogle::Apis::ContaineranalysisV1alpha1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



3992
3993
3994
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3992

def sbom_status
  @sbom_status
end

#vulnerability_attestationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation

The status of a vulnerability attestation generation. Corresponds to the JSON property vulnerabilityAttestation



3997
3998
3999
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3997

def vulnerability_attestation
  @vulnerability_attestation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4004

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @cpe = args[:cpe] if args.key?(:cpe)
  @files = args[:files] if args.key?(:files)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time)
  @operation = args[:operation] if args.key?(:operation)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
  @vulnerability_attestation = args[:vulnerability_attestation] if args.key?(:vulnerability_attestation)
end