Class: Google::Apis::ContaineranalysisV1alpha1::Discovered

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Provides information about the scan status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Discovered

Returns a new instance of Discovered.



3672
3673
3674
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::ContaineranalysisV1alpha1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



3603
3604
3605
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3603

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::ContaineranalysisV1alpha1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



3609
3610
3611
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3609

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


3614
3615
3616
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3614

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::ContaineranalysisV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



3624
3625
3626
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3624

def analysis_status_error
  @analysis_status_error
end

#archive_timeString

The time occurrences related to this discovery occurrence were archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


3629
3630
3631
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3629

def archive_time
  @archive_time
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


3634
3635
3636
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3634

def continuous_analysis
  @continuous_analysis
end

#cpeString

The CPE of the resource being scanned. Corresponds to the JSON property cpe

Returns:

  • (String)


3639
3640
3641
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3639

def cpe
  @cpe
end

#filesArray<Google::Apis::ContaineranalysisV1alpha1::File>

Optional. Files that make up the resource described by the occurrence. Corresponds to the JSON property files



3644
3645
3646
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3644

def files
  @files
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


3649
3650
3651
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3649

def last_scan_time
  @last_scan_time
end

#last_vulnerability_update_timeString

Optional. The last time vulnerability scan results changed. Corresponds to the JSON property lastVulnerabilityUpdateTime

Returns:

  • (String)


3654
3655
3656
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3654

def last_vulnerability_update_time
  @last_vulnerability_update_time
end

#operationGoogle::Apis::ContaineranalysisV1alpha1::Operation

This resource represents a long-running operation that is the result of a network API call. Corresponds to the JSON property operation



3660
3661
3662
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3660

def operation
  @operation
end

#sbom_statusGoogle::Apis::ContaineranalysisV1alpha1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



3665
3666
3667
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3665

def sbom_status
  @sbom_status
end

#vulnerability_attestationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation

The status of a vulnerability attestation generation. Corresponds to the JSON property vulnerabilityAttestation



3670
3671
3672
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3670

def vulnerability_attestation
  @vulnerability_attestation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3677
3678
3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 3677

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @cpe = args[:cpe] if args.key?(:cpe)
  @files = args[:files] if args.key?(:files)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time)
  @operation = args[:operation] if args.key?(:operation)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
  @vulnerability_attestation = args[:vulnerability_attestation] if args.key?(:vulnerability_attestation)
end