Class: Google::Apis::ContaineranalysisV1alpha1::DocumentOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DocumentOccurrence

Returns a new instance of DocumentOccurrence.



4181
4182
4183
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Identify when the SPDX file was originally created. The date is to be specified according to combined date and time in UTC format as specified in ISO 8601 standard Corresponds to the JSON property createTime

Returns:

  • (String)


4131
4132
4133
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4131

def create_time
  @create_time
end

#creator_commentString

A field for creators of the SPDX file to provide general comments about the creation of the SPDX file or any other relevant comment not included in the other fields Corresponds to the JSON property creatorComment

Returns:

  • (String)


4138
4139
4140
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4138

def creator_comment
  @creator_comment
end

#creatorsArray<String>

Identify who (or what, in the case of a tool) created the SPDX file. If the SPDX file was created by an individual, indicate the person's name Corresponds to the JSON property creators

Returns:

  • (Array<String>)


4144
4145
4146
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4144

def creators
  @creators
end

#document_commentString

A field for creators of the SPDX file content to provide comments to the consumers of the SPDX document Corresponds to the JSON property documentComment

Returns:

  • (String)


4150
4151
4152
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4150

def document_comment
  @document_comment
end

#external_document_refsArray<String>

Identify any external SPDX documents referenced within this SPDX document Corresponds to the JSON property externalDocumentRefs

Returns:

  • (Array<String>)


4155
4156
4157
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4155

def external_document_refs
  @external_document_refs
end

#idString

Identify the current SPDX document which may be referenced in relationships by other files, packages internally and documents externally Corresponds to the JSON property id

Returns:

  • (String)


4161
4162
4163
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4161

def id
  @id
end

#license_list_versionString

A field for creators of the SPDX file to provide the version of the SPDX License List used when the SPDX file was created Corresponds to the JSON property licenseListVersion

Returns:

  • (String)


4167
4168
4169
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4167

def license_list_version
  @license_list_version
end

#namespaceString

Provide an SPDX document specific namespace as a unique absolute Uniform Resource Identifier (URI) as specified in RFC-3986, with the exception of the ‘

’ delimiter

Corresponds to the JSON property namespace

Returns:

  • (String)


4174
4175
4176
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4174

def namespace
  @namespace
end

#titleString

Identify name of this document as designated by creator Corresponds to the JSON property title

Returns:

  • (String)


4179
4180
4181
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4179

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4186

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator_comment = args[:creator_comment] if args.key?(:creator_comment)
  @creators = args[:creators] if args.key?(:creators)
  @document_comment = args[:document_comment] if args.key?(:document_comment)
  @external_document_refs = args[:external_document_refs] if args.key?(:external_document_refs)
  @id = args[:id] if args.key?(:id)
  @license_list_version = args[:license_list_version] if args.key?(:license_list_version)
  @namespace = args[:namespace] if args.key?(:namespace)
  @title = args[:title] if args.key?(:title)
end