Class: Google::Apis::ContaineranalysisV1alpha1::DocumentOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::DocumentOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/
Instance Attribute Summary collapse
-
#create_time ⇒ String
Identify when the SPDX file was originally created.
-
#creator_comment ⇒ String
A field for creators of the SPDX file to provide general comments about the creation of the SPDX file or any other relevant comment not included in the other fields Corresponds to the JSON property
creatorComment. -
#creators ⇒ Array<String>
Identify who (or what, in the case of a tool) created the SPDX file.
-
#document_comment ⇒ String
A field for creators of the SPDX file content to provide comments to the consumers of the SPDX document Corresponds to the JSON property
documentComment. -
#external_document_refs ⇒ Array<String>
Identify any external SPDX documents referenced within this SPDX document Corresponds to the JSON property
externalDocumentRefs. -
#id ⇒ String
Identify the current SPDX document which may be referenced in relationships by other files, packages internally and documents externally Corresponds to the JSON property
id. -
#license_list_version ⇒ String
A field for creators of the SPDX file to provide the version of the SPDX License List used when the SPDX file was created Corresponds to the JSON property
licenseListVersion. -
#namespace ⇒ String
Provide an SPDX document specific namespace as a unique absolute Uniform Resource Identifier (URI) as specified in RFC-3986, with the exception of the ‘ #’ delimiter Corresponds to the JSON property
namespace. -
#title ⇒ String
Identify name of this document as designated by creator Corresponds to the JSON property
title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DocumentOccurrence
constructor
A new instance of DocumentOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DocumentOccurrence
Returns a new instance of DocumentOccurrence.
4133 4134 4135 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Identify when the SPDX file was originally created. The date is to be
specified according to combined date and time in UTC format as specified in
ISO 8601 standard
Corresponds to the JSON property createTime
4083 4084 4085 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4083 def create_time @create_time end |
#creator_comment ⇒ String
A field for creators of the SPDX file to provide general comments about the
creation of the SPDX file or any other relevant comment not included in the
other fields
Corresponds to the JSON property creatorComment
4090 4091 4092 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4090 def creator_comment @creator_comment end |
#creators ⇒ Array<String>
Identify who (or what, in the case of a tool) created the SPDX file. If the
SPDX file was created by an individual, indicate the person's name
Corresponds to the JSON property creators
4096 4097 4098 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4096 def creators @creators end |
#document_comment ⇒ String
A field for creators of the SPDX file content to provide comments to the
consumers of the SPDX document
Corresponds to the JSON property documentComment
4102 4103 4104 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4102 def document_comment @document_comment end |
#external_document_refs ⇒ Array<String>
Identify any external SPDX documents referenced within this SPDX document
Corresponds to the JSON property externalDocumentRefs
4107 4108 4109 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4107 def external_document_refs @external_document_refs end |
#id ⇒ String
Identify the current SPDX document which may be referenced in relationships by
other files, packages internally and documents externally
Corresponds to the JSON property id
4113 4114 4115 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4113 def id @id end |
#license_list_version ⇒ String
A field for creators of the SPDX file to provide the version of the SPDX
License List used when the SPDX file was created
Corresponds to the JSON property licenseListVersion
4119 4120 4121 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4119 def license_list_version @license_list_version end |
#namespace ⇒ String
Provide an SPDX document specific namespace as a unique absolute Uniform Resource Identifier (URI) as specified in RFC-3986, with the exception of the ‘
’ delimiter
Corresponds to the JSON property namespace
4126 4127 4128 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4126 def namespace @namespace end |
#title ⇒ String
Identify name of this document as designated by creator
Corresponds to the JSON property title
4131 4132 4133 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4131 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4138 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator_comment = args[:creator_comment] if args.key?(:creator_comment) @creators = args[:creators] if args.key?(:creators) @document_comment = args[:document_comment] if args.key?(:document_comment) @external_document_refs = args[:external_document_refs] if args.key?(:external_document_refs) @id = args[:id] if args.key?(:id) @license_list_version = args[:license_list_version] if args.key?(:license_list_version) @namespace = args[:namespace] if args.key?(:namespace) @title = args[:title] if args.key?(:title) end |