Class: Google::Apis::ContaineranalysisV1alpha1::ExternalRef

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalRef

Returns a new instance of ExternalRef.



4385
4386
4387
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package Corresponds to the JSON property category

Returns:

  • (String)


4367
4368
4369
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4367

def category
  @category
end

#commentString

Human-readable information about the purpose and target of the reference Corresponds to the JSON property comment

Returns:

  • (String)


4372
4373
4374
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4372

def comment
  @comment
end

#locatorString

The unique string with no spaces necessary to access the package-specific information, metadata, or content within the target location Corresponds to the JSON property locator

Returns:

  • (String)


4378
4379
4380
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4378

def locator
  @locator
end

#typeString

Type of category (e.g. 'npm' for the PACKAGE_MANAGER category) Corresponds to the JSON property type

Returns:

  • (String)


4383
4384
4385
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4383

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4390
4391
4392
4393
4394
4395
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4390

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @comment = args[:comment] if args.key?(:comment)
  @locator = args[:locator] if args.key?(:locator)
  @type = args[:type] if args.key?(:type)
end