Class: Google::Apis::ContaineranalysisV1alpha1::ExternalRef

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalRef

Returns a new instance of ExternalRef.



4337
4338
4339
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package Corresponds to the JSON property category

Returns:

  • (String)


4319
4320
4321
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4319

def category
  @category
end

#commentString

Human-readable information about the purpose and target of the reference Corresponds to the JSON property comment

Returns:

  • (String)


4324
4325
4326
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4324

def comment
  @comment
end

#locatorString

The unique string with no spaces necessary to access the package-specific information, metadata, or content within the target location Corresponds to the JSON property locator

Returns:

  • (String)


4330
4331
4332
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4330

def locator
  @locator
end

#typeString

Type of category (e.g. 'npm' for the PACKAGE_MANAGER category) Corresponds to the JSON property type

Returns:

  • (String)


4335
4336
4337
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4335

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4342
4343
4344
4345
4346
4347
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4342

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @comment = args[:comment] if args.key?(:comment)
  @locator = args[:locator] if args.key?(:locator)
  @type = args[:type] if args.key?(:type)
end