Class: Google::Apis::ContaineranalysisV1alpha1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Container message for hashes of byte content of files, used in Source messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



4433
4434
4435
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::ContaineranalysisV1alpha1::HashProp>

Collection of file hashes. Corresponds to the JSON property fileHash



4431
4432
4433
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4431

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4438
4439
4440
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4438

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end