Class: Google::Apis::ContaineranalysisV1alpha1::FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::FileLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::ContaineranalysisV1alpha1::LayerDetails
Details about the layer a package was found in.
-
#line_number ⇒ Fixnum
Line number in the file where the package is found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileLocation
constructor
A new instance of FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileLocation
Returns a new instance of FileLocation.
4485 4486 4487 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
4472 4473 4474 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4472 def file_path @file_path end |
#layer_details ⇒ Google::Apis::ContaineranalysisV1alpha1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
4477 4478 4479 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4477 def layer_details @layer_details end |
#line_number ⇒ Fixnum
Line number in the file where the package is found. Optional field that only
applies to source repository scanning.
Corresponds to the JSON property lineNumber
4483 4484 4485 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4483 def line_number @line_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4490 4491 4492 4493 4494 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4490 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) @line_number = args[:line_number] if args.key?(:line_number) end |