Class: Google::Apis::ContaineranalysisV1alpha1::FileLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileLocation

Returns a new instance of FileLocation.



4476
4477
4478
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


4463
4464
4465
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4463

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::ContaineranalysisV1alpha1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



4468
4469
4470
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4468

def layer_details
  @layer_details
end

#line_numberFixnum

Line number in the file where the package is found. Optional field that only applies to source repository scanning. Corresponds to the JSON property lineNumber

Returns:

  • (Fixnum)


4474
4475
4476
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4474

def line_number
  @line_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4481
4482
4483
4484
4485
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4481

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @line_number = args[:line_number] if args.key?(:line_number)
end