Class: Google::Apis::ContaineranalysisV1alpha1::FileLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileLocation

Returns a new instance of FileLocation.



4464
4465
4466
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


4451
4452
4453
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4451

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::ContaineranalysisV1alpha1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



4456
4457
4458
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4456

def layer_details
  @layer_details
end

#line_numberFixnum

Line number in the file where the package is found. Optional field that only applies to source repository scanning. Corresponds to the JSON property lineNumber

Returns:

  • (Fixnum)


4462
4463
4464
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4462

def line_number
  @line_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4469
4470
4471
4472
4473
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4469

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @line_number = args[:line_number] if args.key?(:line_number)
end