Class: Google::Apis::ContaineranalysisV1alpha1::FileLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileLocation

Returns a new instance of FileLocation.



4125
4126
4127
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


4118
4119
4120
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4118

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::ContaineranalysisV1alpha1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



4123
4124
4125
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4123

def layer_details
  @layer_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4130
4131
4132
4133
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4130

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
end