Class: Google::Apis::ContaineranalysisV1alpha1::FileOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

FileOccurrence represents an SPDX File Information section: https://spdx. github.io/spdx-spec/4-file-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileOccurrence

Returns a new instance of FileOccurrence.



4560
4561
4562
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributionsArray<String>

This field provides a place for the SPDX data creator to record, at the file level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attributions

Returns:

  • (Array<String>)


4519
4520
4521
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4519

def attributions
  @attributions
end

#commentString

This field provides a place for the SPDX file creator to record any general comments about the file Corresponds to the JSON property comment

Returns:

  • (String)


4525
4526
4527
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4525

def comment
  @comment
end

#contributorsArray<String>

This field provides a place for the SPDX file creator to record file contributors Corresponds to the JSON property contributors

Returns:

  • (Array<String>)


4531
4532
4533
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4531

def contributors
  @contributors
end

Identify the copyright holder of the file, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


4536
4537
4538
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4536

def copyright
  @copyright
end

#files_license_infoArray<String>

This field contains the license information actually found in the file, if any Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


4541
4542
4543
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4541

def files_license_info
  @files_license_info
end

#idString

Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property id

Returns:

  • (String)


4547
4548
4549
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4547

def id
  @id
end

#license_concludedGoogle::Apis::ContaineranalysisV1alpha1::License

License information. Corresponds to the JSON property licenseConcluded



4552
4553
4554
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4552

def license_concluded
  @license_concluded
end

#noticeString

This field provides a place for the SPDX file creator to record license notices or other such related notices found in the file Corresponds to the JSON property notice

Returns:

  • (String)


4558
4559
4560
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4558

def notice
  @notice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4565
4566
4567
4568
4569
4570
4571
4572
4573
4574
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4565

def update!(**args)
  @attributions = args[:attributions] if args.key?(:attributions)
  @comment = args[:comment] if args.key?(:comment)
  @contributors = args[:contributors] if args.key?(:contributors)
  @copyright = args[:copyright] if args.key?(:copyright)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @id = args[:id] if args.key?(:id)
  @license_concluded = args[:license_concluded] if args.key?(:license_concluded)
  @notice = args[:notice] if args.key?(:notice)
end