Class: Google::Apis::ContaineranalysisV1alpha1::FileOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::FileOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
FileOccurrence represents an SPDX File Information section: https://spdx. github.io/spdx-spec/4-file-information/
Instance Attribute Summary collapse
-
#attributions ⇒ Array<String>
This field provides a place for the SPDX data creator to record, at the file level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property
attributions. -
#comment ⇒ String
This field provides a place for the SPDX file creator to record any general comments about the file Corresponds to the JSON property
comment. -
#contributors ⇒ Array<String>
This field provides a place for the SPDX file creator to record file contributors Corresponds to the JSON property
contributors. -
#copyright ⇒ String
Identify the copyright holder of the file, as well as any dates present Corresponds to the JSON property
copyright. -
#files_license_info ⇒ Array<String>
This field contains the license information actually found in the file, if any Corresponds to the JSON property
filesLicenseInfo. -
#id ⇒ String
Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property
id. -
#license_concluded ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
-
#notice ⇒ String
This field provides a place for the SPDX file creator to record license notices or other such related notices found in the file Corresponds to the JSON property
notice.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileOccurrence
constructor
A new instance of FileOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileOccurrence
Returns a new instance of FileOccurrence.
4512 4513 4514 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributions ⇒ Array<String>
This field provides a place for the SPDX data creator to record, at the file
level, acknowledgements that may be needed to be communicated in some contexts
Corresponds to the JSON property attributions
4471 4472 4473 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4471 def attributions @attributions end |
#comment ⇒ String
This field provides a place for the SPDX file creator to record any general
comments about the file
Corresponds to the JSON property comment
4477 4478 4479 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4477 def comment @comment end |
#contributors ⇒ Array<String>
This field provides a place for the SPDX file creator to record file
contributors
Corresponds to the JSON property contributors
4483 4484 4485 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4483 def contributors @contributors end |
#copyright ⇒ String
Identify the copyright holder of the file, as well as any dates present
Corresponds to the JSON property copyright
4488 4489 4490 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4488 def copyright @copyright end |
#files_license_info ⇒ Array<String>
This field contains the license information actually found in the file, if any
Corresponds to the JSON property filesLicenseInfo
4493 4494 4495 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4493 def files_license_info @files_license_info end |
#id ⇒ String
Uniquely identify any element in an SPDX document which may be referenced by
other elements
Corresponds to the JSON property id
4499 4500 4501 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4499 def id @id end |
#license_concluded ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
Corresponds to the JSON property licenseConcluded
4504 4505 4506 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4504 def license_concluded @license_concluded end |
#notice ⇒ String
This field provides a place for the SPDX file creator to record license
notices or other such related notices found in the file
Corresponds to the JSON property notice
4510 4511 4512 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4510 def notice @notice end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4517 def update!(**args) @attributions = args[:attributions] if args.key?(:attributions) @comment = args[:comment] if args.key?(:comment) @contributors = args[:contributors] if args.key?(:contributors) @copyright = args[:copyright] if args.key?(:copyright) @files_license_info = args[:files_license_info] if args.key?(:files_license_info) @id = args[:id] if args.key?(:id) @license_concluded = args[:license_concluded] if args.key?(:license_concluded) @notice = args[:notice] if args.key?(:notice) end |