Class: Google::Apis::ContaineranalysisV1alpha1::Finding
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Finding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Finding provides details for a single finding within an AISkillAnalysisOccurrence.
Instance Attribute Summary collapse
-
#category ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#file_path ⇒ String
Optional.
-
#rule_id ⇒ String
Optional.
-
#severity ⇒ String
Optional.
-
#snippet ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Finding
constructor
A new instance of Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Finding
Returns a new instance of Finding.
4569 4570 4571 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4569 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Optional. Category of the finding.
Corresponds to the JSON property category
4537 4538 4539 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4537 def category @category end |
#description ⇒ String
Optional. Detailed description of the finding.
Corresponds to the JSON property description
4542 4543 4544 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4542 def description @description end |
#file_path ⇒ String
Optional. Path to the file where the finding was detected.
Corresponds to the JSON property filePath
4547 4548 4549 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4547 def file_path @file_path end |
#rule_id ⇒ String
Optional. Unique identifier of the rule that produced this finding.
Corresponds to the JSON property ruleId
4552 4553 4554 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4552 def rule_id @rule_id end |
#severity ⇒ String
Optional. Severity of the finding.
Corresponds to the JSON property severity
4557 4558 4559 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4557 def severity @severity end |
#snippet ⇒ String
Optional. Code snippet relevant to the finding.
Corresponds to the JSON property snippet
4562 4563 4564 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4562 def snippet @snippet end |
#title ⇒ String
Optional. Title of the finding.
Corresponds to the JSON property title
4567 4568 4569 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4567 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4574 4575 4576 4577 4578 4579 4580 4581 4582 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4574 def update!(**args) @category = args[:category] if args.key?(:category) @description = args[:description] if args.key?(:description) @file_path = args[:file_path] if args.key?(:file_path) @rule_id = args[:rule_id] if args.key?(:rule_id) @severity = args[:severity] if args.key?(:severity) @snippet = args[:snippet] if args.key?(:snippet) @title = args[:title] if args.key?(:title) end |