Class: Google::Apis::ContaineranalysisV1alpha1::GetVulnzOccurrencesSummaryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A summary of how many vulnz occurrences there are per severity type. counts by groups, or if we should have different summary messages like this.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetVulnzOccurrencesSummaryResponse

Returns a new instance of GetVulnzOccurrencesSummaryResponse.



4744
4745
4746
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countsArray<Google::Apis::ContaineranalysisV1alpha1::SeverityCount>

A map of how many occurrences were found for each severity. Corresponds to the JSON property counts



4742
4743
4744
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4742

def counts
  @counts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4749
4750
4751
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4749

def update!(**args)
  @counts = args[:counts] if args.key?(:counts)
end