Class: Google::Apis::ContaineranalysisV1alpha1::GetVulnzOccurrencesSummaryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A summary of how many vulnz occurrences there are per severity type. counts by groups, or if we should have different summary messages like this.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetVulnzOccurrencesSummaryResponse

Returns a new instance of GetVulnzOccurrencesSummaryResponse.



4328
4329
4330
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countsArray<Google::Apis::ContaineranalysisV1alpha1::SeverityCount>

A map of how many occurrences were found for each severity. Corresponds to the JSON property counts



4326
4327
4328
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4326

def counts
  @counts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4333
4334
4335
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4333

def update!(**args)
  @counts = args[:counts] if args.key?(:counts)
end