Class: Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder.



4895
4896
4897
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

URI indicating the builder’s identity. Corresponds to the JSON property id

Returns:

  • (String)


4893
4894
4895
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4893

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4900
4901
4902
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4900

def update!(**args)
  @id = args[:id] if args.key?(:id)
end