Class: Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SourceContext

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsContaineranalysisV1alpha1SourceContext

Returns a new instance of GoogleDevtoolsContaineranalysisV1alpha1SourceContext.



4759
4760
4761
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_repoGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1CloudRepoSourceContext

A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo. Corresponds to the JSON property cloudRepo



4741
4742
4743
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4741

def cloud_repo
  @cloud_repo
end

#gerritGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1GerritSourceContext

A SourceContext referring to a Gerrit project. Corresponds to the JSON property gerrit



4746
4747
4748
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4746

def gerrit
  @gerrit
end

#gitGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1GitSourceContext

A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub). Corresponds to the JSON property git



4752
4753
4754
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4752

def git
  @git
end

#labelsHash<String,String>

Labels with user defined metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4757
4758
4759
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4757

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4764
4765
4766
4767
4768
4769
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4764

def update!(**args)
  @cloud_repo = args[:cloud_repo] if args.key?(:cloud_repo)
  @gerrit = args[:gerrit] if args.key?(:gerrit)
  @git = args[:git] if args.key?(:git)
  @labels = args[:labels] if args.key?(:labels)
end