Class: Google::Apis::ContaineranalysisV1alpha1::InTotoProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::InTotoProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Instance Attribute Summary collapse
-
#builder_config ⇒ Google::Apis::ContaineranalysisV1alpha1::BuilderConfig
required Corresponds to the JSON property
builderConfig. -
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::Metadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1alpha1::Recipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InTotoProvenance
constructor
A new instance of InTotoProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InTotoProvenance
Returns a new instance of InTotoProvenance.
5286 5287 5288 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder_config ⇒ Google::Apis::ContaineranalysisV1alpha1::BuilderConfig
required
Corresponds to the JSON property builderConfig
5265 5266 5267 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5265 def builder_config @builder_config end |
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
5273 5274 5275 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5273 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::Metadata
Other properties of the build.
Corresponds to the JSON property metadata
5278 5279 5280 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5278 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1alpha1::Recipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
5284 5285 5286 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5284 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5291 5292 5293 5294 5295 5296 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5291 def update!(**args) @builder_config = args[:builder_config] if args.key?(:builder_config) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |