Class: Google::Apis::ContaineranalysisV1alpha1::InTotoProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::InTotoProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Instance Attribute Summary collapse
-
#builder_config ⇒ Google::Apis::ContaineranalysisV1alpha1::BuilderConfig
required Corresponds to the JSON property
builderConfig. -
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::Metadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1alpha1::Recipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InTotoProvenance
constructor
A new instance of InTotoProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InTotoProvenance
Returns a new instance of InTotoProvenance.
5277 5278 5279 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder_config ⇒ Google::Apis::ContaineranalysisV1alpha1::BuilderConfig
required
Corresponds to the JSON property builderConfig
5256 5257 5258 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5256 def builder_config @builder_config end |
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
5264 5265 5266 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5264 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::Metadata
Other properties of the build.
Corresponds to the JSON property metadata
5269 5270 5271 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5269 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1alpha1::Recipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
5275 5276 5277 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5275 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5282 5283 5284 5285 5286 5287 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5282 def update!(**args) @builder_config = args[:builder_config] if args.key?(:builder_config) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |