Class: Google::Apis::ContaineranalysisV1alpha1::InTotoProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoProvenance

Returns a new instance of InTotoProvenance.



4855
4856
4857
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builder_configGoogle::Apis::ContaineranalysisV1alpha1::BuilderConfig

required Corresponds to the JSON property builderConfig



4834
4835
4836
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4834

def builder_config
  @builder_config
end

#materialsArray<String>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


4842
4843
4844
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4842

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1alpha1::Metadata

Other properties of the build. Corresponds to the JSON property metadata



4847
4848
4849
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4847

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1alpha1::Recipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



4853
4854
4855
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4853

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4860
4861
4862
4863
4864
4865
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 4860

def update!(**args)
  @builder_config = args[:builder_config] if args.key?(:builder_config)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end