Class: Google::Apis::ContaineranalysisV1alpha1::InTotoStatement

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Spec defined at https://github.com/in-toto/attestation/tree/main/spec# statement The serialized InTotoStatement will be stored as Envelope.payload. Envelope.payloadType is always "application/vnd.in-toto+json".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoStatement

Returns a new instance of InTotoStatement.



5293
5294
5295
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#_typeString

Always "https://in-toto.io/Statement/v0.1". Corresponds to the JSON property _type

Returns:

  • (String)


5265
5266
5267
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5265

def _type
  @_type
end

#predicate_typeString

"https://slsa.dev/provenance/v0.1" for SlsaProvenance. Corresponds to the JSON property predicateType

Returns:

  • (String)


5270
5271
5272
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5270

def predicate_type
  @predicate_type
end

#provenanceGoogle::Apis::ContaineranalysisV1alpha1::InTotoProvenance

Generic Grafeas provenance. Corresponds to the JSON property provenance



5275
5276
5277
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5275

def provenance
  @provenance
end

#slsa_provenanceGoogle::Apis::ContaineranalysisV1alpha1::SlsaProvenance

SlsaProvenance is the slsa provenance as defined by the slsa spec. Corresponds to the JSON property slsaProvenance



5280
5281
5282
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5280

def slsa_provenance
  @slsa_provenance
end

#slsa_provenance_zero_twoGoogle::Apis::ContaineranalysisV1alpha1::SlsaProvenanceZeroTwo

SlsaProvenanceZeroTwo is the slsa provenance as defined by the slsa spec. See full explanation of fields at slsa.dev/provenance/v0.2. Corresponds to the JSON property slsaProvenanceZeroTwo



5286
5287
5288
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5286

def slsa_provenance_zero_two
  @slsa_provenance_zero_two
end

#subjectArray<Google::Apis::ContaineranalysisV1alpha1::Subject>

subject is the subjects of the intoto statement Corresponds to the JSON property subject



5291
5292
5293
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5291

def subject
  @subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5298

def update!(**args)
  @_type = args[:_type] if args.key?(:_type)
  @predicate_type = args[:predicate_type] if args.key?(:predicate_type)
  @provenance = args[:provenance] if args.key?(:provenance)
  @slsa_provenance = args[:slsa_provenance] if args.key?(:slsa_provenance)
  @slsa_provenance_zero_two = args[:slsa_provenance_zero_two] if args.key?(:slsa_provenance_zero_two)
  @subject = args[:subject] if args.key?(:subject)
end