Class: Google::Apis::ContaineranalysisV1alpha1::Installation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Installation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
This represents how a particular software package may be installed on a system.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#cpe_uri ⇒ String
Output only.
-
#license ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
-
#location ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Location>
All of the places within the filesystem versions of this package have been found.
-
#name ⇒ String
Output only.
-
#package_type ⇒ String
Output only.
-
#version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Installation
constructor
A new instance of Installation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Installation
Returns a new instance of Installation.
5411 5412 5413 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture for which packages in this distribution
channel were built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
5372 5373 5374 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5372 def architecture @architecture end |
#cpe_uri ⇒ String
Output only. The cpe_uri in CPE format
denoting the package manager version distributing a package. The cpe_uri will
be blank for language packages.
Corresponds to the JSON property cpeUri
5379 5380 5381 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5379 def cpe_uri @cpe_uri end |
#license ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
Corresponds to the JSON property license
5384 5385 5386 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5384 def license @license end |
#location ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Location>
All of the places within the filesystem versions of this package have been
found.
Corresponds to the JSON property location
5390 5391 5392 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5390 def location @location end |
#name ⇒ String
Output only. The name of the installed package.
Corresponds to the JSON property name
5395 5396 5397 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5395 def name @name end |
#package_type ⇒ String
Output only. The type of package; whether native or non native (e.g., ruby
gems, node.js packages, etc.).
Corresponds to the JSON property packageType
5401 5402 5403 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5401 def package_type @package_type end |
#version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package. For
a discussion of this in Debian/Ubuntu: http://serverfault.com/questions/604541/
debian-packages-version-convention For a discussion of this in Redhat/Fedora/
Centos: http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/
Corresponds to the JSON property version
5409 5410 5411 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5409 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5416 5417 5418 5419 5420 5421 5422 5423 5424 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5416 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @license = args[:license] if args.key?(:license) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @version = args[:version] if args.key?(:version) end |