Class: Google::Apis::ContaineranalysisV1alpha1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



5526
5527
5528
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::ContaineranalysisV1alpha1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



5503
5504
5505
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5503

def base_images
  @base_images
end

#chain_idString

The chain ID of the layer in the container image. Corresponds to the JSON property chainId

Returns:

  • (String)


5508
5509
5510
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5508

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


5514
5515
5516
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5514

def command
  @command
end

#diff_idString

The diff ID (sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


5519
5520
5521
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5519

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


5524
5525
5526
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5524

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5531
5532
5533
5534
5535
5536
5537
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5531

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end