Class: Google::Apis::ContaineranalysisV1alpha1::LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::LayerDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The chain ID of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayerDetails
constructor
A new instance of LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LayerDetails
Returns a new instance of LayerDetails.
5452 5453 5454 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
5429 5430 5431 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5429 def base_images @base_images end |
#chain_id ⇒ String
The chain ID of the layer in the container image.
Corresponds to the JSON property chainId
5434 5435 5436 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5434 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
5440 5441 5442 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5440 def command @command end |
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
5445 5446 5447 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5445 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
5450 5451 5452 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5450 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5457 5458 5459 5460 5461 5462 5463 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5457 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |