Class: Google::Apis::ContaineranalysisV1alpha1::LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::LayerDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The chain ID of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayerDetails
constructor
A new instance of LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LayerDetails
Returns a new instance of LayerDetails.
5104 5105 5106 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
5081 5082 5083 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5081 def base_images @base_images end |
#chain_id ⇒ String
The chain ID of the layer in the container image.
Corresponds to the JSON property chainId
5086 5087 5088 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5086 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
5092 5093 5094 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5092 def command @command end |
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
5097 5098 5099 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5097 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
5102 5103 5104 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5102 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5109 5110 5111 5112 5113 5114 5115 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5109 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |