Class: Google::Apis::ContaineranalysisV1alpha1::Material

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Material is a material used in the generation of the provenance

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Material

Returns a new instance of Material.



5299
5300
5301
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

digest is a map from a hash algorithm (e.g. sha256) to the value in the material Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


5292
5293
5294
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5292

def digest
  @digest
end

#uriString

uri is the uri of the material Corresponds to the JSON property uri

Returns:

  • (String)


5297
5298
5299
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5297

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5304
5305
5306
5307
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5304

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @uri = args[:uri] if args.key?(:uri)
end