Class: Google::Apis::ContaineranalysisV1alpha1::Note
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Note
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Provides a detailed description of a Note.
Instance Attribute Summary collapse
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1alpha1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
-
#attestation_authority ⇒ Google::Apis::ContaineranalysisV1alpha1::AttestationAuthority
Note kind that represents a logical attestation "role" or "authority".
-
#base_image ⇒ Google::Apis::ContaineranalysisV1alpha1::Basis
Basis describes the base image portion (Note) of the DockerImage relationship.
-
#build_type ⇒ Google::Apis::ContaineranalysisV1alpha1::BuildType
Note holding the version of the provider's builder and the signature of the provenance message in linked BuildDetails.
-
#compliance ⇒ Google::Apis::ContaineranalysisV1alpha1::ComplianceNote
ComplianceNote encapsulates all information about a specific compliance check.
-
#create_time ⇒ String
Output only.
-
#deployable ⇒ Google::Apis::ContaineranalysisV1alpha1::Deployable
An artifact that can be deployed in some runtime.
-
#discovery ⇒ Google::Apis::ContaineranalysisV1alpha1::Discovery
A note that indicates a type of analysis a provider would perform.
-
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::DsseAttestationNote
A note describing an attestation Corresponds to the JSON property
dsseAttestation. -
#expiration_time ⇒ String
Time of expiration for this note, null if note does not expire.
-
#kind ⇒ String
Output only.
-
#long_description ⇒ String
A detailed description of this
Note. -
#name ⇒ String
The name of the note in the form "projects/
provider_project_id/notes/NOTE_ID" Corresponds to the JSON propertyname. -
#package ⇒ Google::Apis::ContaineranalysisV1alpha1::Package
This represents a particular package that is distributed over various channels.
-
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::RelatedUrl>
URLs associated with this note Corresponds to the JSON property
relatedUrl. -
#sbom ⇒ Google::Apis::ContaineranalysisV1alpha1::DocumentNote
DocumentNote represents an SPDX Document Creation Infromation section: https:// spdx.github.io/spdx-spec/2-document-creation-information/ Corresponds to the JSON property
sbom. -
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomReferenceNote
The note representing an SBOM reference.
-
#secret ⇒ Google::Apis::ContaineranalysisV1alpha1::SecretNote
The note representing a secret.
-
#short_description ⇒ String
A one sentence description of this
Note. -
#spdx_file ⇒ Google::Apis::ContaineranalysisV1alpha1::FileNote
FileNote represents an SPDX File Information section: https://spdx.github.io/ spdx-spec/4-file-information/ Corresponds to the JSON property
spdxFile. -
#spdx_package ⇒ Google::Apis::ContaineranalysisV1alpha1::PackageInfoNote
PackageInfoNote represents an SPDX Package Information section: https://spdx.
-
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1alpha1::RelationshipNote
RelationshipNote represents an SPDX Relationship section: https://spdx.github.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::ContaineranalysisV1alpha1::UpgradeNote
An Upgrade Note represents a potential upgrade of a package to a given version.
-
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE.
-
#vulnerability_type ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityType
VulnerabilityType provides metadata about a security vulnerability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Note
constructor
A new instance of Note.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Note
Returns a new instance of Note.
5901 5902 5903 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1alpha1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
5746 5747 5748 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5746 def ai_skill_analysis @ai_skill_analysis end |
#attestation_authority ⇒ Google::Apis::ContaineranalysisV1alpha1::AttestationAuthority
Note kind that represents a logical attestation "role" or "authority". For
example, an organization might have one AttestationAuthority for "QA" and
one for "build". This Note is intended to act strictly as a grouping mechanism
for the attached Occurrences (Attestations). This grouping mechanism also
provides a security boundary, since IAM ACLs gate the ability for a principle
to attach an Occurrence to a given Note. It also provides a single point of
lookup to find all attached Attestation Occurrences, even if they don't all
live in the same project.
Corresponds to the JSON property attestationAuthority
5758 5759 5760 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5758 def @attestation_authority end |
#base_image ⇒ Google::Apis::ContaineranalysisV1alpha1::Basis
Basis describes the base image portion (Note) of the DockerImage relationship.
Linked occurrences are derived from this or an equivalent image via: FROM Or
an equivalent reference, e.g. a tag of the resource_url.
Corresponds to the JSON property baseImage
5765 5766 5767 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5765 def base_image @base_image end |
#build_type ⇒ Google::Apis::ContaineranalysisV1alpha1::BuildType
Note holding the version of the provider's builder and the signature of the
provenance message in linked BuildDetails.
Corresponds to the JSON property buildType
5771 5772 5773 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5771 def build_type @build_type end |
#compliance ⇒ Google::Apis::ContaineranalysisV1alpha1::ComplianceNote
ComplianceNote encapsulates all information about a specific compliance check.
Corresponds to the JSON property compliance
5776 5777 5778 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5776 def compliance @compliance end |
#create_time ⇒ String
Output only. The time this note was created. This field can be used as a
filter in list requests.
Corresponds to the JSON property createTime
5782 5783 5784 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5782 def create_time @create_time end |
#deployable ⇒ Google::Apis::ContaineranalysisV1alpha1::Deployable
An artifact that can be deployed in some runtime.
Corresponds to the JSON property deployable
5787 5788 5789 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5787 def deployable @deployable end |
#discovery ⇒ Google::Apis::ContaineranalysisV1alpha1::Discovery
A note that indicates a type of analysis a provider would perform. This note
exists in a provider's project. A Discovery occurrence is created in a
consumer's project at the start of analysis. The occurrence's operation will
indicate the status of the analysis. Absence of an occurrence linked to this
note for a resource indicates that analysis hasn't started.
Corresponds to the JSON property discovery
5796 5797 5798 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5796 def discovery @discovery end |
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::DsseAttestationNote
A note describing an attestation
Corresponds to the JSON property dsseAttestation
5801 5802 5803 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5801 def dsse_attestation @dsse_attestation end |
#expiration_time ⇒ String
Time of expiration for this note, null if note does not expire.
Corresponds to the JSON property expirationTime
5806 5807 5808 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5806 def expiration_time @expiration_time end |
#kind ⇒ String
Output only. This explicitly denotes which kind of note is specified. This
field can be used as a filter in list requests.
Corresponds to the JSON property kind
5812 5813 5814 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5812 def kind @kind end |
#long_description ⇒ String
A detailed description of this Note.
Corresponds to the JSON property longDescription
5817 5818 5819 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5817 def long_description @long_description end |
#name ⇒ String
The name of the note in the form "projects/provider_project_id/notes/
NOTE_ID"
Corresponds to the JSON property name
5823 5824 5825 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5823 def name @name end |
#package ⇒ Google::Apis::ContaineranalysisV1alpha1::Package
This represents a particular package that is distributed over various channels.
e.g. glibc (aka libc6) is distributed by many, at various versions.
Corresponds to the JSON property package
5829 5830 5831 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5829 def package @package end |
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::RelatedUrl>
URLs associated with this note
Corresponds to the JSON property relatedUrl
5834 5835 5836 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5834 def @related_url end |
#sbom ⇒ Google::Apis::ContaineranalysisV1alpha1::DocumentNote
DocumentNote represents an SPDX Document Creation Infromation section: https://
spdx.github.io/spdx-spec/2-document-creation-information/
Corresponds to the JSON property sbom
5840 5841 5842 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5840 def sbom @sbom end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomReferenceNote
The note representing an SBOM reference.
Corresponds to the JSON property sbomReference
5845 5846 5847 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5845 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1alpha1::SecretNote
The note representing a secret.
Corresponds to the JSON property secret
5850 5851 5852 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5850 def secret @secret end |
#short_description ⇒ String
A one sentence description of this Note.
Corresponds to the JSON property shortDescription
5855 5856 5857 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5855 def short_description @short_description end |
#spdx_file ⇒ Google::Apis::ContaineranalysisV1alpha1::FileNote
FileNote represents an SPDX File Information section: https://spdx.github.io/
spdx-spec/4-file-information/
Corresponds to the JSON property spdxFile
5861 5862 5863 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5861 def spdx_file @spdx_file end |
#spdx_package ⇒ Google::Apis::ContaineranalysisV1alpha1::PackageInfoNote
PackageInfoNote represents an SPDX Package Information section: https://spdx.
github.io/spdx-spec/3-package-information/
Corresponds to the JSON property spdxPackage
5867 5868 5869 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5867 def spdx_package @spdx_package end |
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1alpha1::RelationshipNote
RelationshipNote represents an SPDX Relationship section: https://spdx.github.
io/spdx-spec/7-relationships-between-SPDX-elements/
Corresponds to the JSON property spdxRelationship
5873 5874 5875 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5873 def spdx_relationship @spdx_relationship end |
#update_time ⇒ String
Output only. The time this note was last updated. This field can be used as a
filter in list requests.
Corresponds to the JSON property updateTime
5879 5880 5881 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5879 def update_time @update_time end |
#upgrade ⇒ Google::Apis::ContaineranalysisV1alpha1::UpgradeNote
An Upgrade Note represents a potential upgrade of a package to a given version.
For each package version combination (i.e. bash 4.0, bash 4.1, bash 4.1.2),
there will be a Upgrade Note.
Corresponds to the JSON property upgrade
5886 5887 5888 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5886 def upgrade @upgrade end |
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's
vulnerability assessment for one CVE. Multiple VulnerabilityAssessmentNotes
together form a Vex statement. Please go/sds-vex-example for a sample Vex
statement in the CSAF format.
Corresponds to the JSON property vulnerabilityAssessment
5894 5895 5896 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5894 def vulnerability_assessment @vulnerability_assessment end |
#vulnerability_type ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityType
VulnerabilityType provides metadata about a security vulnerability.
Corresponds to the JSON property vulnerabilityType
5899 5900 5901 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5899 def vulnerability_type @vulnerability_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5906 def update!(**args) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation_authority = args[:attestation_authority] if args.key?(:attestation_authority) @base_image = args[:base_image] if args.key?(:base_image) @build_type = args[:build_type] if args.key?(:build_type) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @deployable = args[:deployable] if args.key?(:deployable) @discovery = args[:discovery] if args.key?(:discovery) @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @kind = args[:kind] if args.key?(:kind) @long_description = args[:long_description] if args.key?(:long_description) @name = args[:name] if args.key?(:name) @package = args[:package] if args.key?(:package) @related_url = args[:related_url] if args.key?(:related_url) @sbom = args[:sbom] if args.key?(:sbom) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @short_description = args[:short_description] if args.key?(:short_description) @spdx_file = args[:spdx_file] if args.key?(:spdx_file) @spdx_package = args[:spdx_package] if args.key?(:spdx_package) @spdx_relationship = args[:spdx_relationship] if args.key?(:spdx_relationship) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) @vulnerability_assessment = args[:vulnerability_assessment] if args.key?(:vulnerability_assessment) @vulnerability_type = args[:vulnerability_type] if args.key?(:vulnerability_type) end |