Class: Google::Apis::ContaineranalysisV1alpha1::Occurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Occurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Occurrence includes information about analysis occurrences for an image.
Instance Attribute Summary collapse
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1alpha1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
-
#attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::Attestation
Occurrence that represents a single "attestation".
-
#build_details ⇒ Google::Apis::ContaineranalysisV1alpha1::BuildDetails
Message encapsulating build provenance details.
-
#compliance ⇒ Google::Apis::ContaineranalysisV1alpha1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.
-
#create_time ⇒ String
Output only.
-
#deployment ⇒ Google::Apis::ContaineranalysisV1alpha1::Deployment
The period during which some deployable was active in a runtime.
-
#derived_image ⇒ Google::Apis::ContaineranalysisV1alpha1::Derived
Derived describes the derived image portion (Occurrence) of the DockerImage relationship.
-
#discovered ⇒ Google::Apis::ContaineranalysisV1alpha1::Discovered
Provides information about the scan status of a discovered resource.
-
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::DsseAttestationOccurrence
An occurrence describing an attestation on a resource Corresponds to the JSON property
dsseAttestation. - #envelope ⇒ Google::Apis::ContaineranalysisV1alpha1::Envelope
-
#installation ⇒ Google::Apis::ContaineranalysisV1alpha1::Installation
This represents how a particular software package may be installed on a system.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#note_name ⇒ String
An analysis note associated with this image, in the form "providers/
provider_id/notes/NOTE_ID" This field can be used as a filter in list requests. -
#remediation ⇒ String
A description of actions that can be taken to remedy the
NoteCorresponds to the JSON propertyremediation. -
#resource ⇒ Google::Apis::ContaineranalysisV1alpha1::Resource
Resource is an entity that can have metadata.
-
#resource_url ⇒ String
The unique URL of the image or the container for which the
Occurrenceapplies. -
#sbom ⇒ Google::Apis::ContaineranalysisV1alpha1::DocumentOccurrence
DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/ Corresponds to the JSON property
sbom. -
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific resource.
-
#secret ⇒ Google::Apis::ContaineranalysisV1alpha1::SecretOccurrence
The occurrence provides details of a secret.
-
#spdx_file ⇒ Google::Apis::ContaineranalysisV1alpha1::FileOccurrence
FileOccurrence represents an SPDX File Information section: https://spdx.
-
#spdx_package ⇒ Google::Apis::ContaineranalysisV1alpha1::PackageInfoOccurrence
PackageInfoOccurrence represents an SPDX Package Information section: https:// spdx.github.io/spdx-spec/3-package-information/ Corresponds to the JSON property
spdxPackage. -
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1alpha1::RelationshipOccurrence
RelationshipOccurrence represents an SPDX Relationship section: https://spdx.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::ContaineranalysisV1alpha1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade.
-
#vulnerability_details ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityDetails
Used by Occurrence to point to where the vulnerability exists and how to fix it.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Occurrence
constructor
A new instance of Occurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Occurrence
Returns a new instance of Occurrence.
6244 6245 6246 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1alpha1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
6092 6093 6094 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6092 def ai_skill_analysis @ai_skill_analysis end |
#attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::Attestation
Occurrence that represents a single "attestation". The authenticity of an
Attestation can be verified using the attached signature. If the verifier
trusts the public key of the signer, then verifying the signature is
sufficient to establish trust. In this circumstance, the AttestationAuthority
to which this Attestation is attached is primarily useful for look-up (how to
find this Attestation if you already know the Authority and artifact to be
verified) and intent (which authority was this attestation intended to sign
for).
Corresponds to the JSON property attestation
6104 6105 6106 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6104 def attestation @attestation end |
#build_details ⇒ Google::Apis::ContaineranalysisV1alpha1::BuildDetails
Message encapsulating build provenance details.
Corresponds to the JSON property buildDetails
6109 6110 6111 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6109 def build_details @build_details end |
#compliance ⇒ Google::Apis::ContaineranalysisV1alpha1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were
not satisfied for particular resources or a specified reason.
Corresponds to the JSON property compliance
6115 6116 6117 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6115 def compliance @compliance end |
#create_time ⇒ String
Output only. The time this Occurrence was created.
Corresponds to the JSON property createTime
6120 6121 6122 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6120 def create_time @create_time end |
#deployment ⇒ Google::Apis::ContaineranalysisV1alpha1::Deployment
The period during which some deployable was active in a runtime.
Corresponds to the JSON property deployment
6125 6126 6127 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6125 def deployment @deployment end |
#derived_image ⇒ Google::Apis::ContaineranalysisV1alpha1::Derived
Derived describes the derived image portion (Occurrence) of the DockerImage
relationship. This image would be produced from a Dockerfile with FROM .
Corresponds to the JSON property derivedImage
6131 6132 6133 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6131 def derived_image @derived_image end |
#discovered ⇒ Google::Apis::ContaineranalysisV1alpha1::Discovered
Provides information about the scan status of a discovered resource.
Corresponds to the JSON property discovered
6136 6137 6138 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6136 def discovered @discovered end |
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1alpha1::DsseAttestationOccurrence
An occurrence describing an attestation on a resource
Corresponds to the JSON property dsseAttestation
6141 6142 6143 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6141 def dsse_attestation @dsse_attestation end |
#envelope ⇒ Google::Apis::ContaineranalysisV1alpha1::Envelope
MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope.
proto. An authenticated message of arbitrary type.
Corresponds to the JSON property envelope
6147 6148 6149 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6147 def envelope @envelope end |
#installation ⇒ Google::Apis::ContaineranalysisV1alpha1::Installation
This represents how a particular software package may be installed on a system.
Corresponds to the JSON property installation
6152 6153 6154 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6152 def installation @installation end |
#kind ⇒ String
Output only. This explicitly denotes which of the Occurrence details are
specified. This field can be used as a filter in list requests.
Corresponds to the JSON property kind
6158 6159 6160 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6158 def kind @kind end |
#name ⇒ String
Output only. The name of the Occurrence in the form "projects/project_id/
occurrences/OCCURRENCE_ID"
Corresponds to the JSON property name
6164 6165 6166 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6164 def name @name end |
#note_name ⇒ String
An analysis note associated with this image, in the form "providers/
provider_id/notes/NOTE_ID" This field can be used as a filter in list
requests.
Corresponds to the JSON property noteName
6171 6172 6173 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6171 def note_name @note_name end |
#remediation ⇒ String
A description of actions that can be taken to remedy the Note
Corresponds to the JSON property remediation
6176 6177 6178 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6176 def remediation @remediation end |
#resource ⇒ Google::Apis::ContaineranalysisV1alpha1::Resource
Resource is an entity that can have metadata. E.g., a Docker image.
Corresponds to the JSON property resource
6181 6182 6183 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6181 def resource @resource end |
#resource_url ⇒ String
The unique URL of the image or the container for which the Occurrence
applies. For example, https://gcr.io/project/image@sha256:foo This field can
be used as a filter in list requests.
Corresponds to the JSON property resourceUrl
6188 6189 6190 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6188 def resource_url @resource_url end |
#sbom ⇒ Google::Apis::ContaineranalysisV1alpha1::DocumentOccurrence
DocumentOccurrence represents an SPDX Document Creation Information section:
https://spdx.github.io/spdx-spec/2-document-creation-information/
Corresponds to the JSON property sbom
6194 6195 6196 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6194 def sbom @sbom end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1alpha1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific
resource. The occurrence follows the DSSE specification. See https://github.
com/secure-systems-lab/dsse/blob/master/envelope.md for more details.
Corresponds to the JSON property sbomReference
6201 6202 6203 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6201 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1alpha1::SecretOccurrence
The occurrence provides details of a secret.
Corresponds to the JSON property secret
6206 6207 6208 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6206 def secret @secret end |
#spdx_file ⇒ Google::Apis::ContaineranalysisV1alpha1::FileOccurrence
FileOccurrence represents an SPDX File Information section: https://spdx.
github.io/spdx-spec/4-file-information/
Corresponds to the JSON property spdxFile
6212 6213 6214 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6212 def spdx_file @spdx_file end |
#spdx_package ⇒ Google::Apis::ContaineranalysisV1alpha1::PackageInfoOccurrence
PackageInfoOccurrence represents an SPDX Package Information section: https://
spdx.github.io/spdx-spec/3-package-information/
Corresponds to the JSON property spdxPackage
6218 6219 6220 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6218 def spdx_package @spdx_package end |
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1alpha1::RelationshipOccurrence
RelationshipOccurrence represents an SPDX Relationship section: https://spdx.
github.io/spdx-spec/7-relationships-between-SPDX-elements/
Corresponds to the JSON property spdxRelationship
6224 6225 6226 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6224 def spdx_relationship @spdx_relationship end |
#update_time ⇒ String
Output only. The time this Occurrence was last updated.
Corresponds to the JSON property updateTime
6229 6230 6231 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6229 def update_time @update_time end |
#upgrade ⇒ Google::Apis::ContaineranalysisV1alpha1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a
specific upgrade. This presence is supplied via local sources (i.e. it is
present in the mirror and the running system has noticed its availability).
Corresponds to the JSON property upgrade
6236 6237 6238 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6236 def upgrade @upgrade end |
#vulnerability_details ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityDetails
Used by Occurrence to point to where the vulnerability exists and how to fix
it.
Corresponds to the JSON property vulnerabilityDetails
6242 6243 6244 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6242 def vulnerability_details @vulnerability_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6249 def update!(**args) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation = args[:attestation] if args.key?(:attestation) @build_details = args[:build_details] if args.key?(:build_details) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @deployment = args[:deployment] if args.key?(:deployment) @derived_image = args[:derived_image] if args.key?(:derived_image) @discovered = args[:discovered] if args.key?(:discovered) @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation) @envelope = args[:envelope] if args.key?(:envelope) @installation = args[:installation] if args.key?(:installation) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @note_name = args[:note_name] if args.key?(:note_name) @remediation = args[:remediation] if args.key?(:remediation) @resource = args[:resource] if args.key?(:resource) @resource_url = args[:resource_url] if args.key?(:resource_url) @sbom = args[:sbom] if args.key?(:sbom) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @spdx_file = args[:spdx_file] if args.key?(:spdx_file) @spdx_package = args[:spdx_package] if args.key?(:spdx_package) @spdx_relationship = args[:spdx_relationship] if args.key?(:spdx_relationship) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) @vulnerability_details = args[:vulnerability_details] if args.key?(:vulnerability_details) end |