Class: Google::Apis::ContaineranalysisV1alpha1::Package
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Package
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
This represents a particular package that is distributed over various channels. e.g. glibc (aka libc6) is distributed by many, at various versions.
Instance Attribute Summary collapse
-
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were built.
-
#cpe_uri ⇒ String
The cpe_uri in CPE format denoting the package manager version distributing a package.
-
#description ⇒ String
The description of this package.
-
#digest ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Digest>
Hash value, typically a file digest, that allows unique identification a specific package.
-
#distribution ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Distribution>
The various channels by which a package is distributed.
-
#license ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
-
#maintainer ⇒ String
A freeform text denoting the maintainer of this package.
-
#name ⇒ String
The name of the package.
-
#package_type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).
-
#url ⇒ String
The homepage for this package.
-
#version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Package
constructor
A new instance of Package.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Package
Returns a new instance of Package.
5900 5901 5902 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were
built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
5841 5842 5843 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5841 def architecture @architecture end |
#cpe_uri ⇒ String
The cpe_uri in CPE format denoting the
package manager version distributing a package. The cpe_uri will be blank for
language packages.
Corresponds to the JSON property cpeUri
5848 5849 5850 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5848 def cpe_uri @cpe_uri end |
#description ⇒ String
The description of this package.
Corresponds to the JSON property description
5853 5854 5855 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5853 def description @description end |
#digest ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Digest>
Hash value, typically a file digest, that allows unique identification a
specific package.
Corresponds to the JSON property digest
5859 5860 5861 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5859 def digest @digest end |
#distribution ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Distribution>
The various channels by which a package is distributed.
Corresponds to the JSON property distribution
5864 5865 5866 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5864 def distribution @distribution end |
#license ⇒ Google::Apis::ContaineranalysisV1alpha1::License
License information.
Corresponds to the JSON property license
5869 5870 5871 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5869 def license @license end |
#maintainer ⇒ String
A freeform text denoting the maintainer of this package.
Corresponds to the JSON property maintainer
5874 5875 5876 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5874 def maintainer @maintainer end |
#name ⇒ String
The name of the package.
Corresponds to the JSON property name
5879 5880 5881 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5879 def name @name end |
#package_type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js
packages, etc.).
Corresponds to the JSON property packageType
5885 5886 5887 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5885 def package_type @package_type end |
#url ⇒ String
The homepage for this package.
Corresponds to the JSON property url
5890 5891 5892 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5890 def url @url end |
#version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package. For
a discussion of this in Debian/Ubuntu: http://serverfault.com/questions/604541/
debian-packages-version-convention For a discussion of this in Redhat/Fedora/
Centos: http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/
Corresponds to the JSON property version
5898 5899 5900 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5898 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 5905 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @description = args[:description] if args.key?(:description) @digest = args[:digest] if args.key?(:digest) @distribution = args[:distribution] if args.key?(:distribution) @license = args[:license] if args.key?(:license) @maintainer = args[:maintainer] if args.key?(:maintainer) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @url = args[:url] if args.key?(:url) @version = args[:version] if args.key?(:version) end |