Class: Google::Apis::ContaineranalysisV1alpha1::PackageInfoNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

PackageInfoNote represents an SPDX Package Information section: https://spdx. github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoNote

Returns a new instance of PackageInfoNote.



6536
6537
6538
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzedBoolean Also known as: analyzed?

Indicates whether the file content of this package has been available for or subjected to analysis when creating the SPDX document Corresponds to the JSON property analyzed

Returns:

  • (Boolean)


6438
6439
6440
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6438

def analyzed
  @analyzed
end

#attributionString

A place for the SPDX data creator to record, at the package level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attribution

Returns:

  • (String)


6445
6446
6447
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6445

def attribution
  @attribution
end

#checksumString

Provide an independently reproducible mechanism that permits unique identification of a specific package that correlates to the data in this SPDX file Corresponds to the JSON property checksum

Returns:

  • (String)


6452
6453
6454
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6452

def checksum
  @checksum
end

Identify the copyright holders of the package, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


6457
6458
6459
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6457

def copyright
  @copyright
end

#detailed_descriptionString

A more detailed description of the package Corresponds to the JSON property detailedDescription

Returns:

  • (String)


6462
6463
6464
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6462

def detailed_description
  @detailed_description
end

#download_locationString

This section identifies the download Universal Resource Locator (URL), or a specific location within a version control system (VCS) for the package at the time that the SPDX file was created Corresponds to the JSON property downloadLocation

Returns:

  • (String)


6469
6470
6471
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6469

def download_location
  @download_location
end

#external_refsArray<Google::Apis::ContaineranalysisV1alpha1::ExternalRef>

ExternalRef Corresponds to the JSON property externalRefs



6474
6475
6476
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6474

def external_refs
  @external_refs
end

#files_license_infoArray<String>

Contain the license the SPDX file creator has concluded as governing the This field is to contain a list of all licenses found in the package. The relationship between licenses (i.e., conjunctive, disjunctive) is not specified in this field – it is simply a listing of all licenses found Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


6482
6483
6484
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6482

def files_license_info
  @files_license_info
end

#home_pageString

Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6488
6489
6490
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6488

def home_page
  @home_page
end

#license_declaredGoogle::Apis::ContaineranalysisV1alpha1::License

License information. Corresponds to the JSON property licenseDeclared



6493
6494
6495
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6493

def license_declared
  @license_declared
end

#originatorString

If the package identified in the SPDX file originated from a different person or organization than identified as Package Supplier, this field identifies from where or whom the package originally came Corresponds to the JSON property originator

Returns:

  • (String)


6500
6501
6502
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6500

def originator
  @originator
end

#package_typeString

The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6505
6506
6507
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6505

def package_type
  @package_type
end

#summary_descriptionString

A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6510
6511
6512
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6510

def summary_description
  @summary_description
end

#supplierString

Identify the actual distribution source for the package/directory identified in the SPDX file Corresponds to the JSON property supplier

Returns:

  • (String)


6516
6517
6518
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6516

def supplier
  @supplier
end

#titleString

Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6521
6522
6523
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6521

def title
  @title
end

#verification_codeString

This field provides an independently reproducible mechanism identifying specific contents of a package based on the actual files (except the SPDX file itself, if it is included in the package) that make up each package and that correlates to the data in this SPDX file Corresponds to the JSON property verificationCode

Returns:

  • (String)


6529
6530
6531
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6529

def verification_code
  @verification_code
end

#versionString

Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6534
6535
6536
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6534

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6541

def update!(**args)
  @analyzed = args[:analyzed] if args.key?(:analyzed)
  @attribution = args[:attribution] if args.key?(:attribution)
  @checksum = args[:checksum] if args.key?(:checksum)
  @copyright = args[:copyright] if args.key?(:copyright)
  @detailed_description = args[:detailed_description] if args.key?(:detailed_description)
  @download_location = args[:download_location] if args.key?(:download_location)
  @external_refs = args[:external_refs] if args.key?(:external_refs)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @home_page = args[:home_page] if args.key?(:home_page)
  @license_declared = args[:license_declared] if args.key?(:license_declared)
  @originator = args[:originator] if args.key?(:originator)
  @package_type = args[:package_type] if args.key?(:package_type)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @supplier = args[:supplier] if args.key?(:supplier)
  @title = args[:title] if args.key?(:title)
  @verification_code = args[:verification_code] if args.key?(:verification_code)
  @version = args[:version] if args.key?(:version)
end