Class: Google::Apis::ContaineranalysisV1alpha1::PackageInfoNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

PackageInfoNote represents an SPDX Package Information section: https://spdx. github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoNote

Returns a new instance of PackageInfoNote.



6443
6444
6445
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzedBoolean Also known as: analyzed?

Indicates whether the file content of this package has been available for or subjected to analysis when creating the SPDX document Corresponds to the JSON property analyzed

Returns:

  • (Boolean)


6345
6346
6347
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6345

def analyzed
  @analyzed
end

#attributionString

A place for the SPDX data creator to record, at the package level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attribution

Returns:

  • (String)


6352
6353
6354
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6352

def attribution
  @attribution
end

#checksumString

Provide an independently reproducible mechanism that permits unique identification of a specific package that correlates to the data in this SPDX file Corresponds to the JSON property checksum

Returns:

  • (String)


6359
6360
6361
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6359

def checksum
  @checksum
end

Identify the copyright holders of the package, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


6364
6365
6366
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6364

def copyright
  @copyright
end

#detailed_descriptionString

A more detailed description of the package Corresponds to the JSON property detailedDescription

Returns:

  • (String)


6369
6370
6371
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6369

def detailed_description
  @detailed_description
end

#download_locationString

This section identifies the download Universal Resource Locator (URL), or a specific location within a version control system (VCS) for the package at the time that the SPDX file was created Corresponds to the JSON property downloadLocation

Returns:

  • (String)


6376
6377
6378
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6376

def download_location
  @download_location
end

#external_refsArray<Google::Apis::ContaineranalysisV1alpha1::ExternalRef>

ExternalRef Corresponds to the JSON property externalRefs



6381
6382
6383
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6381

def external_refs
  @external_refs
end

#files_license_infoArray<String>

Contain the license the SPDX file creator has concluded as governing the This field is to contain a list of all licenses found in the package. The relationship between licenses (i.e., conjunctive, disjunctive) is not specified in this field – it is simply a listing of all licenses found Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


6389
6390
6391
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6389

def files_license_info
  @files_license_info
end

#home_pageString

Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6395
6396
6397
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6395

def home_page
  @home_page
end

#license_declaredGoogle::Apis::ContaineranalysisV1alpha1::License

License information. Corresponds to the JSON property licenseDeclared



6400
6401
6402
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6400

def license_declared
  @license_declared
end

#originatorString

If the package identified in the SPDX file originated from a different person or organization than identified as Package Supplier, this field identifies from where or whom the package originally came Corresponds to the JSON property originator

Returns:

  • (String)


6407
6408
6409
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6407

def originator
  @originator
end

#package_typeString

The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6412
6413
6414
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6412

def package_type
  @package_type
end

#summary_descriptionString

A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6417
6418
6419
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6417

def summary_description
  @summary_description
end

#supplierString

Identify the actual distribution source for the package/directory identified in the SPDX file Corresponds to the JSON property supplier

Returns:

  • (String)


6423
6424
6425
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6423

def supplier
  @supplier
end

#titleString

Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6428
6429
6430
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6428

def title
  @title
end

#verification_codeString

This field provides an independently reproducible mechanism identifying specific contents of a package based on the actual files (except the SPDX file itself, if it is included in the package) that make up each package and that correlates to the data in this SPDX file Corresponds to the JSON property verificationCode

Returns:

  • (String)


6436
6437
6438
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6436

def verification_code
  @verification_code
end

#versionString

Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6441
6442
6443
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6441

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6448
6449
6450
6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6448

def update!(**args)
  @analyzed = args[:analyzed] if args.key?(:analyzed)
  @attribution = args[:attribution] if args.key?(:attribution)
  @checksum = args[:checksum] if args.key?(:checksum)
  @copyright = args[:copyright] if args.key?(:copyright)
  @detailed_description = args[:detailed_description] if args.key?(:detailed_description)
  @download_location = args[:download_location] if args.key?(:download_location)
  @external_refs = args[:external_refs] if args.key?(:external_refs)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @home_page = args[:home_page] if args.key?(:home_page)
  @license_declared = args[:license_declared] if args.key?(:license_declared)
  @originator = args[:originator] if args.key?(:originator)
  @package_type = args[:package_type] if args.key?(:package_type)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @supplier = args[:supplier] if args.key?(:supplier)
  @title = args[:title] if args.key?(:title)
  @verification_code = args[:verification_code] if args.key?(:verification_code)
  @version = args[:version] if args.key?(:version)
end