Class: Google::Apis::ContaineranalysisV1alpha1::PackageInfoOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

PackageInfoOccurrence represents an SPDX Package Information section: https:// spdx.github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoOccurrence

Returns a new instance of PackageInfoOccurrence.



6114
6115
6116
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

A place for the SPDX file creator to record any general comments about the package being described Corresponds to the JSON property comment

Returns:

  • (String)


6062
6063
6064
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6062

def comment
  @comment
end

#filenameString

Provide the actual file name of the package, or path of the directory being treated as a package Corresponds to the JSON property filename

Returns:

  • (String)


6068
6069
6070
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6068

def filename
  @filename
end

#home_pageString

Output only. Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6074
6075
6076
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6074

def home_page
  @home_page
end

#idString

Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property id

Returns:

  • (String)


6080
6081
6082
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6080

def id
  @id
end

#license_concludedGoogle::Apis::ContaineranalysisV1alpha1::License

License information. Corresponds to the JSON property licenseConcluded



6085
6086
6087
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6085

def license_concluded
  @license_concluded
end

#package_typeString

Output only. The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6090
6091
6092
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6090

def package_type
  @package_type
end

#source_infoString

Provide a place for the SPDX file creator to record any relevant background information or additional comments about the origin of the package Corresponds to the JSON property sourceInfo

Returns:

  • (String)


6096
6097
6098
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6096

def source_info
  @source_info
end

#summary_descriptionString

Output only. A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6101
6102
6103
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6101

def summary_description
  @summary_description
end

#titleString

Output only. Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6107
6108
6109
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6107

def title
  @title
end

#versionString

Output only. Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6112
6113
6114
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6112

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6119

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @filename = args[:filename] if args.key?(:filename)
  @home_page = args[:home_page] if args.key?(:home_page)
  @id = args[:id] if args.key?(:id)
  @license_concluded = args[:license_concluded] if args.key?(:license_concluded)
  @package_type = args[:package_type] if args.key?(:package_type)
  @source_info = args[:source_info] if args.key?(:source_info)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @title = args[:title] if args.key?(:title)
  @version = args[:version] if args.key?(:version)
end