Class: Google::Apis::ContaineranalysisV1alpha1::PackageIssue
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::PackageIssue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
This message wraps a location affected by a vulnerability and its associated fix (if one is available).
Instance Attribute Summary collapse
-
#affected_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability Corresponds to the JSON property
affectedLocation. -
#effective_severity ⇒ String
Output only.
-
#fixed_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability Corresponds to the JSON property
fixedLocation. -
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
-
#severity_name ⇒ String
Corresponds to the JSON property
severityName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageIssue
constructor
A new instance of PackageIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageIssue
Returns a new instance of PackageIssue.
6675 6676 6677 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability
Corresponds to the JSON property affectedLocation
6650 6651 6652 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6650 def affected_location @affected_location end |
#effective_severity ⇒ String
Output only. The distro or language system assigned severity for this
vulnerability when that is available and note provider assigned severity when
distro or language system has not yet assigned a severity for this
vulnerability.
Corresponds to the JSON property effectiveSeverity
6658 6659 6660 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6658 def effective_severity @effective_severity end |
#fixed_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability
Corresponds to the JSON property fixedLocation
6663 6664 6665 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6663 def fixed_location @fixed_location end |
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Corresponds to the JSON property packageType
6668 6669 6670 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6668 def package_type @package_type end |
#severity_name ⇒ String
Corresponds to the JSON property severityName
6673 6674 6675 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6673 def severity_name @severity_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6680 6681 6682 6683 6684 6685 6686 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6680 def update!(**args) @affected_location = args[:affected_location] if args.key?(:affected_location) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @fixed_location = args[:fixed_location] if args.key?(:fixed_location) @package_type = args[:package_type] if args.key?(:package_type) @severity_name = args[:severity_name] if args.key?(:severity_name) end |