Class: Google::Apis::ContaineranalysisV1alpha1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

This message wraps a location affected by a vulnerability and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



6594
6595
6596
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property affectedLocation



6569
6570
6571
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6569

def affected_location
  @affected_location
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when distro or language system has not yet assigned a severity for this vulnerability. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


6577
6578
6579
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6577

def effective_severity
  @effective_severity
end

#fixed_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property fixedLocation



6582
6583
6584
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6582

def fixed_location
  @fixed_location
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


6587
6588
6589
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6587

def package_type
  @package_type
end

#severity_nameString

Corresponds to the JSON property severityName

Returns:

  • (String)


6592
6593
6594
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6592

def severity_name
  @severity_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6599
6600
6601
6602
6603
6604
6605
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6599

def update!(**args)
  @affected_location = args[:affected_location] if args.key?(:affected_location)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @fixed_location = args[:fixed_location] if args.key?(:fixed_location)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
end