Class: Google::Apis::ContaineranalysisV1alpha1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

This message wraps a location affected by a vulnerability and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



6526
6527
6528
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property affectedLocation



6501
6502
6503
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6501

def affected_location
  @affected_location
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when distro or language system has not yet assigned a severity for this vulnerability. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


6509
6510
6511
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6509

def effective_severity
  @effective_severity
end

#fixed_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property fixedLocation



6514
6515
6516
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6514

def fixed_location
  @fixed_location
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


6519
6520
6521
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6519

def package_type
  @package_type
end

#severity_nameString

Corresponds to the JSON property severityName

Returns:

  • (String)


6524
6525
6526
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6524

def severity_name
  @severity_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6531
6532
6533
6534
6535
6536
6537
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6531

def update!(**args)
  @affected_location = args[:affected_location] if args.key?(:affected_location)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @fixed_location = args[:fixed_location] if args.key?(:fixed_location)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
end