Class: Google::Apis::ContaineranalysisV1alpha1::PackageIssue
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::PackageIssue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
This message wraps a location affected by a vulnerability and its associated fix (if one is available).
Instance Attribute Summary collapse
-
#affected_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability Corresponds to the JSON property
affectedLocation. -
#effective_severity ⇒ String
Output only.
-
#fixed_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability Corresponds to the JSON property
fixedLocation. -
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
-
#severity_name ⇒ String
Corresponds to the JSON property
severityName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageIssue
constructor
A new instance of PackageIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageIssue
Returns a new instance of PackageIssue.
6526 6527 6528 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability
Corresponds to the JSON property affectedLocation
6501 6502 6503 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6501 def affected_location @affected_location end |
#effective_severity ⇒ String
Output only. The distro or language system assigned severity for this
vulnerability when that is available and note provider assigned severity when
distro or language system has not yet assigned a severity for this
vulnerability.
Corresponds to the JSON property effectiveSeverity
6509 6510 6511 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6509 def effective_severity @effective_severity end |
#fixed_location ⇒ Google::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation
The location of the vulnerability
Corresponds to the JSON property fixedLocation
6514 6515 6516 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6514 def fixed_location @fixed_location end |
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Corresponds to the JSON property packageType
6519 6520 6521 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6519 def package_type @package_type end |
#severity_name ⇒ String
Corresponds to the JSON property severityName
6524 6525 6526 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6524 def severity_name @severity_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6531 6532 6533 6534 6535 6536 6537 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6531 def update!(**args) @affected_location = args[:affected_location] if args.key?(:affected_location) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @fixed_location = args[:fixed_location] if args.key?(:fixed_location) @package_type = args[:package_type] if args.key?(:package_type) @severity_name = args[:severity_name] if args.key?(:severity_name) end |