Class: Google::Apis::ContaineranalysisV1alpha1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

This message wraps a location affected by a vulnerability and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



6166
6167
6168
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property affectedLocation



6141
6142
6143
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6141

def affected_location
  @affected_location
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when distro or language system has not yet assigned a severity for this vulnerability. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


6149
6150
6151
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6149

def effective_severity
  @effective_severity
end

#fixed_locationGoogle::Apis::ContaineranalysisV1alpha1::VulnerabilityLocation

The location of the vulnerability Corresponds to the JSON property fixedLocation



6154
6155
6156
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6154

def fixed_location
  @fixed_location
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


6159
6160
6161
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6159

def package_type
  @package_type
end

#severity_nameString

Corresponds to the JSON property severityName

Returns:

  • (String)


6164
6165
6166
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6164

def severity_name
  @severity_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6171
6172
6173
6174
6175
6176
6177
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6171

def update!(**args)
  @affected_location = args[:affected_location] if args.key?(:affected_location)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @fixed_location = args[:fixed_location] if args.key?(:fixed_location)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
end