Class: Google::Apis::ContaineranalysisV1alpha1::Publisher
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Publisher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Publisher contains information about the publisher of this Note.
Instance Attribute Summary collapse
-
#issuing_authority ⇒ String
Provides information about the authority of the issuing party to release the document, in particular, the party's constituency and responsibilities or other obligations.
-
#name ⇒ String
Name of the publisher.
-
#publisher_namespace ⇒ String
The context or namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Publisher
constructor
A new instance of Publisher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Publisher
Returns a new instance of Publisher.
6828 6829 6830 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issuing_authority ⇒ String
Provides information about the authority of the issuing party to release the
document, in particular, the party's constituency and responsibilities or
other obligations.
Corresponds to the JSON property issuingAuthority
6814 6815 6816 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6814 def @issuing_authority end |
#name ⇒ String
Name of the publisher. Examples: 'Google', 'Google Cloud Platform'.
Corresponds to the JSON property name
6819 6820 6821 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6819 def name @name end |
#publisher_namespace ⇒ String
The context or namespace. Contains a URL which is under control of the issuing
party and can be used as a globally unique identifier for that issuing party.
Example: https://csaf.io
Corresponds to the JSON property publisherNamespace
6826 6827 6828 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6826 def publisher_namespace @publisher_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6833 6834 6835 6836 6837 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6833 def update!(**args) @issuing_authority = args[:issuing_authority] if args.key?(:issuing_authority) @name = args[:name] if args.key?(:name) @publisher_namespace = args[:publisher_namespace] if args.key?(:publisher_namespace) end |