Class: Google::Apis::ContaineranalysisV1alpha1::Publisher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Publisher contains information about the publisher of this Note.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Publisher

Returns a new instance of Publisher.



6772
6773
6774
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#issuing_authorityString

Provides information about the authority of the issuing party to release the document, in particular, the party's constituency and responsibilities or other obligations. Corresponds to the JSON property issuingAuthority

Returns:

  • (String)


6758
6759
6760
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6758

def issuing_authority
  @issuing_authority
end

#nameString

Name of the publisher. Examples: 'Google', 'Google Cloud Platform'. Corresponds to the JSON property name

Returns:

  • (String)


6763
6764
6765
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6763

def name
  @name
end

#publisher_namespaceString

The context or namespace. Contains a URL which is under control of the issuing party and can be used as a globally unique identifier for that issuing party. Example: https://csaf.io Corresponds to the JSON property publisherNamespace

Returns:

  • (String)


6770
6771
6772
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6770

def publisher_namespace
  @publisher_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6777
6778
6779
6780
6781
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6777

def update!(**args)
  @issuing_authority = args[:issuing_authority] if args.key?(:issuing_authority)
  @name = args[:name] if args.key?(:name)
  @publisher_namespace = args[:publisher_namespace] if args.key?(:publisher_namespace)
end