Class: Google::Apis::ContaineranalysisV1alpha1::Risk
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Risk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The Risk message provides information about the risk of a vulnerability.
Instance Attribute Summary collapse
-
#cisa_kev ⇒ Google::Apis::ContaineranalysisV1alpha1::CisaKnownExploitedVulnerabilities
CISAKnownExploitedVulnerabilities provides information about whether the vulnerability is known to have been leveraged as part of a ransomware campaign.
-
#epss ⇒ Google::Apis::ContaineranalysisV1alpha1::ExploitPredictionScoringSystem
ExploitPredictionScoringSystem provides information about the Exploit Prediction Scoring System (EPSS) score and percentile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Risk
constructor
A new instance of Risk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Risk
Returns a new instance of Risk.
6750 6751 6752 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cisa_kev ⇒ Google::Apis::ContaineranalysisV1alpha1::CisaKnownExploitedVulnerabilities
CISAKnownExploitedVulnerabilities provides information about whether the
vulnerability is known to have been leveraged as part of a ransomware campaign.
Corresponds to the JSON property cisaKev
6742 6743 6744 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6742 def cisa_kev @cisa_kev end |
#epss ⇒ Google::Apis::ContaineranalysisV1alpha1::ExploitPredictionScoringSystem
ExploitPredictionScoringSystem provides information about the Exploit
Prediction Scoring System (EPSS) score and percentile.
Corresponds to the JSON property epss
6748 6749 6750 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6748 def epss @epss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6755 6756 6757 6758 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 6755 def update!(**args) @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev) @epss = args[:epss] if args.key?(:epss) end |