Class: Google::Apis::ContaineranalysisV1alpha1::SbomReferenceIntotoPredicate
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::SbomReferenceIntotoPredicate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
A predicate which describes the SBOM being referenced.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
A map of algorithm to digest of the contents of the SBOM.
-
#location ⇒ String
The location of the SBOM.
-
#mime_type ⇒ String
The mime type of the SBOM.
-
#referrer_id ⇒ String
The person or system referring this predicate to the consumer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SbomReferenceIntotoPredicate
constructor
A new instance of SbomReferenceIntotoPredicate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SbomReferenceIntotoPredicate
Returns a new instance of SbomReferenceIntotoPredicate.
7490 7491 7492 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
A map of algorithm to digest of the contents of the SBOM.
Corresponds to the JSON property digest
7473 7474 7475 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7473 def digest @digest end |
#location ⇒ String
The location of the SBOM.
Corresponds to the JSON property location
7478 7479 7480 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7478 def location @location end |
#mime_type ⇒ String
The mime type of the SBOM.
Corresponds to the JSON property mimeType
7483 7484 7485 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7483 def mime_type @mime_type end |
#referrer_id ⇒ String
The person or system referring this predicate to the consumer.
Corresponds to the JSON property referrerId
7488 7489 7490 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7488 def referrer_id @referrer_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7495 7496 7497 7498 7499 7500 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7495 def update!(**args) @digest = args[:digest] if args.key?(:digest) @location = args[:location] if args.key?(:location) @mime_type = args[:mime_type] if args.key?(:mime_type) @referrer_id = args[:referrer_id] if args.key?(:referrer_id) end |