Class: Google::Apis::ContaineranalysisV1alpha1::SlsaProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::SlsaProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
SlsaProvenance is the slsa provenance as defined by the slsa spec.
Instance Attribute Summary collapse
-
#builder ⇒ Google::Apis::ContaineranalysisV1alpha1::SlsaBuilder
SlsaBuilder encapsulates the identity of the builder of this provenance.
-
#materials ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Material>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::SlsaMetadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1alpha1::SlsaRecipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenance
constructor
A new instance of SlsaProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenance
Returns a new instance of SlsaProvenance.
7853 7854 7855 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder ⇒ Google::Apis::ContaineranalysisV1alpha1::SlsaBuilder
SlsaBuilder encapsulates the identity of the builder of this provenance.
Corresponds to the JSON property builder
7832 7833 7834 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7832 def builder @builder end |
#materials ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::Material>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
7840 7841 7842 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7840 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::SlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
7845 7846 7847 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7845 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1alpha1::SlsaRecipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
7851 7852 7853 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7851 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7858 7859 7860 7861 7862 7863 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7858 def update!(**args) @builder = args[:builder] if args.key?(:builder) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |