Class: Google::Apis::ContaineranalysisV1alpha1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

SlsaProvenance is the slsa provenance as defined by the slsa spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



7720
7721
7722
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::ContaineranalysisV1alpha1::SlsaBuilder

SlsaBuilder encapsulates the identity of the builder of this provenance. Corresponds to the JSON property builder



7699
7700
7701
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7699

def builder
  @builder
end

#materialsArray<Google::Apis::ContaineranalysisV1alpha1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



7707
7708
7709
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7707

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1alpha1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



7712
7713
7714
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7712

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1alpha1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



7718
7719
7720
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7718

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7725
7726
7727
7728
7729
7730
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7725

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end