Class: Google::Apis::ContaineranalysisV1alpha1::SlsaProvenanceZeroTwo
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::SlsaProvenanceZeroTwo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
SlsaProvenanceZeroTwo is the slsa provenance as defined by the slsa spec. See full explanation of fields at slsa.dev/provenance/v0.2.
Instance Attribute Summary collapse
-
#build_config ⇒ Hash<String,Object>
Lists the steps in the build.
-
#build_type ⇒ String
URI indicating what type of build was performed.
-
#builder ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.
-
#invocation ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
-
#materials ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMaterial>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
constructor
A new instance of SlsaProvenanceZeroTwo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
Returns a new instance of SlsaProvenanceZeroTwo.
7791 7792 7793 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_config ⇒ Hash<String,Object>
Lists the steps in the build.
Corresponds to the JSON property buildConfig
7762 7763 7764 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7762 def build_config @build_config end |
#build_type ⇒ String
URI indicating what type of build was performed.
Corresponds to the JSON property buildType
7767 7768 7769 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7767 def build_type @build_type end |
#builder ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have
correctly performed the operation and populated this provenance.
Corresponds to the JSON property builder
7773 7774 7775 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7773 def builder @builder end |
#invocation ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
Corresponds to the JSON property invocation
7778 7779 7780 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7778 def invocation @invocation end |
#materials ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMaterial>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on.
Corresponds to the JSON property materials
7784 7785 7786 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7784 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
7789 7790 7791 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7789 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7796 def update!(**args) @build_config = args[:build_config] if args.key?(:build_config) @build_type = args[:build_type] if args.key?(:build_type) @builder = args[:builder] if args.key?(:builder) @invocation = args[:invocation] if args.key?(:invocation) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) end |