Class: Google::Apis::ContaineranalysisV1alpha1::SlsaProvenanceZeroTwo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

SlsaProvenanceZeroTwo is the slsa provenance as defined by the slsa spec. See full explanation of fields at slsa.dev/provenance/v0.2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenanceZeroTwo

Returns a new instance of SlsaProvenanceZeroTwo.



7735
7736
7737
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_configHash<String,Object>

Lists the steps in the build. Corresponds to the JSON property buildConfig

Returns:

  • (Hash<String,Object>)


7706
7707
7708
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7706

def build_config
  @build_config
end

#build_typeString

URI indicating what type of build was performed. Corresponds to the JSON property buildType

Returns:

  • (String)


7711
7712
7713
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7711

def build_type
  @build_type
end

#builderGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaBuilder

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance. Corresponds to the JSON property builder



7717
7718
7719
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7717

def builder
  @builder
end

#invocationGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaInvocation

Identifies the event that kicked off the build. Corresponds to the JSON property invocation



7722
7723
7724
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7722

def invocation
  @invocation
end

#materialsArray<Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMaterial>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. Corresponds to the JSON property materials



7728
7729
7730
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7728

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SlsaProvenanceZeroTwoSlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



7733
7734
7735
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7733

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7740
7741
7742
7743
7744
7745
7746
7747
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7740

def update!(**args)
  @build_config = args[:build_config] if args.key?(:build_config)
  @build_type = args[:build_type] if args.key?(:build_type)
  @builder = args[:builder] if args.key?(:builder)
  @invocation = args[:invocation] if args.key?(:invocation)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
end