Class: Google::Apis::ContaineranalysisV1alpha1::Source
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Source
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Source describes the location of the source used for the build.
Instance Attribute Summary collapse
-
#additional_contexts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SourceContext>
If provided, some of the source code used for the build may be found in these locations, in the case where the source repository had multiple remotes or submodules.
-
#artifact_storage_source ⇒ Google::Apis::ContaineranalysisV1alpha1::StorageSource
StorageSource describes the location of the source in an archive file in Google Cloud Storage.
-
#context ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SourceContext
A SourceContext is a reference to a tree of files.
-
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1alpha1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build.
-
#repo_source ⇒ Google::Apis::ContaineranalysisV1alpha1::RepoSource
RepoSource describes the location of the source in a Google Cloud Source Repository.
-
#storage_source ⇒ Google::Apis::ContaineranalysisV1alpha1::StorageSource
StorageSource describes the location of the source in an archive file in Google Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
7506 7507 7508 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_contexts ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SourceContext>
If provided, some of the source code used for the build may be found in these
locations, in the case where the source repository had multiple remotes or
submodules. This list will not include the context specified in the context
field.
Corresponds to the JSON property additionalContexts
7471 7472 7473 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7471 def additional_contexts @additional_contexts end |
#artifact_storage_source ⇒ Google::Apis::ContaineranalysisV1alpha1::StorageSource
StorageSource describes the location of the source in an archive file in
Google Cloud Storage.
Corresponds to the JSON property artifactStorageSource
7477 7478 7479 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7477 def artifact_storage_source @artifact_storage_source end |
#context ⇒ Google::Apis::ContaineranalysisV1alpha1::GoogleDevtoolsContaineranalysisV1alpha1SourceContext
A SourceContext is a reference to a tree of files. A SourceContext together
with a path point to a unique revision of a single file or directory.
Corresponds to the JSON property context
7483 7484 7485 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7483 def context @context end |
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1alpha1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original
source integrity was maintained in the build. The keys to this map are file
paths used as build source and the values contain the hash values for those
files. If the build source came in a single package such as a gzipped tarfile (
.tar.gz), the FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
7492 7493 7494 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7492 def file_hashes @file_hashes end |
#repo_source ⇒ Google::Apis::ContaineranalysisV1alpha1::RepoSource
RepoSource describes the location of the source in a Google Cloud Source
Repository.
Corresponds to the JSON property repoSource
7498 7499 7500 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7498 def repo_source @repo_source end |
#storage_source ⇒ Google::Apis::ContaineranalysisV1alpha1::StorageSource
StorageSource describes the location of the source in an archive file in
Google Cloud Storage.
Corresponds to the JSON property storageSource
7504 7505 7506 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7504 def storage_source @storage_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7511 7512 7513 7514 7515 7516 7517 7518 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 7511 def update!(**args) @additional_contexts = args[:additional_contexts] if args.key?(:additional_contexts) @artifact_storage_source = args[:artifact_storage_source] if args.key?(:artifact_storage_source) @context = args[:context] if args.key?(:context) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @repo_source = args[:repo_source] if args.key?(:repo_source) @storage_source = args[:storage_source] if args.key?(:storage_source) end |