Class: Google::Apis::ContaineranalysisV1alpha1::UpgradeDistribution
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::UpgradeDistribution
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.
Instance Attribute Summary collapse
-
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed.
-
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to.
-
#cve ⇒ Array<String>
The cve that would be resolved by this upgrade.
-
#severity ⇒ String
The severity as specified by the upstream operating system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeDistribution
constructor
A new instance of UpgradeDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeDistribution
Returns a new instance of UpgradeDistribution.
8210 8211 8212 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the
upstream operating system upgrade feed.
Corresponds to the JSON property classification
8192 8193 8194 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8192 def classification @classification end |
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to. See https://
cpe.mitre.org/specification/.
Corresponds to the JSON property cpeUri
8198 8199 8200 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8198 def cpe_uri @cpe_uri end |
#cve ⇒ Array<String>
The cve that would be resolved by this upgrade.
Corresponds to the JSON property cve
8203 8204 8205 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8203 def cve @cve end |
#severity ⇒ String
The severity as specified by the upstream operating system.
Corresponds to the JSON property severity
8208 8209 8210 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8208 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8215 8216 8217 8218 8219 8220 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8215 def update!(**args) @classification = args[:classification] if args.key?(:classification) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @cve = args[:cve] if args.key?(:cve) @severity = args[:severity] if args.key?(:severity) end |