Class: Google::Apis::ContaineranalysisV1alpha1::UpgradeDistribution

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeDistribution

Returns a new instance of UpgradeDistribution.



8198
8199
8200
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationString

The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed. Corresponds to the JSON property classification

Returns:

  • (String)


8180
8181
8182
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8180

def classification
  @classification
end

#cpe_uriString

Required - The specific operating system this metadata applies to. See https:// cpe.mitre.org/specification/. Corresponds to the JSON property cpeUri

Returns:

  • (String)


8186
8187
8188
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8186

def cpe_uri
  @cpe_uri
end

#cveArray<String>

The cve that would be resolved by this upgrade. Corresponds to the JSON property cve

Returns:

  • (Array<String>)


8191
8192
8193
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8191

def cve
  @cve
end

#severityString

The severity as specified by the upstream operating system. Corresponds to the JSON property severity

Returns:

  • (String)


8196
8197
8198
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8196

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8203
8204
8205
8206
8207
8208
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8203

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @cve = args[:cve] if args.key?(:cve)
  @severity = args[:severity] if args.key?(:severity)
end