Class: Google::Apis::ContaineranalysisV1alpha1::UpgradeDistribution
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::UpgradeDistribution
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.
Instance Attribute Summary collapse
-
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed.
-
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to.
-
#cve ⇒ Array<String>
The cve that would be resolved by this upgrade.
-
#severity ⇒ String
The severity as specified by the upstream operating system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeDistribution
constructor
A new instance of UpgradeDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeDistribution
Returns a new instance of UpgradeDistribution.
8142 8143 8144 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the
upstream operating system upgrade feed.
Corresponds to the JSON property classification
8124 8125 8126 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8124 def classification @classification end |
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to. See https://
cpe.mitre.org/specification/.
Corresponds to the JSON property cpeUri
8130 8131 8132 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8130 def cpe_uri @cpe_uri end |
#cve ⇒ Array<String>
The cve that would be resolved by this upgrade.
Corresponds to the JSON property cve
8135 8136 8137 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8135 def cve @cve end |
#severity ⇒ String
The severity as specified by the upstream operating system.
Corresponds to the JSON property severity
8140 8141 8142 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8140 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8147 8148 8149 8150 8151 8152 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8147 def update!(**args) @classification = args[:classification] if args.key?(:classification) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @cve = args[:cve] if args.key?(:cve) @severity = args[:severity] if args.key?(:severity) end |