Class: Google::Apis::ContaineranalysisV1alpha1::UpgradeOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeOccurrence

Returns a new instance of UpgradeOccurrence.



8403
8404
8405
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distributionGoogle::Apis::ContaineranalysisV1alpha1::UpgradeDistribution

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities. Corresponds to the JSON property distribution



8388
8389
8390
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8388

def distribution
  @distribution
end

#packageString

Required - The package this Upgrade is for. Corresponds to the JSON property package

Returns:

  • (String)


8393
8394
8395
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8393

def package
  @package
end

#parsed_versionGoogle::Apis::ContaineranalysisV1alpha1::Version

Version contains structured information about the version of the package. For a discussion of this in Debian/Ubuntu: http://serverfault.com/questions/604541/ debian-packages-version-convention For a discussion of this in Redhat/Fedora/ Centos: http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/ Corresponds to the JSON property parsedVersion



8401
8402
8403
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8401

def parsed_version
  @parsed_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8408
8409
8410
8411
8412
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8408

def update!(**args)
  @distribution = args[:distribution] if args.key?(:distribution)
  @package = args[:package] if args.key?(:package)
  @parsed_version = args[:parsed_version] if args.key?(:parsed_version)
end