Class: Google::Apis::ContaineranalysisV1alpha1::UpgradeOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::UpgradeOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability).
Instance Attribute Summary collapse
-
#distribution ⇒ Google::Apis::ContaineranalysisV1alpha1::UpgradeDistribution
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE).
-
#package ⇒ String
Required - The package this Upgrade is for.
-
#parsed_version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeOccurrence
constructor
A new instance of UpgradeOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeOccurrence
Returns a new instance of UpgradeOccurrence.
8285 8286 8287 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distribution ⇒ Google::Apis::ContaineranalysisV1alpha1::UpgradeDistribution
The Upgrade Distribution represents metadata about the Upgrade for each
operating system (CPE). Some distributions have additional metadata around
updates, classifying them into various categories and severities.
Corresponds to the JSON property distribution
8270 8271 8272 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8270 def distribution @distribution end |
#package ⇒ String
Required - The package this Upgrade is for.
Corresponds to the JSON property package
8275 8276 8277 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8275 def package @package end |
#parsed_version ⇒ Google::Apis::ContaineranalysisV1alpha1::Version
Version contains structured information about the version of the package. For
a discussion of this in Debian/Ubuntu: http://serverfault.com/questions/604541/
debian-packages-version-convention For a discussion of this in Redhat/Fedora/
Centos: http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/
Corresponds to the JSON property parsedVersion
8283 8284 8285 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8283 def parsed_version @parsed_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8290 8291 8292 8293 8294 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8290 def update!(**args) @distribution = args[:distribution] if args.key?(:distribution) @package = args[:package] if args.key?(:package) @parsed_version = args[:parsed_version] if args.key?(:parsed_version) end |