Class: Google::Apis::ContaineranalysisV1alpha1::Volume
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::Volume
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution. Next ID: 3
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the volume to mount.
-
#path ⇒ String
Path at which to mount the volume.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Volume
constructor
A new instance of Volume.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Volume
Returns a new instance of Volume.
8554 8555 8556 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the volume to mount. Volume names must be unique per build step and
must be valid names for Docker volumes. Each named volume must be used by at
least two build steps.
Corresponds to the JSON property name
8545 8546 8547 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8545 def name @name end |
#path ⇒ String
Path at which to mount the volume. Paths must be absolute and cannot conflict
with other volume paths on the same build step or with certain reserved volume
paths.
Corresponds to the JSON property path
8552 8553 8554 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8552 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8559 8560 8561 8562 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8559 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) end |