Class: Google::Apis::ContaineranalysisV1alpha1::Volume

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution. Next ID: 3

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Volume

Returns a new instance of Volume.



8424
8425
8426
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the volume to mount. Volume names must be unique per build step and must be valid names for Docker volumes. Each named volume must be used by at least two build steps. Corresponds to the JSON property name

Returns:

  • (String)


8415
8416
8417
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8415

def name
  @name
end

#pathString

Path at which to mount the volume. Paths must be absolute and cannot conflict with other volume paths on the same build step or with certain reserved volume paths. Corresponds to the JSON property path

Returns:

  • (String)


8422
8423
8424
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8422

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8429
8430
8431
8432
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8429

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
end