Class: Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAssessmentNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE. Multiple VulnerabilityAssessmentNotes together form a Vex statement. Please go/sds-vex-example for a sample Vex statement in the CSAF format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityAssessmentNote

Returns a new instance of VulnerabilityAssessmentNote.



8485
8486
8487
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assessmentGoogle::Apis::ContaineranalysisV1alpha1::Assessment

Assessment provides all information that is related to a single vulnerability for this product. Corresponds to the JSON property assessment



8452
8453
8454
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8452

def assessment
  @assessment
end

#language_codeString

Identifies the language used by this document, corresponding to IETF BCP 47 / RFC 5646. Corresponds to the JSON property languageCode

Returns:

  • (String)


8458
8459
8460
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8458

def language_code
  @language_code
end

#long_descriptionString

A detailed description of this Vex. Corresponds to the JSON property longDescription

Returns:

  • (String)


8463
8464
8465
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8463

def long_description
  @long_description
end

#productGoogle::Apis::ContaineranalysisV1alpha1::Product

Product contains information about a product and how to uniquely identify it. Corresponds to the JSON property product



8468
8469
8470
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8468

def product
  @product
end

#publisherGoogle::Apis::ContaineranalysisV1alpha1::Publisher

Publisher contains information about the publisher of this Note. Corresponds to the JSON property publisher



8473
8474
8475
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8473

def publisher
  @publisher
end

#short_descriptionString

A one sentence description of this Vex. Corresponds to the JSON property shortDescription

Returns:

  • (String)


8478
8479
8480
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8478

def short_description
  @short_description
end

#titleString

The title of the note. E.g. Vex-Debian-11.4 Corresponds to the JSON property title

Returns:

  • (String)


8483
8484
8485
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8483

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8490
8491
8492
8493
8494
8495
8496
8497
8498
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8490

def update!(**args)
  @assessment = args[:assessment] if args.key?(:assessment)
  @language_code = args[:language_code] if args.key?(:language_code)
  @long_description = args[:long_description] if args.key?(:long_description)
  @product = args[:product] if args.key?(:product)
  @publisher = args[:publisher] if args.key?(:publisher)
  @short_description = args[:short_description] if args.key?(:short_description)
  @title = args[:title] if args.key?(:title)
end