Class: Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb

Overview

The status of a vulnerability attestation generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityAttestation

Returns a new instance of VulnerabilityAttestation.



8515
8516
8517
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorString

Output only. If failure, the error reason for why the attestation generation failed. Corresponds to the JSON property error

Returns:

  • (String)


8503
8504
8505
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8503

def error
  @error
end

#last_attempt_timeString

Output only. The last time we attempted to generate an attestation. Corresponds to the JSON property lastAttemptTime

Returns:

  • (String)


8508
8509
8510
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8508

def last_attempt_time
  @last_attempt_time
end

#stateString

Output only. The success/failure state of the latest attestation attempt. Corresponds to the JSON property state

Returns:

  • (String)


8513
8514
8515
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8513

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8520
8521
8522
8523
8524
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8520

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @last_attempt_time = args[:last_attempt_time] if args.key?(:last_attempt_time)
  @state = args[:state] if args.key?(:state)
end