Class: Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::VulnerabilityAttestation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
The status of a vulnerability attestation generation.
Instance Attribute Summary collapse
-
#error ⇒ String
Output only.
-
#last_attempt_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityAttestation
constructor
A new instance of VulnerabilityAttestation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityAttestation
Returns a new instance of VulnerabilityAttestation.
8099 8100 8101 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ String
Output only. If failure, the error reason for why the attestation generation
failed.
Corresponds to the JSON property error
8087 8088 8089 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8087 def error @error end |
#last_attempt_time ⇒ String
Output only. The last time we attempted to generate an attestation.
Corresponds to the JSON property lastAttemptTime
8092 8093 8094 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8092 def last_attempt_time @last_attempt_time end |
#state ⇒ String
Output only. The success/failure state of the latest attestation attempt.
Corresponds to the JSON property state
8097 8098 8099 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8097 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8104 8105 8106 8107 8108 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8104 def update!(**args) @error = args[:error] if args.key?(:error) @last_attempt_time = args[:last_attempt_time] if args.key?(:last_attempt_time) @state = args[:state] if args.key?(:state) end |