Class: Google::Apis::ContaineranalysisV1alpha1::VulnerabilityDetails
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1alpha1::VulnerabilityDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1alpha1/classes.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb,
lib/google/apis/containeranalysis_v1alpha1/representations.rb
Overview
Used by Occurrence to point to where the vulnerability exists and how to fix it.
Instance Attribute Summary collapse
-
#cvss_score ⇒ Float
Output only.
-
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System.
-
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System.
-
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System.
-
#cvss_version ⇒ String
Output only.
-
#effective_severity ⇒ String
The distro assigned severity for this vulnerability when that is available and note provider assigned severity when distro has not yet assigned a severity for this vulnerability.
-
#extra_details ⇒ String
Occurrence-specific extra details about the vulnerability.
-
#package_issue ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::PackageIssue>
The set of affected locations and their fixes (if available) within the associated resource.
-
#risk ⇒ Google::Apis::ContaineranalysisV1alpha1::Risk
The Risk message provides information about the risk of a vulnerability.
-
#severity ⇒ String
Output only.
-
#type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages etc).
-
#vex_assessment ⇒ Google::Apis::ContaineranalysisV1alpha1::VexAssessment
VexAssessment provides all publisher provided Vex information that is related to this vulnerability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityDetails
constructor
A new instance of VulnerabilityDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityDetails
Returns a new instance of VulnerabilityDetails.
8630 8631 8632 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cvss_score ⇒ Float
Output only. The CVSS score of this vulnerability. CVSS score is on a scale of
0-10 where 0 indicates low severity and 10 indicates high severity.
Corresponds to the JSON property cvssScore
8542 8543 8544 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8542 def cvss_score @cvss_score end |
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2
and v3. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS v2
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS v3
details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV2
8553 8554 8555 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8553 def cvss_v2 @cvss_v2 end |
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2
and v3. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS v2
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS v3
details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV3
8564 8565 8566 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8564 def cvss_v3 @cvss_v3 end |
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1alpha1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2
and v3. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS v2
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS v3
details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV4
8575 8576 8577 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8575 def cvss_v4 @cvss_v4 end |
#cvss_version ⇒ String
Output only. CVSS version used to populate cvss_score and severity.
Corresponds to the JSON property cvssVersion
8580 8581 8582 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8580 def cvss_version @cvss_version end |
#effective_severity ⇒ String
The distro assigned severity for this vulnerability when that is available and
note provider assigned severity when distro has not yet assigned a severity
for this vulnerability. When there are multiple package issues for this
vulnerability, they can have different effective severities because some might
come from the distro and some might come from installed language packs (e.g.
Maven JARs or Go binaries). For this reason, it is advised to use the
effective severity on the PackageIssue level, as this field may eventually be
deprecated. In the case where multiple PackageIssues have different effective
severities, the one set here will be the highest severity of any of the
PackageIssues.
Corresponds to the JSON property effectiveSeverity
8594 8595 8596 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8594 def effective_severity @effective_severity end |
#extra_details ⇒ String
Occurrence-specific extra details about the vulnerability.
Corresponds to the JSON property extraDetails
8599 8600 8601 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8599 def extra_details @extra_details end |
#package_issue ⇒ Array<Google::Apis::ContaineranalysisV1alpha1::PackageIssue>
The set of affected locations and their fixes (if available) within the
associated resource.
Corresponds to the JSON property packageIssue
8605 8606 8607 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8605 def package_issue @package_issue end |
#risk ⇒ Google::Apis::ContaineranalysisV1alpha1::Risk
The Risk message provides information about the risk of a vulnerability.
Corresponds to the JSON property risk
8610 8611 8612 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8610 def risk @risk end |
#severity ⇒ String
Output only. The note provider assigned Severity of the vulnerability.
Corresponds to the JSON property severity
8615 8616 8617 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8615 def severity @severity end |
#type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages
etc). This may be deprecated in the future because we can have multiple
PackageIssues with different package types.
Corresponds to the JSON property type
8622 8623 8624 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8622 def type @type end |
#vex_assessment ⇒ Google::Apis::ContaineranalysisV1alpha1::VexAssessment
VexAssessment provides all publisher provided Vex information that is related
to this vulnerability.
Corresponds to the JSON property vexAssessment
8628 8629 8630 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8628 def vex_assessment @vex_assessment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8635 8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 8647 8648 |
# File 'lib/google/apis/containeranalysis_v1alpha1/classes.rb', line 8635 def update!(**args) @cvss_score = args[:cvss_score] if args.key?(:cvss_score) @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2) @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3) @cvss_v4 = args[:cvss_v4] if args.key?(:cvss_v4) @cvss_version = args[:cvss_version] if args.key?(:cvss_version) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @extra_details = args[:extra_details] if args.key?(:extra_details) @package_issue = args[:package_issue] if args.key?(:package_issue) @risk = args[:risk] if args.key?(:risk) @severity = args[:severity] if args.key?(:severity) @type = args[:type] if args.key?(:type) @vex_assessment = args[:vex_assessment] if args.key?(:vex_assessment) end |